@@ -15,7 +15,8 @@
 #   along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
-#   Copyright (C) 2017   	Xavier Padullés <x.padulles@gmail.com>
+#   Copyright (C) 2017-2020   	Xavier Padullés <x.padulles@gmail.com>
+#   Copyright (C) 2017-2020     Xavier de Blas <xaviblas@gmail.com>
 
 #call from Chronojump or:
 
@@ -46,11 +47,15 @@ assignOptions <- function(options)
                 drawRfdOptions          = drawRfdOptions,
                 drawImpulseOptions      = options[16],
 		testLength 		= as.numeric(options[17]),
-		title 	 		= options[18],
-                scriptsPath 		= options[19]
+		captureOptions 		= options[18],
+		title 	 		= options[19],
+		exercise 	 	= options[20],
+		datetime 	 	= options[21],
+                scriptsPath 		= options[22]
         ))
 }
 
+
 #-------------- get params -------------
 args <- commandArgs(TRUE)
 
@@ -68,6 +73,12 @@ print(op)
 
 source(paste(op$scriptsPath, "/scripts-util.R", sep=""))
 
+op$title = fixTitleAndOtherStrings(op$title)
+op$exercise = fixTitleAndOtherStrings(op$exercise)
+titleFull = paste(op$title, op$exercise, sep=" - ")
+
+op$datetime = fixDatetime(op$datetime)
+
 
 #Fits the data to the model f = fmax*(1 - exp(-K*t))
 #Important! It fits the data with the axes moved to initf and startTime. The real maximum force is fmax + initf
@@ -84,19 +95,24 @@ getForceModel <- function(time, force, startTime, # startTime is the instant whe
 
         fmax = summary(model)$coeff[1,1]
         K = summary(model)$coeff[2,1]
-        return(list(fmax = fmax, K = K, error =sum(abs(residuals(model)))))
+        return(list(fmax = fmax, K = K, error = 100*residuals(model)/data$force))
 }
 
-getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentChange = 5, bestFit = TRUE, testLength = -1)
+getDynamicsFromLoadCellFile <- function(captureOptions, inputFile, averageLength = 0.1, percentChange = 5, bestFit = TRUE, testLength = -1)
 {
         originalTest = read.csv(inputFile, header = F, dec = op$decimalChar, sep = ";", skip = 2)
         colnames(originalTest) <- c("time", "force")
         originalTest$time = as.numeric(originalTest$time / 1000000)  # Time is converted from microseconds to seconds
-        
+
+	if(captureOptions == "ABS")
+		originalTest$force = abs(originalTest$force)
+	else if(captureOptions == "INVERTED")
+		originalTest$force = -1 * originalTest$force
+
         #Instantaneous RFD
         rfd = getRFD(originalTest)
         
-        #Finding the decrease of the foce to detect the end of the maximum voluntary force
+        #Finding the increase and decrease of the force to detect the start and end of the maximum voluntary force test
         trimmingSamples = getTrimmingSamples(originalTest, rfd, averageLength = averageLength, percentChange = percentChange,
 					     testLength = op$testLength, startDetectingMethod = "SD")
         startSample = trimmingSamples$startSample
@@ -118,29 +134,29 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
         
         f.smoothed = getMovingAverageForce(originalTest, averageLength = averageLength) #Running average with equal weight averageLength seconds
         fmax.smoothed = max(f.smoothed, na.rm = TRUE)
-        lastRelativeError = 1E16
+        lastmeanError = 1E16
         #Trimming the data before and after contraction
         testTrimmed = originalTest[startSample:endSample,]
         
         model = getForceModel(testTrimmed$time, testTrimmed$force, startTime, fmax.smoothed, initf)
-        relativeError = model$error / length(testTrimmed$force)
+        meanError = mean(abs(model$error))
         
         # print(paste("Error:", model$error))
         # print(paste("length:", length(testTrimmed$force)))
-        # print(paste("Relative Error:", relativeError))
+        # print(paste("Relative Error:", meanError))
         # print("--------")
         
-        
-        if(bestFit)     #looking for the startSample that best fits the data
+        #If bestFit is TRUE, this overrides the startSample calculus and find the startSample that makes the best fit of the curve  
+        if(bestFit)
         {
-                while(relativeError < lastRelativeError)
+                while(meanError < lastmeanError)
                 {
-                        lastRelativeError = relativeError
+                        lastmeanError = meanError
                         
                         startSample = startSample + 1
                         startTime = originalTest$time[startSample]
                         
-                        #Make this only if testLength = -1
+                        #If the lenght of the test is fixed, moving the startSample implies moving the endSample also
                         if (testLength != -1){
                                 endSample = endSample + 1
                                 endTime = originalTest$time[endSample]
@@ -151,7 +167,7 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
                         testTrimmed = originalTest[startSample:endSample,]
                         
                         model = getForceModel(testTrimmed$time, testTrimmed$force, startTime, fmax.smoothed, initf)
-                        relativeError = model$error / length(testTrimmed$force)
+                        meanError = mean(abs(model$error))
                         
                         #print(paste("Error:", model$error))
                         #print(paste("length:", length(testTrimmed$force)))
@@ -191,11 +207,11 @@ getDynamicsFromLoadCellFile <- function(inputFile, averageLength = 0.1, percentC
                     rfd = rfd,
                     f.raw = originalTest$force, f.smoothed = f.smoothed, f.fitted = f.fitted,
                     endTime = endTime,
-                    relativeError = relativeError))
+                    meanError = meanError))
 }
 
 drawDynamicsFromLoadCell <- function(
-        dynamics, vlineT0=T, vline50fmax.raw=F, vline50fmax.fitted=F,
+        dynamics, captureOptions, vlineT0=T, vline50fmax.raw=F, vline50fmax.fitted=F,
         hline50fmax.raw=F, hline50fmax.fitted=F,
         rfdDrawingOptions, xlimits = NA)
 {
@@ -220,7 +236,7 @@ drawDynamicsFromLoadCell <- function(
                 yHeight = max(dynamics$fmax.raw, dynamics$fmax.fitted) * 1.1
         }
                 
-	par(mar=c(4,4,1,1))
+	par(mar=c(4,4,3,1))
         #Plotting raw data from startTime to endTime (Only the analysed data)
         if (!is.na(xlimits[1])){
                 xWidth = xlimits[2] - xlimits[1]
@@ -228,8 +244,9 @@ drawDynamicsFromLoadCell <- function(
                      type="l", xlab="Time[s]", ylab="Force[N]",
                      xlim = xlimits, ylim=c(0, yHeight),
                      #main = dynamics$nameOfFile,
-		     main = op$title,
+		     main = paste(parse(text = paste0("'", titleFull, "'"))), #process unicode, needed paste because its an expression. See graph.R
 		     yaxs= "i", xaxs = "i")
+		mtext(op$datetime, line = 0)
                 xmin = xlimits[1]
                 xmax = xlimits[2]
                 #points(dynamics$time[dynamics$startSample:dynamics$endSample] , dynamics$f.raw[dynamics$startSample:dynamics$endSample])
@@ -242,8 +259,9 @@ drawDynamicsFromLoadCell <- function(
                      xlim = c(xmin, xmax),
                      ylim=c(0, yHeight),
                      #main = dynamics$nameOfFile,
-		     main = op$title,
+		     main = paste(parse(text = paste0("'", titleFull, "'"))), #process unicode, needed paste because its an expression. See graph.R
 		     yaxs= "i", xaxs = "i")
+		mtext(op$datetime, line = 0)
         }
         
 
@@ -325,9 +343,9 @@ drawDynamicsFromLoadCell <- function(
                 }
                 
                 text(x = (dynamics$startTime + (dynamics$time[endImpulseSample] - dynamics$time[startImpulseSample])*0.66), y = mean(dynamics$f.raw[startImpulseSample:endImpulseSample])*0.66,
-                     labels = paste("Impulse =", round(impulse, digits = 2), "N·s"), pos = 4, cex = 1.5)
+                     labels = paste("Impulse =", round(impulse, digits = 2), "N\u00B7s"), pos = 4, cex = 1.5)
 
-		impulseLegend = paste("Impulse", impulseOptions$start, "-", impulseOptions$end, " = ", round(impulse, digits = 2), " N·s", sep = "")
+		impulseLegend = paste("Impulse", impulseOptions$start, "-", impulseOptions$end, " = ", round(impulse, digits = 2), " N\u00B7s", sep = "") #\u00B7 is ·
         }
         
         #Plotting not analysed data
@@ -338,9 +356,9 @@ drawDynamicsFromLoadCell <- function(
         #Plotting fitted data
         lines(dynamics$time, dynamics$f.fitted, col="blue")
         abline(h = dynamics$fmax.fitted, lty = 2, col = "blue")
-        text(x = xmin + (xmax - xmin)*0.25, y = dynamics$fmax.fitted,
-             labels = paste("Fmax =", round(dynamics$fmax.fitted,digits = 2), "N"),
-             col = "blue", pos = 3, cex = 1.5)
+	text(x = xmax, y = dynamics$fmax.fitted,
+	     labels = paste("Fmax =", round(dynamics$fmax.fitted,digits = 2), "N"),
+             col = "blue", cex = 1.5, adj=c(1,0))
         
         #Plottting smoothed data
         #lines(dynamics$time, dynamics$f.smoothed, col="grey")
@@ -404,8 +422,8 @@ drawDynamicsFromLoadCell <- function(
         
         legendText = c(
 		       paste("Fmax =", round(dynamics$fmax.fitted, digits = 2), "N"),
-		       paste("K = ", round(dynamics$k.fitted, digits = 2),"s^-1"),
-		       paste("tau = ", round(dynamics$tau.fitted, digits = 2),"s")
+		       paste("K = ", round(dynamics$k.fitted, digits = 2),"s\u207B\u00B9"),
+		       paste("\u03C4 = ", round(dynamics$tau.fitted, digits = 2),"s")
 		       )
         legendColor = c("blue", "blue", "blue")
         
@@ -599,8 +617,13 @@ drawDynamicsFromLoadCell <- function(
                 legendColor = c(legendColor, impulseColor)
 	}
         
-        legendText = c(legendText, paste("MeanError = ", round(dynamics$relativeError, digits = 2), " N", sep =""))
-        legendColor = c(legendColor, "red")
+        legendText = c(legendText, paste("MeanError = ", round(dynamics$meanError, digits = 2), "%", sep =""))
+        if (dynamics$meanError >= 5){
+                legendColor = c(legendColor, "red")
+                text(x = xmax, y = dynamics$fmax.fitted*0.01, labels = "The mean error is larger than 5%. Possible bad execution", col = "red", pos = 2)
+        } else {
+                legendColor = c(legendColor, "grey40")
+        }
 
 	legend(x = xmax, y = dynamics$fmax.fitted/2, legend = legendText, xjust = 1, yjust = 0.1, text.col = legendColor)
 }
@@ -619,7 +642,7 @@ getDynamicsFromLoadCellFolder <- function(folderName, resultFileName, export2Pdf
         
         for(i in 1:nFiles)
         {
-                dynamics = getDynamicsFromLoadCellFile(paste(folderName,originalFiles[i], sep = ""))
+                dynamics = getDynamicsFromLoadCellFile(op$captureOptions, paste(folderName,originalFiles[i], sep = ""))
                 
                 results[i, "fileName"] = dynamics$nameOfFile
                 results[i, "fmax.fitted"] = dynamics$fmax.fitted
@@ -643,8 +666,15 @@ getDynamicsFromLoadCellFolder <- function(folderName, resultFileName, export2Pdf
         
 }
 
-#Finds the sample in which the force start incresing (RFD > 20% of maxRFD)
-#and decrease a given percentage of the maximum force.
+#Finds the sample in which the force start incresing with two optional methods
+# - SD method: When the force increase 3 times the standard deviation
+# - RFD method: When the RFD is at least 20% of the maximum RFD
+#
+#If bestFit is TRUE then the startSample is changed in order to find the startSample that minimizes the mean error of the model.
+#bestFit gives better resuls for model variables. The counterpart is that there's no scientific papers using it and some control of the procerss is lost
+#as it is more difficult to predict the startSample by humans.
+#
+#This function also finds the sample at which there is a decrease of a given percentage of the maximum force.
 #The maximum force is calculed from the moving average of averageLength seconds
 getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.1, percentChange = 5, testLength = -1, startDetectingMethod = "SD")
 {
@@ -652,7 +682,7 @@ getTrimmingSamples <- function(test, rfd, movingAverageForce, averageLength = 0.
         maxRFD = max(rfd[2:(length(rfd) - 1)])
         maxRFDSample = which.max(rfd[2:(length(rfd) - 1)])
         
-        #Detecting when the force is greater of the mean + 3*SD of 20 samples
+        #Detecting when the force is greater than (mean of 20 samples) + 3*SD
         #If in various sample the force are greater, the last one before the maxRFD are taken
         #See Rate of force development: physiological and methodological considerations. Nicola A. Maffiuletti1 et al.
         
@@ -768,8 +798,8 @@ readImpulseOptions <- function(optionsStr)
 
 prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
 
-dynamics = getDynamicsFromLoadCellFile(dataFile, op$averageLength, op$percentChange, bestFit = TRUE, testLength = -1)
-drawDynamicsFromLoadCell(dynamics, op$vlineT0, op$vline50fmax.raw, op$vline50fmax.fitted, op$hline50fmax.raw, op$hline50fmax.fitted,
+dynamics = getDynamicsFromLoadCellFile(op$captureOptions, dataFile, op$averageLength, op$percentChange, bestFit = TRUE, testLength = -1)
+drawDynamicsFromLoadCell(dynamics, op$captureOptions, op$vlineT0, op$vline50fmax.raw, op$vline50fmax.fitted, op$hline50fmax.raw, op$hline50fmax.fitted,
                          op$drawRfdOptions)
 #                         op$drawRfdOptions, xlimits = c(0.5, 1.5))
 endGraph()
