@@ -15,7 +15,9 @@
 #   along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 # 
-#   Copyright (C) 2018   	Xavier Padullés <x.padulles@gmail.com>
+#   Copyright (C) 2018-2020   	Xavier Padullés <x.padulles@gmail.com>
+#   Copyright (C) 2020   	Xavier de Blas <xaviblas@gmail.com>
+
 
 #-------------- get params -------------
 args <- commandArgs(TRUE)
@@ -42,14 +44,29 @@ assignOptions <- function(options) {
                 testLength = as.numeric(options[6]),
                 os 		= options[7],
                 graphWidth 	= as.numeric(options[8]),
-                graphHeight	= as.numeric(options[9])
+                graphHeight	= as.numeric(options[9]),
+                device  	= options[10],
+                title 	 	= options[11],
+                datetime 	= options[12],
+                startAccel 	= options[13],
+                plotRawAccel 	= as.logical(options[14]),
+                plotFittedAccel = as.logical(options[15]),
+                plotRawForce 	= as.logical(options[16]),
+                plotFittedForce = as.logical(options[17]),
+                plotRawPower 	= as.logical(options[18]),
+                plotFittedPower = as.logical(options[19]),
+		triggersOnList  = as.numeric(unlist(strsplit(options[20], "\\;"))),
+		triggersOffList  = as.numeric(unlist(strsplit(options[21], "\\;")))
         ))
 }
 
 #-------------- assign options -------------
 op <- assignOptions(options)
 
-getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, Height , Vw = 0)
+op$title = fixTitleAndOtherStrings(op$title)
+op$datetime = fixDatetime(op$datetime)
+
+getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, Height , Vw = 0, device = "MANUAL", startAccel)
 {
         print("#####Entering in getSprintFromEncoder###############")
         # Constants for the air friction modeling
@@ -64,28 +81,45 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         colnames(raceAnalyzer) = c("displacement", "time", "force")
         raceAnalyzer$force = (raceAnalyzer$force) * 0.175806451613 /2  #TODO: Implement the calibration factor comming from the arduino
         totalTime = raceAnalyzer$time/1E6     #Converting microseconds to seconds
-        elapsedTime = diff(c(0,totalTime))      #The elapsed time between each sample
+        elapsedTime = diff(totalTime)      #The elapsed time between each sample
+        #raceAnalyzer = raceAnalyzer[2:length(raceAnalyzer)]
+        #totalTime = totalTime[1:length(totalTime)]
         
         #The encoder can be used with both loose ends of the rope. This means that the encoder can rotate
-        #in both directions. We considre always the speed as positive.
+        #in both directions. We consider always the speed as positive.
         if(mean(raceAnalyzer$displacement) < 0)
                 raceAnalyzer$displacement = -raceAnalyzer$displacement
-        diameter = 0.16         #Diameter of the pulley
-        #raceAnalyzer$displacement = raceAnalyzer$displacement * 2 * pi * diameter / 200
-        #In 30m there are 12267 pulses.
-        #TODO: measure this several times to have an accurate value
-        raceAnalyzer$displacement = 4 * raceAnalyzer$displacement * 30 / 12267
+        
+        #TODO: measure metersPerPulse several times to have an accurate value
+	metersPerPulse = NULL
+	if(device == "MANUAL")                 #manual race analyzer - Hand device
+	        metersPerPulse = 0.003003
+	else                                    #resisted race analyzer - sled device
+	        metersPerPulse = 4 * 30 / 12267 	#With an encoder of 200 ppr, in 30m there are 12267 pulses.
+
+        raceAnalyzer$displacement = raceAnalyzer$displacement * metersPerPulse
         position = cumsum(raceAnalyzer$displacement)
-        speed = raceAnalyzer$displacement / elapsedTime
-        accel = (speed[3] - speed[1]) / (totalTime[3] - totalTime[1])
+        speed = raceAnalyzer$displacement[2:length(raceAnalyzer$displacement)] / elapsedTime
+        
+        #Adjusting the time of each sample to the mean time between two samples
+        for( i in 2:length(totalTime)){
+                totalTime[i] = totalTime[i] - elapsedTime[i-1] / 2
+        }
+        
+        #Accel of the sample N is the mean accel between N-1 and N+1 samples.
+        #The time of the accel sample is the same as the speed sample.
+        #TODO. Adjust the time at which this accel is measured.
+        accel = speed[2] / totalTime[2]
         for(i in 3:(length(speed) -1))
         {
                 accel = c(accel, (speed[i+1] - speed[i-1]) / (totalTime[i +1] - totalTime[i -1]))
         }
-        accel = c(accel[1],accel, accel[length(accel)])
+        accel = c(accel, accel[length(accel)])
         forceBody = accel * Mass + Ka*(speed - Vw)^2
         totalForce = forceBody + raceAnalyzer$force
         power = totalForce * speed
+        # print("totalTime:")
+        # print(totalTime)
         # print("time:")
         # print(raceAnalyzer$time)
         # print("elapsedTime:")
@@ -100,8 +134,8 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         # print(forceBody)
         # print("forceRope:")
         # print(raceAnalyzer$force)
-        print("power:")
-        print(power)
+        # print("power:")
+        # print(power)
         
         
         # #Checking if the sprint is long enough
@@ -120,7 +154,7 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
                 abline(h = testLength, lty = 2)
                 text(x = (totalTime[length(totalTime)] + totalTime[1])/2,
                      y = testLength,
-                     labels = (paste("Configured test length :", testLength, "m", sep = "")),
+                     labels = (paste("Configured test length :", testLength, " m", sep = "")),
                      pos = 3)
                 text(x = (totalTime[length(totalTime)] + totalTime[1])/2, testLength /2,
                      labels = "The capture does not reach the length of the test", cex = 2, pos = 3)
@@ -132,13 +166,36 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         }
         
         #Finding when the sprint starts
-        trimmingSamples = getTrimmingSamples(totalTime, position, speed, accel, testLength)
+        trimmingSamples = getTrimmingSamples(totalTime, position, speed, accel, testLength, startAccel)
         print(trimmingSamples)
+
+	#plot error if no enough acceleration
+	if(trimmingSamples$start == -1 & trimmingSamples$end == -1)
+	{
+		plot(position, type = "l", ylab = "Position (m)")
+                text(x = length(position)/2, y = max(position)/2,
+                     labels = "The capture has not enough accel", cex = 2, pos = 3)
+                text(x = length(position)/2, y = max(position)/3,
+                     labels = paste("Max raw detected accel: ", round(max(accel),2), "\nMinimum raw accel needed: ", startAccel), cex = 2, pos = 3)
+                text(x = length(position)/2, y = max(position)/4,
+                     labels = "or does not seem a sprint", cex = 2, pos = 3)
+		print("Capture has not enough accel")
+		return("Capture has not enough accel")
+	}
+
         #Zeroing time to the initial acceleration sample
         time = totalTime - totalTime[trimmingSamples$start]
         #Zeroing position to the initial acceleration sample
         position = position - position[trimmingSamples$start]
-        data = data.frame(time = time[trimmingSamples$start:trimmingSamples$end], speed = speed[trimmingSamples$start:trimmingSamples$end])
+        
+        #generating an initial speed of zero
+        #1. Find the line defined by the two first samples
+        #2. Look for the cross with the X axis.
+        #3. X of the cross is the time whe need to add to all the samples
+
+        timeBefore = speed[trimmingSamples$start] * ((time[trimmingSamples$start + 1]) / (speed[trimmingSamples$start + 1] - speed[trimmingSamples$start]))
+        time = time + timeBefore
+        data = data.frame(time = c(0,time[trimmingSamples$start:trimmingSamples$end]), speed = c(0,speed[trimmingSamples$start:trimmingSamples$end]))
         #print(data)
         
         print("Trying nls")
@@ -149,16 +206,16 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         print(paste("longEnough:", longEnough))
         print(paste("regressionDone:", regression$regressionDone))
         
-        if (!regression$regressionDone)
+        if (! regression$regressionDone)
         {
                 print("NLS regression problem")
-                plot(totalTime, speed, type = "l",
+                plot(totalTime[2:length(totalTime)], speed, type = "l",
                      #ylim = c(min(speed), testLength)*1.05,
                      xlab = "Time (s)", ylab = "Speed (m/s)")
                 #abline(h = testLength, lty = 2)
                 # text(x = (totalTime[length(totalTime)] + totalTime[1])/2,
                 #      y = testLength,
-                #      labels = (paste("Configured test length :", testLength, "m", sep = "")),
+                #      labels = (paste("Configured test length :", testLength, " m", sep = "")),
                 #      pos = 3)
                 text(x = (totalTime[length(totalTime)] + totalTime[1])/2, max(speed) /2,
                      labels = "The graph doesn't seem a sprint", cex = 2, pos = 3)
@@ -173,12 +230,27 @@ getSprintFromEncoder <- function(filename, testLength, Mass, Temperature = 25, H
         return(list(Vmax = Vmax, K = K,
                     time = time, rawPosition = position, rawSpeed = speed, rawAccel = accel, rawForce = totalForce, rawPower = power,
                     rawVmax = max(speed[trimmingSamples$start:trimmingSamples$end]), rawAmax = max(accel[trimmingSamples$start:trimmingSamples$end]), rawFmax = max(totalForce[trimmingSamples$start:trimmingSamples$end]), rawPmax = max(power[trimmingSamples$start:trimmingSamples$end]),
-                    startSample = trimmingSamples$start, endSample = trimmingSamples$end, testLength = testLength, longEnough = longEnough, regressionDone = regression$regressionDone))
+                    startSample = trimmingSamples$start, endSample = trimmingSamples$end, testLength = testLength, longEnough = longEnough, regressionDone = regression$regressionDone, timeBefore = timeBefore, startAccel = startAccel))
 }
 
-plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title = "Test graph",
-                                  plotRawMeanSpeed = TRUE, plotRawSpeed = TRUE, plotRawAccel = FALSE, plotRawForce = FALSE, plotMeanRawForce = TRUE, plotRawPower = FALSE, plotMeanRawPower = TRUE,
-                                  plotFittedSpeed = TRUE, plotFittedAccel = FALSE, plotFittedForce = FALSE, plotFittedPower = FALSE)
+plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics,
+				  title = "Test graph",
+				  subtitle = "",
+				  triggersOn = "",
+				  triggersOff = "",
+                                  plotRawMeanSpeed = TRUE,
+                                  plotRawSpeed = TRUE,
+				  plotRawAccel = op$plotRawAccel,
+				  plotRawForce = op$plotRawForce,
+                                  plotMeanRawForce = TRUE,
+				  plotRawPower = op$plotRawPower,
+                                  plotMeanRawPower = TRUE,
+                                  plotFittedSpeed = TRUE,
+				  plotFittedAccel = op$plotFittedAccel,
+				  plotFittedForce = op$plotFittedForce,
+				  plotFittedPower = op$plotFittedPower,
+                                  startAccel,
+                                  plotStartDetection = TRUE)
 {
         #Plotting position
         # plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawPosition[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
@@ -187,11 +259,14 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         # abline(v = raceTime)
         # abline(h = sprintRawDynamics$testLength, lty = 3)
         # points(raceTime, sprintRawDynamics$testLength)
-        # mtext(side = 3, at = raceTime, text = paste(sprintRawDynamics$testLength, "m", sep=""))
-        # mtext(side = 1, at = raceTime, text = paste(round(raceTime, digits = 3), "s", sep=""))
+        # mtext(side = 3, at = raceTime, text = paste(sprintRawDynamics$testLength, " m", sep=""))
+        # mtext(side = 1, at = raceTime, text = paste(round(raceTime, digits = 3), " s", sep=""))
 
         print("#######Entering plotSprintFromEncoder###########")
-        par(mar = c(7, 4, 5, 6.5))
+        par(mar = c(4.5, 4.5, 5, 2))
+        print("plotRawAccel")
+        print(plotRawAccel)
+        print(typeof(plotRawAccel))
         
         #Checking that the position reaches at least testLength
         if(max(sprintRawDynamics$rawPosition) < sprintRawDynamics$testLength)
@@ -202,7 +277,7 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                 abline(h = sprintRawDynamics$testLength, lty = 2)
                 text(x = (sprintRawDynamics$time[length(sprintRawDynamics$time)] + sprintRawDynamics$time[1])/2,
                      y = sprintRawDynamics$testLength,
-                     labels = (paste("Configured test length :", sprintRawDynamics$testLength, "m", sep = "")),
+                     labels = (paste("Configured test length :", sprintRawDynamics$testLength, " m", sep = "")),
                      pos = 3)
                 text(x = (sprintRawDynamics$time[length(sprintRawDynamics$time)] + sprintRawDynamics$time[1])/2, sprintRawDynamics$testLength /2,
                      labels = "The capture does not reach the length of the test", cex = 2, pos = 3)
@@ -210,6 +285,31 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                 return("Capture too short")
         }
         
+	ltyRaw = 1;
+	ltyFitted = 2;
+	lwdRaw = 1;
+	lwdFitted = 2;
+        
+        legendText = paste("V max (raw) =", round(sprintRawDynamics$rawVmax, digits = 2), "m/s")
+        legendColor = "black"
+        legendLty = ltyRaw
+        legendLwd = lwdRaw
+        
+        legendText = c(legendText, paste("V max (fitted) =", round(sprintFittedDynamics$Vmax.fitted, digits = 2), "m/s"))
+        legendColor = c(legendColor, "black")
+        legendLty = c(legendLty, ltyFitted)
+        legendLwd = c(legendLwd, lwdFitted)
+        
+        legendText = c(legendText, paste("K =", round(sprintFittedDynamics$K.fitted, digits = 2), "s\u207B\u00B9"))
+        legendColor = c(legendColor, "black")
+        legendLty = c(legendLty, 0)
+        legendLwd = c(legendLwd, 0)
+
+        legendText = c(legendText, paste("\u03C4 =", round(1/sprintFittedDynamics$K.fitted, digits = 2), "s"))
+        legendColor = c(legendColor, "black")
+        legendLty = c(legendLty, 0)
+        legendLwd = c(legendLwd, 0)
+
         #Plotting rawSpeed
         ylimits = c(0, sprintRawDynamics$rawVmax*1.05)
         xlimits =c(0, sprintRawDynamics$time[sprintRawDynamics$endSample]*1.05)
@@ -255,51 +355,74 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         {
                 barplot(height = meanSpeed, width = diff(c(0,splitTime)), space = 0,
                         ylim = ylimits,
-                        main = title, xlab = "Time(s)", ylab = "Speed(m/s)",
+                        xlab = "Time (s)", ylab = "Speed (m/s)",
                         yaxs = "i", xaxs = "i")
+                mtext(title, line = 2.5, cex = 1.5)
+                mtext(subtitle, line = 1)
                 lines(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                       sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample:sprintRawDynamics$endSample])
+                lines(c(0,sprintRawDynamics$time[sprintRawDynamics$startSample]),c(0,sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample]))
+                # points(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
+                #        sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample:sprintRawDynamics$endSample])
+                # abline(v=sprintRawDynamics$time[sprintRawDynamics$startSample])
+                if(plotStartDetection){
+                        points(sprintRawDynamics$time[sprintRawDynamics$startSample], sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample])
+                }
+                print("########")
                 lapTime = diff(c(0, splitTime))
                 textXPos = c(0,splitTime[1:length(splitTime) -1]) + lapTime/2
                 text(textXPos, meanSpeed, round(meanSpeed, digits = 2), pos = 3)
-                text(textXPos, 0, paste(round(lapTime, digits = 3), "s", sep = ""), pos = 3)
+                text(textXPos, 0, paste(round(lapTime, digits = 3), " s", sep = ""), pos = 3)
         } else
         {
                 plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                      sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                      type = "l", lty = 3, ylim = ylimits,
-                     main = title, xlab = "Time(s)", ylab = "Speed(m/s)",
+                     main = title, xlab = "Time (s)", ylab = "Speed (m/s)",
                      yaxs = "i", xaxs = "i")
+                lines(x = c(0,sprintRawDynamics$time[sprintRawDynamics$startSample]), y = c(0,sprintRawDynamics$rawSpeed[sprintRawDynamics$startSample]))
         }
         
         abline(v = splitTime, lty = 3)
-        mtext(side = 3, at = splitTime, text = paste(splitPosition, "m", sep=""))
-        mtext(side = 1, at = splitTime, text = paste(round(splitTime, digits = 3), "s", sep=""))
+        mtext(side = 3, at = splitTime, text = paste(splitPosition, " m", sep=""))
+        mtext(side = 1, at = splitTime, text = paste(round(splitTime, digits = 3), " s", sep=""))
         
-        legendText = paste("Vmax.raw =", round(sprintRawDynamics$rawVmax, digits = 2), "m/s")
-        legendColor = "black"
-
         if (plotFittedSpeed)
         {
                 #Plotting fitted speed
-                lines(sprintFittedDynamics$t.fitted, sprintFittedDynamics$v.fitted, lty = 2)
-                legendText = c(legendText, paste("Vmax.fitted =", round(sprintFittedDynamics$Vmax.fitted, digits = 2), "m/s"))
-                legendColor = c(legendColor, "black")
+                lines(sprintFittedDynamics$t.fitted, sprintFittedDynamics$v.fitted
+                      , lty = 2, lwd = 2
+                      #, col = "green"
+                      )
         }
         
         if (plotRawAccel || plotFittedAccel)
         {
-                ylimits = c(min(sprintRawDynamics$rawAccel[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95, max(c(sprintRawDynamics$rawAmax, sprintFittedDynamics$amax.fitted)*1.05))
+                if(plotRawAccel){
+			ylimits = c(min(sprintRawDynamics$rawAccel[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95, max(c(sprintRawDynamics$rawAmax, sprintFittedDynamics$amax.fitted)*1.05))
+		} else {
+                        ylimits = c(0,sprintFittedDynamics$amax.fitted)
+		}
+
                 if (plotRawAccel)
                 {
                         #Plotting rawAccel
                         par(new = TRUE)
-                        plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawAccel[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
-                             ylim = ylimits, type = "l", col = "magenta",
+                        plot(c(0,sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample]),
+                             c(0,sprintRawDynamics$rawAccel[(sprintRawDynamics$startSample + 0):(sprintRawDynamics$endSample + 0)]),
+                             ylim = ylimits,
+                             type = "l", col = "magenta",
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
-                        legendText = c(legendText, paste("Amax.raw =", round(sprintRawDynamics$rawAmax, digits = 2), "m/s"))
+                        # points(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawAccel[(sprintRawDynamics$startSample + 0):(sprintRawDynamics$endSample + 0)],
+                        #        col = "magenta", cex = 0.5)
+                             
+                        axis(side = 4)
+                        #abline(h=c(0,sprintRawDynamics$startAccel), col = c("magenta", "magenta"), lty = c(1,2))
+                        legendText = c(legendText, paste("A max (raw) =", round(sprintRawDynamics$rawAmax, digits = 2), "m/s"))
                         legendColor = c(legendColor, "magenta")
+			legendLty = c(legendLty, ltyRaw)
+			legendLwd = c(legendLwd, lwdRaw)
                 }
                 
                 if (plotFittedAccel)
@@ -307,19 +430,26 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                         #Plotting rawAccel
                         par(new = TRUE)
                         plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$a.fitted,
-                             ylim = ylimits, type = "l", col = "magenta", lty = 2,
+                             ylim = ylimits, type = "l", col = "magenta", lty = 2, lwd = 2,
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
-                        legendText = c(legendText, paste("Amax.fitted =", round(max(sprintFittedDynamics$amax.fitted), digits = 2), "m/s^2"))
-                        legendColor = c(legendColor, "magenta")
+
+			legendText = c(legendText, paste("A max (fitted) =", round(max(sprintFittedDynamics$amax.fitted), digits = 2), "m/s\u00b2"))
+			legendColor = c(legendColor, "magenta")
+			legendLty = c(legendLty, ltyFitted)
+			legendLwd = c(legendLwd, lwdFitted)
                 }
                 axis(side = 4, col = "magenta")
         }
         
         if(plotRawForce|| plotFittedForce)
         {
-                ylimits = c(min(sprintRawDynamics$rawForce[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95, max(c(sprintRawDynamics$rawFmax, sprintFittedDynamics$fmax.fitted)*1.05))
-                #ylimits = c(0,sprintFittedDynamics$fmax.fitted)
+                if(plotRawForce){
+                        ylimits = c(min(sprintRawDynamics$rawForce[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95, max(c(sprintRawDynamics$rawFmax, sprintFittedDynamics$fmax.fitted)*1.05))
+                } else {
+                        ylimits = c(0,sprintFittedDynamics$fmax.fitted) 
+                }
+                
                 if (plotRawForce)
                 {
                         #Plotting rawForce
@@ -328,20 +458,25 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                              ylim = ylimits, type = "l", col = "blue",
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
-                        legendText = c(legendText, paste("Fmax.raw =", round(sprintRawDynamics$rawFmax, digits = 2), "N"))
+                        legendText = c(legendText, paste("F max (raw) =", round(sprintRawDynamics$rawFmax, digits = 2), "N"))
                         legendColor = c(legendColor, "blue")
+			legendLty = c(legendLty, ltyRaw)
+			legendLwd = c(legendLwd, lwdRaw)
                 }
                 
                 if (plotFittedForce)
                 {
-                        #Plotting rawAccel
+                        #Plotting fittedForce
                         par(new = TRUE)
                         plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$f.fitted,
-                             ylim = ylimits, type = "l", col = "blue", lty = 2,
+                             ylim = ylimits, type = "l", col = "blue", lty = 2, lwd = 2,
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
-                        legendText = c(legendText, paste("Fmax.fitted =", round(sprintFittedDynamics$fmax.fitted, digits = 2), "N"))
-                        legendColor = c(legendColor, "blue")
+
+			legendText = c(legendText, paste("F max (fitted) =", round(sprintFittedDynamics$fmax.fitted, digits = 2), "N"))
+			legendColor = c(legendColor, "blue")
+			legendLty = c(legendLty, ltyFitted)
+			legendLwd = c(legendLwd, lwdFitted)
                 }
                 axis(side = 4, col = "blue", line = 2)
                 print("Mean force from the model")
@@ -369,30 +504,50 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
         
         if(plotRawPower|| plotFittedPower)
         {
-                ylimits = c(min(sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
-                            max(c(sprintRawDynamics$rawPmax, sprintFittedDynamics$pmax.fitted)*1.05))
+		#this 1.075 were 1.05, but sometimes the textg value in top of fitted power got out of boundaries
                 if (plotRawPower)
                 {
-                        #Plotting rawForce
+                        ylimits = c(min(sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample])*0.95,
+                                    max(c(sprintRawDynamics$rawPmax, sprintFittedDynamics$pmax.fitted)*1.075))
+                } else {
+                        ylimits = c(0,sprintFittedDynamics$pmax.fitted*1.075)
+                }
+                if (plotRawPower)
+                {
+                        #Plotting rawPower
                         par(new = TRUE)
                         plot(sprintRawDynamics$time[sprintRawDynamics$startSample:sprintRawDynamics$endSample], sprintRawDynamics$rawPower[sprintRawDynamics$startSample:sprintRawDynamics$endSample],
                              ylim = ylimits, type = "l", col = "red",
                              xlab = "", ylab = "",
                              axes = FALSE, yaxs = "i", xaxs = "i")
-                        legendText = c(legendText, paste("Pmax.raw =", round(sprintRawDynamics$rawPmax, digits = 2), "N"))
+                        legendText = c(legendText, paste("P max (raw) =", round(sprintRawDynamics$rawPmax, digits = 2), "N"))
                         legendColor = c(legendColor, "red")
+			legendLty = c(legendLty, ltyRaw)
+			legendLwd = c(legendLwd, lwdRaw)
                 }
                 
                 if (plotFittedPower)
                 {
-                        #Plotting rawAccel
+                        #Plotting fittedPower
                         par(new = TRUE)
-                        plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$p.fitted,
-                             ylim = ylimits, type = "l", col = "red", lty = 2,
-                             xlab = "", ylab = "",
-                             axes = FALSE, yaxs = "i", xaxs = "i")
-                        legendText = c(legendText, paste("Pmax.fitted =", round(sprintFittedDynamics$pmax.fitted, digits = 2), "N"))
-                        legendColor = c(legendColor, "red")
+                        plot(sprintFittedDynamics$t.fitted, sprintFittedDynamics$p.fitted
+                             , ylim = ylimits , type = "l", col = "red", lty = 2, lwd = 2,
+                             ,xlab = "", ylab = ""
+                             ,axes = FALSE, yaxs = "i", xaxs = "i")
+                        text(x = sprintFittedDynamics$tpmax.fitted, y = sprintFittedDynamics$pmax.fitted
+                             , labels = paste(round(sprintFittedDynamics$pmax.fitted, digits = 2), "W")
+                             , pos = 3
+                             , col = "red")
+                        lines(c(sprintFittedDynamics$tpmax.fitted, sprintFittedDynamics$tpmax.fitted), c(sprintFittedDynamics$pmax.fitted, 0)
+                              , lty = 2, col = "red")
+                        mtext(paste(round(sprintFittedDynamics$tpmax.fitted, digits = 3), "s")
+                              , at = sprintFittedDynamics$tpmax.fitted, side = 1
+                              , col = "red")
+
+			legendText = c(legendText, paste("P max (fitted) =", round(sprintFittedDynamics$pmax.fitted, digits = 2), "W"))
+			legendColor = c(legendColor, "red")
+			legendLty = c(legendLty, ltyFitted)
+			legendLwd = c(legendLwd, lwdFitted)
                 }
                 axis(side = 4, col = "red", line = 4)
         }
@@ -417,32 +572,42 @@ plotSprintFromEncoder <- function(sprintRawDynamics, sprintFittedDynamics, title
                 axis(side = 4, col = "red", line = 4)
         }
 
+	#triggers
+	abline(v=triggersOn, col="green")
+	abline(v=triggersOff, col="red")
+
+
         plotSize = par("usr")
-        legend(x = plotSize[2], y = plotSize[3] + (plotSize[4] - plotSize[3])*0.66,
+        legend(x = plotSize[2], y = plotSize[3] + (plotSize[4] - plotSize[3])*0.25,
                 xjust = 1, yjust = 0.5, cex = 1,
                 legend = legendText,
-                text.col = legendColor)
+                col = legendColor,
+                text.col = legendColor,
+		lty = legendLty,
+		lwd = legendLwd,
+		pch = NA)
 }
 
 #Detecting where the sprint start and stops
-getTrimmingSamples <- function(totalTime, position, speed, accel, testLength)
+getTrimmingSamples <- function(totalTime, position, speed, accel, testLength, startAccel)
 {
         print("#########Entering getTrimmingSamples###########33")
-        #The test starts when the speed is grater than 1
+        #The test starts when the acceleration is greater than startAccel m/s²
         startSample = 0
         startingSample = FALSE
         while(!startingSample & startSample < (length(speed)-2))
         {
                 startSample = startSample +1
-                if(accel[startSample+1] > 5)
+                if(accel[startSample] > startAccel)
                 {
-                        print(paste("accel[", startSample +1 ,"] = ", accel[startSample + 1], sep = ""))
+                        print(paste("accel[", startSample,"] = ", accel[startSample], sep = ""))
                         
-                        #Looking iF after 1 seconds the position has increased  at least 1m.
+                        #Looking if after 1 second the position has increased at least .5m.
                         sampleAfterSecond = which.min(abs(totalTime - (totalTime[startSample] +1)))
                         print(paste("sampleAfterSecond =", sampleAfterSecond))
                         positionAfterSecond = position[sampleAfterSecond]
-                        if(abs(positionAfterSecond - position[startSample]) > 1){
+                        #Checking if the displacement has been at least .5m
+                        if(abs(positionAfterSecond - position[startSample]) > 0.5){
                                 startingSample = TRUE
                         }
                 }
@@ -451,23 +616,23 @@ getTrimmingSamples <- function(totalTime, position, speed, accel, testLength)
         if(startSample == (length(speed) -2))
         {
                 print("No start detected")
-                return()
+		return(list(start = -1, end = -1, errorInStart = TRUE ))
         }
         
         
-        #Going back in the time to find a really slow velocity
-        while(speed[startSample] > 0.5)
-        {
-                startSample = startSample -1
-                
-                #If the sprint doesn't start at a null speed, the first sample is used
-                #In old versions of RaceAnalyzer it was possible to start with a high speed.
-                if(startSample == 0)
-                {
-                        startSample = 1
-                        break
-                }
-        }
+        # #Going back in the time to find a really slow velocity
+        # while(speed[startSample] > 1)
+        # {
+        #         startSample = startSample -1
+        #         
+        #         #If the sprint doesn't start at a null speed, the first sample is used
+        #         #In old versions of RaceAnalyzer it was possible to start with a high speed.
+        #         if(startSample == 0)
+        #         {
+        #                 startSample = 1
+        #                 break
+        #         }
+        # }
         
         #Zeroing time to the initial acceleration sample
         totalTime = totalTime - totalTime[startSample]
@@ -480,6 +645,7 @@ getTrimmingSamples <- function(totalTime, position, speed, accel, testLength)
                 endSample = endSample +1
         return(list(start = startSample, end = endSample, errorInStart = !startingSample ))
 }
+
 tryNLS <- function(data){
         print("#######Entering tryNLS#########")
         tryCatch (
@@ -488,7 +654,11 @@ tryNLS <- function(data){
                                     start = list(Vmax = max(data[,"speed"]), K = 1), control=nls.control(warnOnly=TRUE))
                         # print("model:")
                         # print(model)
-                        return(list(regressionDone = TRUE, model = model))
+                        if (! model$convInfo$isConv){
+                                return(list(regressionDone = FALSE, model = model))
+                        } else {
+                                return(list(regressionDone = TRUE, model = model))
+                        }
                 }, 
                 error=function(cond)
                 { 
@@ -498,21 +668,38 @@ tryNLS <- function(data){
         )
 }
 
-testEncoderCJ <- function(filename, testLength, mass, personHeight, tempC)
+testEncoderCJ <- function(filename, testLength, mass, personHeight, tempC, startAccel)
 {
-        sprintRawDynamics = getSprintFromEncoder(filename, testLength, op$mass, op$tempC, op$personHeight)
+        sprintRawDynamics = getSprintFromEncoder(filename, testLength, op$mass, op$tempC, op$personHeight, Vw = 0, device = op$device, startAccel)
         # print("sprintRawDynamics:")
         # print(sprintRawDynamics)
         if (sprintRawDynamics$longEnough & sprintRawDynamics$regressionDone)
         {
                 sprintFittedDynamics = getDynamicsFromSprint(K = sprintRawDynamics$K, Vmax = sprintRawDynamics$Vmax, mass, tempC, personHeight)
                 print(paste("K =",sprintFittedDynamics$K.fitted, "Vmax =", sprintFittedDynamics$Vmax.fitted))
-                plotSprintFromEncoder(sprintRawDynamic = sprintRawDynamics, sprintFittedDynamics = sprintFittedDynamics, title = "Testing graph")
+                plotSprintFromEncoder(sprintRawDynamic = sprintRawDynamics, sprintFittedDynamics = sprintFittedDynamics,
+                                      title = op$title,
+                                      subtitle = op$datetime,
+				      triggersOn = op$triggersOnList,
+				      triggersOff = op$triggersOffList,
+                                      plotRawMeanSpeed = TRUE,
+                                      plotRawSpeed = TRUE,
+                                      plotRawAccel = op$plotRawAccel,
+                                      plotRawForce = op$plotRawForce,
+                                      plotMeanRawForce = FALSE,
+                                      plotRawPower = op$plotRawPower,
+                                      plotMeanRawPower = FALSE,
+                                      plotFittedSpeed = TRUE,
+                                      plotFittedAccel = op$plotFittedAccel,
+                                      plotFittedForce = op$plotFittedForce,
+                                      plotFittedPower = op$plotFittedPower,
+				      startAccel,
+                                      plotStartDetection = TRUE)
                 exportSprintDynamics(sprintFittedDynamics)
         } else
-                print("Couldn't calculate the sprint model")
+          print("Couldn't calculate the sprint model")
 }
 
 prepareGraph(op$os, pngFile, op$graphWidth, op$graphHeight)
-testEncoderCJ(op$filename, op$testLength, op$mass, op$personHeight, op$tempC)
+testEncoderCJ(op$filename, op$testLength, op$mass, op$personHeight, op$tempC, op$startAccel)
 endGraph()
