@@ -1,6 +1,4 @@
 /*
- * Copyright (C) 2017  Xavier de Blas <xaviblas@gmail.com>
- *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
  * the Free Software Foundation; either version 2 of the License, or
@@ -14,6 +12,8 @@
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
  * Foundation, Inc., 59 Temple Place - Suite 330, Boston, MA 02111-1307, USA.
+ *
+ * Copyright (C) 2017-2020  Xavier de Blas <xaviblas@gmail.com>
  */
 
 using System;
@@ -40,6 +40,8 @@ public class RFID
 	private Gtk.Button fakeButtonReopenDialog;
 	private Gtk.Button fakeButtonDisconnected;
 
+	private string lastRFID;
+
 	public RFID(string portName)
 	{
 		this.portName = portName;
@@ -61,7 +63,7 @@ public class RFID
 		 */
 		//List<string> l = getPorts(false);
 		
-		string lastRFID = "";
+		lastRFID = "";
 		string str = "";
 		DateTime dtWaitingLastTimeAdminDetected = new DateTime(); //to be able to detect other person after the AdminDetected
 
@@ -143,6 +145,12 @@ public class RFID
 		this.adminRFID = adminRFID;
 	}
 
+	//reset lastRFID in order to be able to use that RFID after capture (if same wristband is used again)
+	public void ResetLastRFID()
+	{
+		lastRFID = "";
+	}
+
 	private bool findRFIDPort(List<string> l)
 	{
 		foreach(string p in l)
