@@ -1,4 +1,5 @@
 #!/usr/bin/env python3
+# -*- coding: utf-8 -*-
 
 import argparse
 import logging
@@ -11,6 +12,9 @@ import re
 
 logging.basicConfig(level=logging.INFO)
 
+DEBUGTOFILE = False
+debugFile = ""
+
 """
 /*
  * This file is part of ChronoJump
@@ -30,7 +34,13 @@ logging.basicConfig(level=logging.INFO)
  * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
  * Copyright (C) 2016-2017 Carles Pina i Estany <carles@pina.cat>
- * Copyright (C) 2019 Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2019-2020 Xavier de Blas <xaviblas@gmail.com>
+ */
+"""
+
+"""
+/*
+ * note there is a diagram on diagrams/processes/import
  */
 """
 
@@ -278,12 +288,12 @@ class Database:
         suffix = re.match("(.*) \(([0-9]+)\)", value)
 
         if suffix is None:
-            return "{} (1)".format(value)
+            return u"{} (1)".format(value)
         else:
             base_name = suffix.group(1)
             counter = int(suffix.group(2))
             counter += 1
-            return "{} ({})".format(base_name, counter)
+            return u"{} ({})".format(base_name, counter)
 
     @staticmethod
     def _add_prefix(list_of_elements, prefix):
@@ -370,11 +380,15 @@ class Database:
 
     def _execute_query_and_log(self, sql, where_values):
         logging.debug("SQL: {} - values: {}".format(sql, where_values))
+        if(DEBUGTOFILE):
+                debugFile.write("\n")
+                debugFile.write("SQL: {} - values: {}".format(sql, where_values))
+
         self._cursor.execute(sql, where_values)
 
 
 class ImportSession:
-    def __init__(self, source_path, destination_path, source_base_directory):
+    def __init__(self, source_path, destination_path, source_base_directory, source_temp_directory):
         """ Creates the object to import the session source_session from source_db into destination_db. """
 
         logging.debug("source path:" + source_path)
@@ -383,6 +397,7 @@ class ImportSession:
         self.source_path = source_path
         self.destination_path = destination_path
         self.source_base_directory = source_base_directory
+        self.source_temp_directory = source_temp_directory
 
         self.source_db = Database(source_path, read_only=True)
         self.destination_db = Database(destination_path, read_only=False)
@@ -413,7 +428,15 @@ class ImportSession:
         self._import_jumps()
         self._import_runs()
         self._import_pulse()
-        self._import_encoder()
+        trigger = self._import_encoder()
+        self._import_forceSensor()
+        triggerRunEncoder = self._import_runEncoder()
+
+        trigger.concatenate_table(triggerRunEncoder)
+        trigger.remove_duplicates()
+        self.destination_db.write(table=trigger, matches_columns=None)
+
+        self._print_status(self, "allData")
 
     def _import_session(self):
         """
@@ -462,6 +485,8 @@ class ImportSession:
 
 
     def _import_persons77(self):
+        self._print_status(self, "persons")
+
         persons77 = self.source_db.read(table_name="Person77",
                                         where_condition="personSession77.sessionID={}".format(self.source_session),
                                         join_clause="LEFT JOIN personSession77 ON personSession77.personID=Person77.uniqueID",
@@ -473,6 +498,7 @@ class ImportSession:
         return persons77
 
     def _import_jumps(self):
+        self._print_status(self, "jumps")
         # Imports JumpType table
         jump_types = self.source_db.read(table_name="JumpType",
                                          where_condition="Session.uniqueID={}".format(self.source_session),
@@ -501,7 +527,7 @@ class ImportSession:
         jump_rj.update_session_ids(self.new_session_id)
         jump_rj.update_ids("type", jump_rj, "old_name", "new_name")
 
-        self.destination_db.write(table=jump_rj, matches_columns=self.destination_db.column_names("JumpRj", skip_columns=["uniqueID", "personID", "sessionID"]))
+        self.destination_db.write(table=jump_rj, matches_columns=self.destination_db.column_names("JumpRj", skip_columns=["uniqueID", "personID"]))
 
         # Imports Jump table (with the new Person77's uniqueIDs)
         jump = self.source_db.read(table_name="Jump",
@@ -514,10 +540,11 @@ class ImportSession:
         self.destination_db.write(table=jump, matches_columns=self.destination_db.column_names("Jump", skip_columns=["uniqueID", "personID"]))
 
     def _import_runs(self):
+        self._print_status(self, "runs")
         # Imports RunTypes table
         run_types = self.source_db.read(table_name="RunType",
-                                        where_condition="Run.sessionID={}".format(self.source_session),
-                                        join_clause="LEFT JOIN Run ON RunType.name=Run.type",
+                                        where_condition="Session.uniqueID={}".format(self.source_session),
+                                        join_clause="LEFT JOIN Run ON RunType.name=Run.type LEFT JOIN Session ON Run.sessionID=Session.uniqueID",
                                         group_by_clause="RunType.uniqueID")
 
         self.destination_db.write(table=run_types,
@@ -526,12 +553,12 @@ class ImportSession:
 
         # Imports RunIntervalTypes table
         run_interval_types = self.source_db.read(table_name="RunIntervalType",
-                                                 where_condition="RunInterval.sessionID={}".format(self.source_session),
-                                                 join_clause="LEFT JOIN RunInterval ON RunIntervalType.name=RunInterval.type",
+                                                 where_condition="Session.uniqueID={}".format(self.source_session),
+                                                 join_clause="LEFT JOIN RunInterval ON RunIntervalType.name=RunInterval.type LEFT JOIN Session on RunInterval.sessionID=Session.uniqueID",
                                                  group_by_clause="RunIntervalType.uniqueID")
 
         self.destination_db.write(table=run_interval_types,
-                                  matches_columns=self.destination_db.column_names("RunIntervalType", skip_columns=["uniqueID"]),
+                                  matches_columns=self.destination_db.column_names("RunIntervalType", ["uniqueID"]),
                                   avoids_duplicate_column="name")
 
         # Imports Run table (with the new Person77's uniqueIDs)
@@ -541,7 +568,7 @@ class ImportSession:
         run.update_session_ids(self.new_session_id)
         run.update_ids("type", run_types, "old_name", "new_name")
         self.destination_db.write(table=run,
-                                  matches_columns=self.destination_db.column_names("Run", skip_columns=["uniqueID", "personID", "sessionID"]))
+                                  matches_columns=self.destination_db.column_names("Run", skip_columns=["uniqueID", "personID"]))
 
         # Imports RunInterval table (with the new Person77's uniqueIDs)
         run_interval = self.source_db.read(table_name="RunInterval",
@@ -550,9 +577,10 @@ class ImportSession:
         run_interval.update_session_ids(self.new_session_id)
         run_interval.update_ids("type", run_interval_types, "old_name", "new_name")
         self.destination_db.write(table=run_interval,
-                                  matches_columns=self.destination_db.column_names("RunInterval", skip_columns=["uniqueID", "personID", "sessionID"]))
+                                  matches_columns=self.destination_db.column_names("RunInterval", skip_columns=["uniqueID", "personID"]))
 
     def _import_pulse(self):
+        #self._print_status(self, "pulses")
         # Imports PulseTypes table
         pulse_types = self.source_db.read(table_name="PulseType",
                                           where_condition="Session.uniqueID={}".format(self.source_session),
@@ -568,7 +596,7 @@ class ImportSession:
                                     where_condition="Pulse.sessionID={}".format(self.source_session))
         pulse.update_session_ids(self.new_session_id)
         pulse.update_ids("type", pulse_types, "old_name", "new_name")
-        self.destination_db.write(pulse, self.destination_db.column_names("Pulse", skip_columns=["uniqueID", "personID", "sessionID"]))
+        self.destination_db.write(pulse, self.destination_db.column_names("Pulse", skip_columns=["uniqueID", "personID"]))
 
     def _import_person_session77(self):
         # Imports PersonSession77
@@ -582,6 +610,7 @@ class ImportSession:
         self.destination_db.write(table=person_session_77, matches_columns=["sessionID", "personID"])
 
     def _import_encoder(self):
+        self._print_status(self, "encoder")
         # Imports EncoderExercise
         encoder_exercise_from_encoder = self.source_db.read(table_name="EncoderExercise",
                                                where_condition="Encoder.sessionID={}".format(self.source_session),
@@ -621,7 +650,7 @@ class ImportSession:
         self._import_encoder_files(encoder)
 
         self.destination_db.write(table=encoder,
-                                  matches_columns=self.destination_db.column_names("encoder", skip_columns=["uniqueID", "personID", "sessionID", "exerciseID"]))
+                                  matches_columns=self.destination_db.column_names("encoder", skip_columns=["uniqueID", "personID", "exerciseID"]))
 
         # Imports EncoderSignalCurve
         encoder_signal_curve_signals = self.source_db.read(table_name="EncoderSignalCurve",
@@ -652,6 +681,95 @@ class ImportSession:
                                   avoids_duplicate_column=None,
                                   matches_columns=None)
 
+        # Imports trigger (can be encoder, forceSensor or raceanalyzer. Right now force sensor is not programmed)
+        trigger = self.source_db.read(table_name="trigger",
+                                      where_condition="mode='ENCODER' AND Encoder.sessionID={}".format(self.source_session),
+                                      join_clause="LEFT JOIN Encoder ON Encoder.uniqueID=trigger.modeID")
+
+        trigger.update_ids("modeID", encoder, "uniqueID", "new_uniqueID")
+        return trigger #to be concatenated and written after forceSensor and runEncoder
+
+
+    def _import_forceSensor(self):
+        self._print_status(self, "forceSensor")
+        # Imports ForceSensorExercise
+        # based on encoder exercise code because rest of the code exercises and tests are linked by names
+        # but on encoder and forceSensor is linked by ex.uniqueID
+
+        if(DEBUGTOFILE):
+            debugFile.write(" start _import_forceSensor\n")
+
+        forceSensor_exercise = self.source_db.read(table_name="ForceSensorExercise",
+                where_condition="ForceSensor.sessionID={}".format(self.source_session),
+                join_clause="LEFT JOIN ForceSensor ON ForceSensor.exerciseID=ForceSensorExercise.uniqueID",
+                group_by_clause="ForceSensorExercise.uniqueID")
+
+
+        self.destination_db.write(table=forceSensor_exercise,
+                                  matches_columns=self.destination_db.column_names("ForceSensorExercise", ["uniqueID"]))
+
+
+        # Imports ForceSensor
+        forceSensor = self.source_db.read(table_name="ForceSensor",
+                                      where_condition="ForceSensor.sessionID={}".format(self.source_session))
+        forceSensor.update_ids("personID", self.persons77, "uniqueID", "new_uniqueID")
+        forceSensor.update_ids("exerciseID", forceSensor_exercise, "uniqueID", "new_uniqueID")
+        forceSensor.update_session_ids(self.new_session_id)
+
+
+        self._import_forceSensor_or_runEncoder_files(forceSensor, "forceSensor")
+
+        self.destination_db.write(table=forceSensor,
+                                  matches_columns=self.destination_db.column_names("forceSensor", skip_columns=["uniqueID", "personID", "exerciseID"]))
+
+        if(DEBUGTOFILE):
+            debugFile.write(" end _import_forceSensor\n")
+
+    def _import_runEncoder(self):
+        self._print_status(self, "runEncoder")
+        # Imports RunEncoderExercise
+        # VERY similar to _import_runEncoder
+
+        if(DEBUGTOFILE):
+            debugFile.write(" start _import_runEncoder\n")
+
+        runEncoder_exercise = self.source_db.read(table_name="RunEncoderExercise",
+                where_condition="RunEncoder.sessionID={}".format(self.source_session),
+                join_clause="LEFT JOIN RunEncoder ON RunEncoder.exerciseID=RunEncoderExercise.uniqueID",
+                group_by_clause="RunEncoderExercise.uniqueID")
+
+
+        self.destination_db.write(table=runEncoder_exercise,
+                                  matches_columns=self.destination_db.column_names("RunEncoderExercise", ["uniqueID"]))
+
+
+        # Imports RunEncoder
+        runEncoder = self.source_db.read(table_name="RunEncoder",
+                                      where_condition="RunEncoder.sessionID={}".format(self.source_session))
+        runEncoder.update_ids("personID", self.persons77, "uniqueID", "new_uniqueID")
+        runEncoder.update_ids("exerciseID", runEncoder_exercise, "uniqueID", "new_uniqueID")
+        runEncoder.update_session_ids(self.new_session_id)
+
+
+        self._import_forceSensor_or_runEncoder_files(runEncoder, "runEncoder")
+
+        self.destination_db.write(table=runEncoder,
+                                  matches_columns=self.destination_db.column_names("runEncoder", skip_columns=["uniqueID", "personID", "exerciseID"]))
+
+        # Imports trigger (can be encoder, forceSensor or raceanalyzer. Right now force sensor is not programmed)
+        trigger = self.source_db.read(table_name="trigger",
+                where_condition="mode='RACEANALYZER' AND RunEncoder.sessionID={}".format(self.source_session),
+                join_clause="LEFT JOIN RunEncoder ON RunEncoder.uniqueID=trigger.modeID")
+
+        trigger.update_ids("modeID", runEncoder, "uniqueID", "new_uniqueID")
+        return trigger
+
+
+        if(DEBUGTOFILE):
+            debugFile.write(" end _import_runEncoder\n")
+
+
+
     @staticmethod
     def _encoder_filename(person_id, original_filename):
         """ original_filename is like 1-Carmelo-89-2014-12-03_12-48-54.txt. It only replaces the person_id (1 in this case)"""
@@ -663,6 +781,34 @@ class ImportSession:
     def _encoder_url(session_id, signal_or_curve):
         return os.path.join("encoder", str(session_id), "data", signal_or_curve)
 
+    @staticmethod
+    def _forceSensor_filename(person_id, original_filename):
+        """ original_filename is like 19_some person_2019-05-26_15-09-25.csv. It only replaces the person_id (1 in this case)"""
+        """ but as we originally do not have database for forceSensor and runEncoder, we just have written the name, in this case: add the id before"""
+        pattern = '\A\d+_' #\A for the beginning of the file, then digits and then the _
+        result = re.match(pattern, original_filename)
+        if result:
+            filename = original_filename.split("_", 1)
+            filename[0] = str(person_id)
+            return "_".join(filename)
+        else:
+            return str(person_id) + "_" + original_filename
+
+    @staticmethod
+    def _forceSensor_url(session_id):
+        return os.path.join("forceSensor", str(session_id))
+
+    @staticmethod
+    def _runEncoder_filename(person_id, original_filename):
+        """ original_filename is like 1-Carmelo-89-2014-12-03_12-48-54.csv. It only replaces the person_id (1 in this case)"""
+        filename=original_filename.split("-", 1)
+        filename[0] = str(person_id)
+        return "-".join(filename)
+
+    @staticmethod
+    def _runEncoder_url(session_id):
+        return os.path.join("raceAnalyzer", str(session_id))
+
     @staticmethod
     def _normalize_path(path):
         """
@@ -679,6 +825,27 @@ class ImportSession:
         elif os.sep == "\\":
             return path.replace("/", "\\")
 
+    @staticmethod
+    def _print_status(self, name):
+        statusPath = self._normalize_path(self.source_temp_directory + "/status/")
+        if not os.path.exists(statusPath):
+            os.makedirs(statusPath)
+        open(statusPath + name + ".txt", 'a').close()
+
+    @staticmethod
+    def _fix_strange_chars(name):
+        """
+        check if there are ñ and change to ñ or backwards.
+        yes, these characters are different,
+        copy on browser url to see differences.
+        """
+        if "ñ" in name:
+            name = name.replace("ñ", "ñ")
+        elif "ñ" in name:
+            name = name.replace("ñ", "ñ")
+
+        return name
+
     def _import_encoder_files(self, encoder_table):
         if self.source_base_directory is None:
             # We are skipping to copy the Encoding files. This is used in unit tests.
@@ -710,7 +877,20 @@ class ImportSession:
             if not os.path.isdir(destination_directory):
                 os.makedirs(destination_directory)
 
-            shutil.copy(source_file, destination_filename)
+            """
+            if sys.version_info >= (3, 0):
+                print ("python 3")
+            else:
+                print ("python 2")
+            """
+
+            if os.path.exists(source_file):
+                shutil.copy(source_file, destination_filename)
+            else:
+                source_file = self._fix_strange_chars(source_file)
+                if os.path.exists(source_file):
+                    shutil.copy(source_file, destination_filename)
+
 
             # If on origin there are no curves, curve folder will not be created
             # and after import curves will not be saved on clicking at capture treeview
@@ -721,6 +901,63 @@ class ImportSession:
             if not os.path.isdir(destination_directory):
                 os.makedirs(destination_directory)
 
+    # valid for forceSensor and runEncoder files, theses are the values on tableName
+    def _import_forceSensor_or_runEncoder_files(self, table, tableName):
+        if self.source_temp_directory is None:
+            # We are skipping to copy the Encoding files. This is used in unit tests.
+            return
+
+        if(DEBUGTOFILE):
+            debugFile.write(" at import_forceSensor_or_runEncoder_files\n")
+            debugFile.write(tableName)
+
+        for row in table:
+            #if(DEBUGTOFILE):
+            #    debugFile.write(" row: ")
+            #    debugFile.write(row.get("url"))
+
+            # Gets information from row
+            person_id = row.get("personID")
+            original_filename = row.get("filename")
+            original_url = self._normalize_path(row.get("url"))
+            session_id = row.get("sessionID")
+
+            if(DEBUGTOFILE):
+                debugFile.write("original_filename: " + original_filename.encode('utf-8') + "\n")
+
+            # Prepares the new filename and destination_url
+            filename = ""
+            destionation_url = ""
+            if tableName == "forceSensor":
+                filename=self._forceSensor_filename(person_id, original_filename)
+                destination_url = self._forceSensor_url(session_id)
+            else:
+                filename=self._runEncoder_filename(person_id, original_filename)
+                destination_url = self._runEncoder_url(session_id)
+
+            # Sets it to the row
+            row.set("filename", filename)
+            row.set("url", destination_url)
+
+            if(DEBUGTOFILE):
+                debugFile.write("filename: " + filename.encode('utf-8') + "\n")
+
+            # Copies the files to the new place
+            destination_directory = os.path.join(self.destination_path, "..", "..", destination_url)
+            destination_directory = os.path.abspath(destination_directory)  # os.makedirs() can't handle directories with ".."
+
+            destination_filename = os.path.join(destination_directory, filename)
+            source_file = os.path.join(self.source_temp_directory, original_url, original_filename)
+
+            if not os.path.isdir(destination_directory):
+                os.makedirs(destination_directory)
+
+            if os.path.exists(source_file):
+                shutil.copy(source_file, destination_filename)
+            else:
+                source_file = self._fix_strange_chars(source_file)
+                if os.path.exists(source_file):
+                    shutil.copy(source_file, destination_filename)
 
 
 def json_information(database_path):
@@ -761,6 +998,9 @@ def process_command_line():
     parser.add_argument("--source_base_directory", type=str, required=False,
                         help="Directory where the encoder/ directory (amongst database/, logs/ and multimedia/ can be found\n" +
                              "By default is parent as --source")
+    parser.add_argument("--source_temp_directory", type=str, required=False,
+                        help="Directory where the temp forceSensor and runAnalyzer files are\n" +
+                             "they are at temp folder because name have been changed")
     parser.add_argument("--destination", type=str, required=False,
                         help="chronojump.sqlite that we import to")
     parser.add_argument("--source_session", type=int, required=False,
@@ -771,6 +1011,8 @@ def process_command_line():
                              "new session.")
     parser.add_argument("--json_information", required=False, action='store_true',
                         help="Shows information of the source database")
+    parser.add_argument("--debug_to_file", type=str, required=False,
+                        help="path to print debug info to file")
     args = parser.parse_args()
 
     if args.json_information:
@@ -782,12 +1024,24 @@ def process_command_line():
             else:
                 source_base_directory = os.path.join(args.source, "../..")
 
-            importer = ImportSession(args.source, args.destination, source_base_directory)
+            # to use the global variable on this function
+            global DEBUGTOFILE
+            global debugFile
+            if args.debug_to_file == "NONE":
+                DEBUGTOFILE = False
+            elif args.debug_to_file != "":
+                DEBUGTOFILE = True
+                debugFile = open(args.debug_to_file, 'w')
+
+            importer = ImportSession(args.source, args.destination, source_base_directory, args.source_temp_directory)
 
             if args.destination_session is None:
                 importer.import_as_new_session(args.source_session)
             else:
                 importer.import_into_session(args.source_session, args.destination_session)
+
+            if(DEBUGTOFILE):
+                debugFile.close()
         else:
             print("if --information not used --source, --destination and --source_session parameters are required")
 
