@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2019   Xavier de Blas <xaviblas@gmail.com>
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com>
  */
 
 
@@ -38,6 +38,7 @@ public class ChronoJump
 	
 	private static string progVersion = ""; //now in "version" file
 	private static string progName = "Chronojump";
+	private static UtilAll.OperatingSystems operatingSystem;
 	
 	private string runningFileName; //useful for knowing if there are two chronojump instances
 	private string messageToShowOnBoot = "";
@@ -77,6 +78,12 @@ public class ChronoJump
 
 		var envPath = Environment.GetEnvironmentVariable ("PATH");
 		var rBinPath = "";
+
+		//record GetOsEnum on variables to not call it all the time
+		operatingSystem = UtilAll.GetOSEnum();
+		Util.operatingSystem = operatingSystem;
+
+		//we need to set Util.operatingSytem before GetPrefixDir()
 		baseDirectory = Util.GetPrefixDir();
 
 		/*
@@ -113,7 +120,7 @@ public class ChronoJump
 			Environment.SetEnvironmentVariable ("R_HOME", baseDirectory);
 			LogB.Information("R_HOME:", baseDirectory);
 		} else {
-			switch (UtilAll.GetOSEnum()) {
+			switch (operatingSystem) {
 				case UtilAll.OperatingSystems.MACOSX:
 					LogB.Information(Environment.GetEnvironmentVariable("R_HOME"));
 					rBinPath = "/Library/Frameworks/R.Framework/Libraries";
@@ -123,11 +130,13 @@ public class ChronoJump
 					LogB.Information(Environment.GetEnvironmentVariable("R_HOME"));
 					LogB.Information(Environment.GetEnvironmentVariable("PATH"));
 
-					//Gstreamer stuff
+					/*
+					//Gstreamer stuff (right now not used, we used ffplay)
 					string prefix="/Applications/Chronojump.app/Contents/Home/";
 					Environment.SetEnvironmentVariable ("GST_PLUGIN_PATH", prefix + "lib/gstreamer-0.10");
 					Environment.SetEnvironmentVariable ("GST_PLUGIN_SYSTEM_PATH", prefix + "lib/gstreamer-0.10");
 					Environment.SetEnvironmentVariable ("GST_PLUGIN_SCANNER_PATH", prefix + "lib/gstreamer-0.10/gst-plugin-scanner");
+					*/
 					break;
 				case UtilAll.OperatingSystems.LINUX:
 					rBinPath = @"/usr/lib/R/lib";
@@ -272,7 +281,7 @@ public class ChronoJump
 		//to store (encoder, force sensor, run encoder) data and graphs
 		UtilEncoder.CreateEncoderDirIfNeeded();
 		Util.CreateForceSensorDirIfNeeded();
-		Util.CreateRaceAnalyzerDirIfNeeded();
+		Util.CreateRunEncoderDirIfNeeded();
 
 //TODO: when a session is deleted, encoder data has to be deleted, also multimedia videos, I suppose. Show message to user warning about it
 //TODO: encoder weight auto written depending on person loaded, and changes if it changes person or weight
@@ -373,6 +382,8 @@ public class ChronoJump
 				messageToShowOnBoot += Catalog.GetString("All DJ jumps have been renamed as 'DJna' (Drop Jumps with No Arms).") + "\n\n"+ 
 					Catalog.GetString("If your Drop Jumps were executed using the arms, please rename them manually as 'DJa'.") + "\n";
 
+			Sqlite.UpdatingDBFrom = Sqlite.UpdatingDBFromEnum.LOCAL;
+
 			bool softwareIsNew = Sqlite.ConvertToLastChronojumpDBVersion();
 			updatingDB = false;
 			
@@ -405,7 +416,7 @@ public class ChronoJump
 
 		//connect to server to Ping
 		versionAvailable = "";
-		versionAvailable = Constants.ServerOffline;
+		versionAvailable = Constants.ServerOfflineStr();
 	
 
 		//doing ping using json methods
@@ -431,7 +442,7 @@ public class ChronoJump
 //TODO: fix this to the new code
 
 		string versionAvailableKnown = SqlitePreferences.Select("versionAvailable", true);
-		if( versionAvailable != Constants.ServerOffline && new Version(versionAvailable) > new Version(progVersion) ) {
+		if( versionAvailable != Constants.ServerOfflineStr() && new Version(versionAvailable) > new Version(progVersion) ) {
 			//check if available version is higher than known available version
 			Version versionAvailableAsV = new Version(versionAvailable);
 
@@ -494,7 +505,7 @@ public class ChronoJump
 	}
 
 	private void on_find_version_cancelled(object o, EventArgs args) {
-		versionAvailable = Constants.ServerOffline;
+		versionAvailable = Constants.ServerOfflineStr();
 		//pingEnd = true;
 	}
 
@@ -572,11 +583,11 @@ public class ChronoJump
 		LogB.SQL("all SQL done! starting Chronojump");
 
 		string topMessage = "";
-		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.LINUX && ! linuxUserHasDialout())
+		if(operatingSystem == UtilAll.OperatingSystems.LINUX && ! linuxUserHasDialout())
 			topMessage = Catalog.GetString("Need dialout permissions to read from device.") + "\n" +
 				Catalog.GetString("Check software page on Chronojump website");
 
-		bool showCameraStop = (ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutableCapture(UtilAll.GetOSEnum())));
+		bool showCameraStop = (ExecuteProcess.IsRunning3 (-1, WebcamFfmpeg.GetExecutableCapture(operatingSystem)));
 
 		new ChronoJumpWindow(progVersion, progName, runningFileName, splashWin, sendLog, messageToShowOnBoot, topMessage, showCameraStop);
 	}
@@ -719,10 +730,11 @@ public class ChronoJump
 					Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "chronojump.db");
 		}
 
-		messageCrashedBefore = "\n" +
-			string.Format(Catalog.GetString("Chronojump {0} crashed before."), progVersion) + "\n\n" +
-			Catalog.GetString("Please, fill your email and click on 'Send error log' in order to fix this fast and contact you if appropriate.") + "\n\n" +
-			Catalog.GetString("Your help is needed.") + "\n";
+		string sendErrorLogStr = Catalog.GetString("Send error log");
+		messageCrashedBefore =
+			string.Format(Catalog.GetString("Chronojump {0} crashed before."), BuildInfo.chronojumpVersion) + "\n" +
+			string.Format(Catalog.GetString("Please, fill your email and click on '{0}' in order to fix this fast and contact you if appropriate."), sendErrorLogStr) + "\n" +
+			Catalog.GetString("Your help is needed.");
 
 
 		//messageCrashedBefore += "\n" + Catalog.GetString("Experimental webcam record has been disabled.") + "\n";
