@@ -1,6 +1,6 @@
 /*
  * Copyright (C) 2005  Juan Gonzalez Gomez
- * Copyright (C) 2014-2016  Xavier de Blas <xaviblas@gmail.com>
+ * Copyright (C) 2014-2017  Xavier de Blas <xaviblas@gmail.com>
  *
  * This program is free software; you can redistribute it and/or modify
  * it under the terms of the GNU General Public License as published by
@@ -314,10 +314,21 @@ public class Chronopic {
 				try {
 					n = sp.Read(respuesta,count,5-count);
 					LogB.Warning("respuesta = ");
-					LogB.Warning(respuesta.ToString());
+					LogB.Warning(respuesta[count].ToString());
 					count+=n;
 					success = true;
-				} catch {}
+				} catch {
+					//LogB.Warning("catched at Read_cambio");
+					//if cancel is clicked, cancellingTest will be true. Stop reading
+					//same for finish and finishingTest
+					if(cancellingTest || finishingTest)
+					{
+						//-- Wait a bit and empty buffer
+						Thread.Sleep(ErrorTimeout);
+						this.flushByTimeOut();
+						return false;
+					}
+				}
 			} while (!success);
 		} while (count<5 && n!=-1);
 
@@ -348,6 +359,32 @@ public class Chronopic {
 
 	public bool AbortFlush;	
 
+	//Used by two threads
+	private static bool cancellingTest;
+	public static void CancelDo()
+	{
+		cancellingTest = true;
+	}
+	private static bool finishingTest;
+	public static void FinishDo()
+	{
+		finishingTest = true;
+	}
+
+	/*
+	   on <= 1.6.2 we could have this problem with static variables:
+	   on thread 1 finishingTest is marked as true
+	   just at the moment on thread 2 read_event is called and read_cambio is called and finishingTest = false
+	   so thread 2 does not end
+	   solution is to not define finishingTest on read_cambio
+	   define it on the beginning and will affect both chronopics
+	   */
+	public static void InitCancelAndFinish()
+	{
+		cancellingTest = false;
+		finishingTest = false;
+	}
+
 	//-- Vaciar buffer de entrada
 	//-- De momento se hace leyendo muchos datos y descartando
 	private void flush()
@@ -489,7 +526,7 @@ public class ChronopicInit
 				LogB.Information("chronopicInit-4");		
 				do {
 					LogB.Information("chronopicInit-5");		
-					ok=myCp.Read_platform(out myPS);
+					ok = myCp.Read_platform(out myPS);
 					LogB.Information("chronopicInit-6");		
 				} while(! ok && ! CancelledByUser);
 				LogB.Information("chronopicInit-7");		
@@ -505,28 +542,8 @@ public class ChronopicInit
 			myCp = new Chronopic(); //fake constructor
 		}
 		
-		bool connected = false;
 		returnString = "";
-		if(success) {
-			if(currentCp == 1)
-				connected = true;
-			returnString = string.Format(Catalog.GetString("<b>Connected</b> to Chronopic on port: {0}"), myPort);
-		}
-		else {
-			returnString = Catalog.GetString("Problems communicating to chronopic.");
-			if(currentCp == 1) {
-				returnString += " " + Catalog.GetString("Changed platform to 'Simulated'");
-				returnString += Catalog.GetString("\n\nWe recommend to remove and connect USB cable.");
-			}
-
-			//this will raise on_radiobutton_simulated_ativate and 
-			//will put cpRunning to false, and simulated to true and cp.Close()
-			if(currentCp == 1) {
-				connected = false;
-			}
-		}
-
-		return connected;
+		return success;
 	}
 	
 }
