@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -247,7 +247,10 @@ public class EncoderCurve
 	public string MeanForce;
 	public string MaxForce;
 	public string MaxForceT;
-	
+	public string MaxForce_MaxForceT;
+	public string WorkJ;
+	public string Impulse;
+
 	public EncoderCurve () {
 	}
 
@@ -257,7 +260,9 @@ public class EncoderCurve
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
 			string PP_PPT,
-			string meanForce, string maxForce, string maxForceT
+			string meanForce, string maxForce, string maxForceT,
+			string maxForce_maxForceT,
+			string workJ, string impulse
 			)
 	{
 		this.Record = record;
@@ -275,6 +280,9 @@ public class EncoderCurve
 		this.MeanForce = meanForce;
 		this.MaxForce = maxForce;
 		this.MaxForceT = maxForceT;
+		this.MaxForce_MaxForceT = maxForce_maxForceT;
+		this.WorkJ = workJ;
+		this.Impulse = impulse;
 	}
 
 	//used on TreeView analyze
@@ -286,7 +294,9 @@ public class EncoderCurve
 			string meanSpeed, string maxSpeed, string maxSpeedT,
 			string meanPower, string peakPower, string peakPowerT, 
 			string PP_PPT,
-			string meanForce, string maxForce, string maxForceT)
+			string meanForce, string maxForce, string maxForceT,
+			string maxForce_maxForceT,
+			string workJ, string impulse)
 	{
 		this.N = n;
 		this.Series = series;
@@ -308,6 +318,34 @@ public class EncoderCurve
 		this.MeanForce = meanForce;
 		this.MaxForce = maxForce;
 		this.MaxForceT = maxForceT;
+		this.MaxForce_MaxForceT = maxForce_maxForceT;
+		this.WorkJ = workJ;
+		this.Impulse = impulse;
+	}
+
+	public EncoderCurve Copy()
+	{
+		EncoderCurve curveCopy = new EncoderCurve(Record, N,
+				Start, Duration, Height,
+				MeanSpeed, MaxSpeed, MaxSpeedT,
+				MeanPower, PeakPower, PeakPowerT,
+				PP_PPT,
+				MeanForce, MaxForce, MaxForceT,
+				MaxForce_MaxForceT,
+				WorkJ, Impulse);
+		return curveCopy;
+	}
+
+	//used on FindPosOfBestN
+	public void ZeroAll ()
+	{
+		Height = "0";
+		MeanSpeed = "0";
+		MaxSpeed = "0";
+		MeanPower = "0";
+		PeakPower = "0";
+		MeanForce = "0";
+		MaxForce = "0";
 	}
 
 	//http://stackoverflow.com/questions/894263/how-to-identify-if-a-string-is-a-number
@@ -340,6 +378,18 @@ public class EncoderCurve
 
 		return false;
 	}
+
+	//note this only works if IsNumberNandEorC()
+	public Preferences.EncoderPhasesEnum GetPhaseEnum()
+	{
+		char lastChar = N[N.Length-1];
+		if(lastChar == 'e')
+			return Preferences.EncoderPhasesEnum.ECC;
+		else
+			return Preferences.EncoderPhasesEnum.CON;
+	}
+
+
 	//at least for RenderNAnalyze
 	public bool IsValidN() {
 		if (N == "MAX" || N == "AVG" || N == "SD" || IsNumberN() || IsNumberNandEorC())
@@ -368,24 +418,39 @@ public class EncoderCurve
 		}
 	}
 
-	public string ToCSV(bool captureOrAnalyze, string decimalSeparator) {
-
+	//ecChar adds an 'e', 'c' or nothing to N
+	//if e or c then N will be /2
+	public string ToCSV (bool captureOrAnalyze, string decimalSeparator, bool useWorkKcal, string ecChar)
+	{
 		//latin:	2,3 ; 2,5
 		//non-latin:	2.3 , 2.5
 
 		string sep = ":::";
+
+		double work = WorkJD;
+		if(useWorkKcal)
+			work = WorkKcalD;
 		
 		string str = "";
 		//TODO: if capture not shown because some variables like Inertia are not defined
 		if(! captureOrAnalyze)
+		{
+			string nprint = N;
+			if(ecChar == "e" || ecChar == "c")
+				nprint = decimal.Truncate((Convert.ToInt32(nprint) +1) /2).ToString() + ecChar;
+
 			str = 
-				N + sep + Series + sep + Exercise + sep + Laterality + sep +
+				nprint + sep +
+				Series + sep + Exercise + sep + Laterality + sep +
 				ExtraWeight + sep + DisplacedWeight + sep + Inertia + sep + 
 				Start + sep + Duration + sep + Height + sep + 
 				MeanSpeed + sep + MaxSpeed + sep + MaxSpeedT + sep + 
 				MeanPower + sep + PeakPower + sep + PeakPowerT + sep + 
 				PP_PPT + sep +
-				MeanForce + sep + MaxForce + sep + MaxForceT;
+				MeanForce + sep + MaxForce + sep + MaxForceT + sep +
+				MaxForce_MaxForceT + sep +
+				work.ToString() + sep + Impulse;
+		}
 		
 		if(decimalSeparator == "COMMA")
 			str = Util.ConvertToComma(str);
@@ -405,6 +470,8 @@ public class EncoderCurve
 	public double MeanForceD { get { return Convert.ToDouble(MeanForce); } }
 	public double MaxForceD  { get { return Convert.ToDouble(MaxForce);  } }
 
+	public double WorkJD  { get { return Convert.ToDouble(WorkJ);  } }
+	public double WorkKcalD  { get { return Convert.ToDouble(WorkJ) * 0.000239006;  } }
 	
 	~EncoderCurve() {}
 }
@@ -415,10 +482,13 @@ public class EncoderSignal
 {
 	private ArrayList curves;
 
+	// constructor ----
+
 	public EncoderSignal (ArrayList curves) {
 		this.curves = curves;
 	}
 
+
 	public int CurvesNum() {
 		return curves.Count;
 	}
@@ -432,9 +502,11 @@ public class EncoderSignal
 		
 		foreach(EncoderCurve curve in curves) 
 		{
-			if(i >= start && curve.GetParameter(variable) > bestValue) {
+			if(i >= start && curve.GetParameter(variable) > bestValue)
+			{
 				bestValue = curve.GetParameter(variable);
 				bestValuePos = i;
+				//LogB.Information(string.Format("bestValue: {0}; bestValuePos: {1}", bestValue, bestValuePos));
 			}
 
 			i++;
@@ -472,6 +544,106 @@ public class EncoderSignal
 		return bestValuePos;
 	}
 
+	public enum Contraction { EC, C };
+	public List<int> FindPosOfBestN(int start, string variable, int n, Contraction eccon)
+	{
+		//1) find how many values to return
+		//size of list will be n or the related curves if it is smaller
+		if(curves.Count - start < n)
+			n = curves.Count - start;
+
+		//2) make a copy of curves and have a new EncoderSignal to work with
+		ArrayList curvesCopy = new ArrayList();
+		foreach(EncoderCurve curve in curves)
+			curvesCopy.Add(curve.Copy());
+		EncoderSignal es = new EncoderSignal(curvesCopy);
+
+		//3) find the best values and fill listOfPos
+		List<int> listOfPos = new List<int>(n);
+		int posOfBest = -1;
+		int count = 0;
+
+		while(count < n)
+		{
+			if(posOfBest >= 0)
+			{
+				//curves.RemoveAt(posOfBest); //do not do it because it is difficult to know pos of next values, just zero that curve
+				((EncoderCurve) curvesCopy[posOfBest]).ZeroAll();
+				if(eccon == Contraction.EC)
+					((EncoderCurve) curvesCopy[posOfBest+1]).ZeroAll();
+			}
+
+			if(eccon == Contraction.C)
+				posOfBest = es.FindPosOfBest(start, variable);
+			else //(eccon == Contraction.EC)
+				posOfBest = es.FindPosOfBestEccCon(start, variable);
+
+			listOfPos.Add(posOfBest);
+			count ++;
+		}
+		return listOfPos;
+	}
+
+	//TODO: do also for ecc-con
+	//returns the pos of the first one of the consecutive rows
+	public int FindPosOfBestNConsecutive(int start, string variable, int n)
+	{
+		//2) find the best values and fill listOfPos
+		double bestValue = 0;
+		int bestValuePos = -1;
+		int count = start;
+
+		while(count <= curves.Count - n)
+		{
+			double sum = 0;
+			for(int i = count; i < count + n; i ++)
+			{
+				sum += ((EncoderCurve) curves[i]).GetParameter(variable);
+			}
+			LogB.Information("sum: " + sum.ToString());
+			if (sum > bestValue)
+			{
+				bestValue = sum;
+				bestValuePos = count;
+				LogB.Information(string.Format("bestValue: {0}, bestValuePos: {1}", bestValue, bestValuePos));
+			}
+
+			count ++;
+		}
+		return bestValuePos;
+	}
+	public int FindPosOfBestNConsecutiveEccCon(int start, string variable, int n)
+	{
+		//2) find the best values and fill listOfPos
+		double bestValue = 0;
+		int bestValuePos = -1;
+		int count = start;
+
+		n *= 2;
+		while(count <= curves.Count - n)
+		{
+			double sum = 0;
+			for(int i = count; i < count + n; i += 2)
+			{
+				double eccValue = ((EncoderCurve) curves[i]).GetParameter(variable);
+				double conValue = ((EncoderCurve) curves[i+1]).GetParameter(variable);
+				sum += (eccValue + conValue) / 2;
+				LogB.Information(string.Format("eccValue: {0}, conValue: {1}, accumulated sum: {2}", eccValue, conValue, sum));
+			}
+			LogB.Information("total sum: " + sum.ToString());
+			if (sum > bestValue)
+			{
+				bestValue = sum;
+				bestValuePos = count;
+				LogB.Information(string.Format("bestValue: {0}, bestValuePos: {1}", bestValue, bestValuePos));
+			}
+
+			count += 2;
+		}
+		return bestValuePos;
+	}
+
+
 	public double GetEccConMean(int eccPos, string variable)
 	{
 		return(
@@ -496,15 +668,17 @@ public class EncoderSignal
 	{
 		double lowest = 100000;
 		double highest = 0;
+		int highestPos = 0;
 		double eccValue = 0;
 		double conValue = 0;
 		bool ecc = true;
-		//int i = 0;
+		int i = 0;
 		foreach (EncoderCurve curve in curves)
 		{
 			if(ecc)
 			{
 				ecc = false;
+				i++;
 				continue;
 			}
 
@@ -512,18 +686,25 @@ public class EncoderSignal
 			if(variable == Constants.MeanPower)
 				compareTo = curve.MeanPowerD;
 
+			bool needChangeLowest = false;
 			conValue = compareTo;
 			if(compareTo > highest)
+			{
 				highest = compareTo;
-			if(compareTo < lowest)
+				highestPos = i;
+				needChangeLowest = true; 	//min rep has to be after max
+			} if(needChangeLowest || (compareTo < lowest &&
+						((EncoderCurve) curves[i]).GetParameter(Constants.Range) >= .7 * ((EncoderCurve) curves[highestPos]).GetParameter(Constants.Range)
+						))
 				lowest = compareTo;
 
 			//LogB.Information(string.Format("Loss ecc/con (by con) of {0}; i: {1} is: {2}", variable, i++,
-			//			Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest))));
+			//			Convert.ToInt32(UtilAll.DivideSafe(100.0 * (highest - lowest), highest))));
 
+			i++;
 			ecc = true;
 		}
-		return Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest));
+		return Convert.ToInt32(UtilAll.DivideSafe(100.0 * (highest - lowest), highest));
 
 	}
 	/*
@@ -554,11 +735,11 @@ public class EncoderSignal
 					lowest = (eccValue + conValue) / 2;
 			}
 			//LogB.Information(string.Format("Loss ecc/con (ecc?: {0}) of {1}; i: {2} is: {3}", ecc.ToString(), variable, i++,
-			//			Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest))));
+			//			Convert.ToInt32(UtilAll.DivideSafe(100.0 * (highest - lowest), highest))));
 
 			ecc = ! ecc;
 		}
-		return Convert.ToInt32(Util.DivideSafe(100.0 * (highest - lowest), highest));
+		return Convert.ToInt32(UtilAll.DivideSafe(100.0 * (highest - lowest), highest));
 
 	}
 	*/
@@ -568,7 +749,8 @@ public class EncoderSignal
 
 
 //related to encoderSignalCurve table
-public class EncoderSignalCurve {
+public class EncoderSignalCurve
+{
 	public int uniqueID;
 	public int signalID;
 	public int curveID;
@@ -759,7 +941,7 @@ public class EncoderSQL
 		this.status = status;
 		this.videoURL = videoURL;
 		this.encoderConfiguration = encoderConfiguration;
-		this.future1 = future1;	//on curves: meanPower. Better use alter table
+		this.future1 = future1;	//on curves: meanPower
 		this.future2 = future2; //on curves: meanSpeed
 		this.future3 = future3; //on curves: meanForce
 		this.exerciseName = exerciseName;
@@ -800,14 +982,15 @@ public class EncoderSQL
 	}
 
 	//showMeanPower is used in curves, but not in signal
-	public string [] ToStringArray (int count, bool checkboxes, bool video, bool encoderConfigPretty, bool showMeanPower) {
+	public string [] ToStringArray (int count, bool checkboxes, bool video, bool encoderConfigPretty, bool showMeanPSF)
+	{
 		int all = 9;
 		if(checkboxes)
 			all ++;
 		if(video)
 			all++;
-		if(showMeanPower)
-			all++;
+		if(showMeanPSF)
+			all += 3;
 
 
 		string [] str = new String [all];
@@ -822,9 +1005,22 @@ public class EncoderSQL
 		str[i++] = Catalog.GetString(laterality);
 		str[i++] = extraWeight;
 		
-		if(showMeanPower)
+		if(showMeanPSF)
+		{
 			str[i++] = future1;
 
+			//as recording meanSpeed and meanForce is new on 2.0, show a blank cell instead of a 0
+			if(future2 == "0")
+				str[i++] = "";
+			else
+				str[i++] = future2;
+
+			if(future3 == "0")
+				str[i++] = "";
+			else
+				str[i++] = future3;
+		}
+
 		if(encoderConfigPretty)
 			str[i++] = encoderConfiguration.ToStringPretty();
 		else
@@ -914,8 +1110,6 @@ public class EncoderSQL
 		return lateralityOptionsEnglish[0];
 	}
 
-
-
 	//used in NUnit
 	public string Filename
 	{
@@ -1016,6 +1210,8 @@ public class EncoderExercise
 		this.speed1RM = speed1RM;
 	}
 
+	/*
+	 * unused, on 1.9.1 all encoder exercises can be deleted
 	public bool IsPredefined() {
 		if(
 				name == "Bench press" ||
@@ -1028,6 +1224,7 @@ public class EncoderExercise
 		else 
 			return false;
 	}
+	*/
 
 	public override string ToString()
 	{
@@ -1035,6 +1232,31 @@ public class EncoderExercise
 			ressistance + "," + description + "," + speed1RM.ToString();
 	}
 
+	public int UniqueID
+	{
+		get { return uniqueID; }
+	}
+	public string Name
+	{
+		get { return name; }
+	}
+	public int PercentBodyWeight
+	{
+		get { return percentBodyWeight; }
+	}
+	public string Ressistance
+	{
+		get { return ressistance; }
+	}
+	public string Description
+	{
+		get { return description; }
+	}
+	public double Speed1RM
+	{
+		get { return speed1RM; }
+	}
+
 	~EncoderExercise() {}
 }
 
@@ -1129,7 +1351,9 @@ public class EncoderCaptureCurveArray
 	~EncoderCaptureCurveArray() {}
 }
 
-public class EncoderBarsData {
+public class EncoderBarsData
+{
+	public double Range;
 	public double MeanSpeed;
 	public double MaxSpeed;
 	public double MeanForce;
@@ -1137,7 +1361,9 @@ public class EncoderBarsData {
 	public double MeanPower;
 	public double PeakPower;
 	
-	public EncoderBarsData(double meanSpeed, double maxSpeed, double meanForce, double maxForce, double meanPower, double peakPower) {
+	public EncoderBarsData(double range, double meanSpeed, double maxSpeed, double meanForce, double maxForce, double meanPower, double peakPower)
+	{
+		this.Range = range;
 		this.MeanSpeed = meanSpeed;
 		this.MaxSpeed  = maxSpeed;
 		this.MeanForce = meanForce;
@@ -1146,8 +1372,13 @@ public class EncoderBarsData {
 		this.PeakPower = peakPower;
 	}
 
-	public double GetValue (string option) {
-		if(option == Constants.MeanSpeed)
+	public double GetValue (string option)
+	{
+		//if(option == Constants.Range)
+		//	return Range;
+		if(option == Constants.RangeAbsolute)
+			return Math.Abs(Range);
+		else if(option == Constants.MeanSpeed)
 			return MeanSpeed;
 		else if(option == Constants.MaxSpeed)
 			return MaxSpeed;
@@ -1695,6 +1926,11 @@ public class EncoderConfiguration
 		inertiaTotal = UtilEncoder.CalculeInertiaTotal(this);
 	}
 
+	public bool Equals(EncoderConfiguration other)
+	{
+		return (this.ToStringOutput(Outputs.SQL) == other.ToStringOutput(Outputs.SQL));
+	}
+
 	public void ReadParamsFromSQL (string [] strFull) 
 	{
 		//adds other params
