@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -66,8 +66,6 @@ public class EventExecute
 	protected string feedbackMessage;
 	protected bool needShowFeedbackMessage;
 
-	public bool WebcamStarted;
-
 	//instances with the info to create
 	public PrepareEventGraphJumpSimple PrepareEventGraphJumpSimpleObject; 
 	public PrepareEventGraphJumpReactive PrepareEventGraphJumpReactiveObject;
@@ -81,6 +79,9 @@ public class EventExecute
 	
 	protected bool volumeOn;
 	protected Preferences.GstreamerTypes gstreamer;
+	protected int graphLimit;
+	protected bool graphAllTypes;
+	protected bool graphAllPersons;
 	protected double progressbarLimit;
 	protected RepetitiveConditionsWindow repetitiveConditionsWin;
 
@@ -634,7 +635,7 @@ public class PhaseTime
 			strMode = "OUT (TF)";
 
 		//TODO: use a printf mode to have always same digits
-		return "\n" + Math.Round(Util.DivideSafe(duration, 1000.0), 3) + " - " + strMode;
+		return "\n" + Math.Round(UtilAll.DivideSafe(duration, 1000.0), 3) + " - " + strMode;
 	}
 
 	public bool IsContact
