@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -49,6 +49,7 @@ public class JumpExecute : EventExecute
 
 	private int angle = -1;
 	private bool avoidGraph;
+	private bool jumpsDjGraphHeights;
 	
 	public JumpExecute() {
 	}
@@ -58,7 +59,8 @@ public class JumpExecute : EventExecute
 			Chronopic cp, Gtk.Window app, int pDN,
 			bool volumeOn, Preferences.GstreamerTypes gstreamer,
 			double progressbarLimit, ExecutingGraphData egd, string description,
-			bool avoidGraph //on configChronojump.Exhibition do not show graph because it gets too slow with big database
+			bool avoidGraph, //on configChronojump.Exhibition do not show graph because it gets too slow with big database
+			bool jumpsDjGraphHeights, int graphLimit, bool graphAllTypes, bool graphAllPersons
 			)
 	{
 		this.personID = personID;
@@ -78,6 +80,10 @@ public class JumpExecute : EventExecute
 		this.egd = egd;
 		this.description = description;
 		this.avoidGraph = avoidGraph;
+		this.jumpsDjGraphHeights = jumpsDjGraphHeights;
+		this.graphLimit = graphLimit;
+		this.graphAllTypes = graphAllTypes;
+		this.graphAllPersons = graphAllPersons;
 	
 		if(TypeHasFall) {
 			hasFall = true;
@@ -148,7 +154,7 @@ public class JumpExecute : EventExecute
 			//mark now that we have leaved platform:
 			if (simulated)
 				platformState = Chronopic.Plataforma.OFF;
-			
+
 			//start thread
 			thread = new Thread(new ThreadStart(waitEvent));
 			GLib.Idle.Add (new GLib.IdleHandler (PulseGTK));
@@ -458,24 +464,33 @@ public class JumpExecute : EventExecute
 		}
 		*/
 		if(simulated)
-			feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
+			feedbackMessage = Catalog.GetString(Constants.SimulatedMessage());
 		else
 			feedbackMessage = "";
 		needShowFeedbackMessage = true; 
 		
 		string table = Constants.JumpTable;
+		string datetime = UtilDate.ToFile(DateTime.Now);
 
 		uniqueID = SqliteJump.Insert(false, table, "NULL", personID, sessionID, 
 				type, tv, tc, fall,  //type, tv, tc, fall
-				weight, description, angle, Util.BoolToNegativeInt(simulated));
+				weight, description, angle, Util.BoolToNegativeInt(simulated),
+				datetime);
 
 		//define the created object
 		eventDone = new Jump(uniqueID, personID, sessionID, type, tv, tc, fall, 
-				weight, description, angle, Util.BoolToNegativeInt(simulated)); 
+				weight, description, angle, Util.BoolToNegativeInt(simulated), datetime);
 
 		if(! avoidGraph)
 		{
-			PrepareEventGraphJumpSimpleObject = new PrepareEventGraphJumpSimple(tv, tc, sessionID, personID, table, type);
+			if(graphAllTypes)
+				type = "";
+
+			PrepareEventGraphJumpSimpleObject = new PrepareEventGraphJumpSimple(
+					tv, tc, sessionID,
+					personID, graphAllPersons, graphLimit,
+					table, type, jumpsDjGraphHeights);
+
 			needUpdateGraphType = eventType.JUMP;
 			needUpdateGraph = true;
 		}
@@ -1029,6 +1044,7 @@ public class JumpRjExecute : JumpExecute
 				*/
 		}
 
+		string datetime = UtilDate.ToFile(DateTime.Now);
 
 		if(tempTable) 
 			SqliteJumpRj.Insert(false, Constants.TempJumpRjTable, "NULL", personID, sessionID, 
@@ -1036,19 +1052,19 @@ public class JumpRjExecute : JumpExecute
 					fall, weight, description,
 					Util.GetAverage(tvString), Util.GetAverage(tcString),
 					tvString, tcString,
-					jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated)
-					);
+					jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated),
+					datetime);
 		else {
 			uniqueID = SqliteJumpRj.Insert(false, Constants.JumpRjTable, "NULL", personID, sessionID, 
 					type, Util.GetMax(tvString), Util.GetMax(tcString), 
 					fall, weight, description,
 					Util.GetAverage(tvString), Util.GetAverage(tcString),
 					tvString, tcString,
-					jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated)
-					);
+					jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated),
+					datetime);
 
 			//define the created object
-			eventDone = new JumpRj(uniqueID, personID, sessionID, type, tvString, tcString, fall, weight, description, jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated)); 
+			eventDone = new JumpRj(uniqueID, personID, sessionID, type, tvString, tcString, fall, weight, description, jumps, Util.GetTotalTime(tcString, tvString), limitString, angleString, Util.BoolToNegativeInt(simulated), datetime);
 
 
 			//event will be raised, and managed in chronojump.cs
@@ -1061,7 +1077,7 @@ public class JumpRjExecute : JumpExecute
 				" " + Catalog.GetString("AVG TC") + ": " + Util.TrimDecimals( Util.GetAverage (tcString).ToString(), pDN ) ;
 			*/
 			if(simulated)
-				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage);
+				feedbackMessage = Catalog.GetString(Constants.SimulatedMessage());
 			else
 				feedbackMessage = "";
 			needShowFeedbackMessage = true; 
