@@ -29,12 +29,10 @@ public class About
 	[Widget] Gtk.Image image_logo;
 	[Widget] Gtk.Label dialog_about_label_version;
 	
-	[Widget] Gtk.Label dialog_about_label_developers_CEO;
 	[Widget] Gtk.Label dialog_about_label_developers_software;
+	[Widget] Gtk.Label dialog_about_label_developers_networks;
 	[Widget] Gtk.Label dialog_about_label_developers_chronopic;
-	[Widget] Gtk.Label dialog_about_label_developers_devices;
-	[Widget] Gtk.Label dialog_about_label_developers_math;
-	[Widget] Gtk.Label dialog_about_label_developers_opencv;
+	[Widget] Gtk.Label dialog_about_label_developers_scientific;
 
 	[Widget] Gtk.Label dialog_about_label_documenters;
 	[Widget] Gtk.Label dialog_about_label_translators;
@@ -68,17 +66,15 @@ public class About
 		dialog_about.ModifyBg(StateType.Normal, new Gdk.Color(0xff,0xff,0xff));
 		
 		//put authors
-		textLabel(Constants.AuthorsCEO, dialog_about_label_developers_CEO);
-		textLabel(Constants.AuthorsSoftware, dialog_about_label_developers_software);
-		textLabel(Constants.AuthorsChronopic, dialog_about_label_developers_chronopic);
-		textLabel(Constants.AuthorsDevices, dialog_about_label_developers_devices);
-		textLabel(Constants.AuthorsMath, dialog_about_label_developers_math);
-		textLabel(Constants.AuthorsOpenCV, dialog_about_label_developers_opencv);
+		textLabel(Constants.Authors(Constants.AuthorsEnum.SOFTWARE), dialog_about_label_developers_software);
+		textLabel(Constants.Authors(Constants.AuthorsEnum.NETWORKS), dialog_about_label_developers_networks);
+		textLabel(Constants.Authors(Constants.AuthorsEnum.CHRONOPIC), dialog_about_label_developers_chronopic);
+		textLabel(Constants.Authors(Constants.AuthorsEnum.SCIENTIFIC), dialog_about_label_developers_scientific);
 
 		//put documenters separated by commas
 		string docsString = "";
 		string paragraph = "";
-		foreach (string doc in Constants.Documenters) {
+		foreach (string doc in Constants.Authors(Constants.AuthorsEnum.DOCUMENTERS)) {
 			docsString += paragraph;
 			docsString += doc;
 			paragraph = "\n";
