@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -25,6 +25,7 @@ using Glade;
 using GLib; //for Value
 using System.Text; //StringBuilder
 using System.Collections; //ArrayList
+using Mono.Unix;
 
 
 public class ConfirmWindowJumpRun
@@ -43,6 +44,7 @@ public class ConfirmWindowJumpRun
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "confirm_window.glade", "confirm_window", "chronojump");
 		gladeXML.Autoconnect(this);
 		
+		confirm_window.Title = "Chronojump - " + Catalog.GetString("Confirm");
 		//put an icon to window
 		UtilGtk.IconWindow(confirm_window);
 		
@@ -109,6 +111,7 @@ public class ConfirmWindow
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "confirm_window.glade", "confirm_window", null);
 		gladeXML.Autoconnect(this);
 		
+		confirm_window.Title = "Chronojump - " + Catalog.GetString("Confirm");
 		//put an icon to window
 		UtilGtk.IconWindow(confirm_window);
 		
