@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2016-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2016-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -31,11 +31,13 @@ public class DialogPersonPopup
 	[Widget] Gtk.Label label_name;
 	[Widget] Gtk.Image image_person;
 	[Widget] Gtk.Image image_person_logout;
+	[Widget] Gtk.Image image_new_tasks_other_stations;
 	[Widget] Gtk.CheckButton checkbutton_autologout;
 	[Widget] Gtk.Image image_close;
 	[Widget] Gtk.Label label_rfid;
 	[Widget] Gtk.VBox vbox_tasks_parametrized;
 
+	[Widget] Gtk.Label label_network_devices;
 	[Widget] Gtk.Label label_server_connected;
 	[Widget] Gtk.Image image_server_connected_yes;
 	[Widget] Gtk.Image image_server_connected_no;
@@ -56,7 +58,9 @@ public class DialogPersonPopup
 	private bool compujumpDjango;
 
 	public DialogPersonPopup (int personID, string name, string rfid,
-			List<Task> tasks, List<StationCount> stationsCount, bool serverConnected, bool Autologout, bool compujumpDjango)
+			List<Task> tasks, List<StationCount> stationsCount,
+			string networkDevices, bool serverConnected, bool Autologout,
+			bool compujumpDjango, bool compujumpHideTaskDone)
 	{
 		Glade.XML gladeXML;
 		gladeXML = Glade.XML.FromAssembly (Util.GetGladePath() + "dialog_person_popup.glade", "dialog_person_popup", null);
@@ -79,19 +83,22 @@ public class DialogPersonPopup
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "image_person_logout.png");
 		image_person_logout.Pixbuf = pixbuf;
+		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "new.png");
+		image_new_tasks_other_stations.Pixbuf = pixbuf;
 
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "gtk-apply.png");
 		image_server_connected_yes.Pixbuf = pixbuf;
 		pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "gtk-cancel.png");
 		image_server_connected_no.Pixbuf = pixbuf;
 
+		label_network_devices.Text = networkDevices;
 		if(serverConnected)
 		{
 			label_server_connected.Text = "Server is connected";
 			image_server_connected_yes.Visible = true;
 			image_server_connected_no.Visible = false;
 		} else {
-			label_server_connected.Text = Constants.ServerDisconnectedMessage;
+			label_server_connected.Text = Constants.ServerDisconnectedMessage();
 			image_server_connected_yes.Visible = false;
 			image_server_connected_no.Visible = true;
 		}
@@ -162,13 +169,16 @@ public class DialogPersonPopup
 			task_parametrized_exist = true;
 
 			//create button_done (shared on R,L)
-			Gtk.Button button_done = new Gtk.Button("Fet!");
-			button_done.Clicked += new EventHandler(button_done_clicked);
-			hboxRow.PackEnd(button_done, false, false, 0);
-			list_buttons_done.Add(button_done);
-			list_buttons_done_id.Add(t.Id);
-			list_hboxs_row.Add(hboxRow);
+			if(! compujumpHideTaskDone)
+			{
+				Gtk.Button button_done = new Gtk.Button("Fet!");
+				button_done.Clicked += new EventHandler(button_done_clicked);
+				hboxRow.PackEnd(button_done, false, false, 0);
+				list_buttons_done.Add(button_done);
+				list_buttons_done_id.Add(t.Id);
+			}
 
+			list_hboxs_row.Add(hboxRow);
 			vbox_tasks_parametrized.PackStart(hboxRow, false, false, 0);
 		}
 
@@ -192,8 +202,11 @@ public class DialogPersonPopup
 		if(stationsString == "")
 			label_other_stations.Text = "There are no tasks at other stations";
 		else
+		{
 			//label_other_stations.Text = "There are task at this stations:" + "\n\n" + stationsString;
 			label_other_stations.Text = stationsString;
+			image_new_tasks_other_stations.Visible = true;
+		}
 	}
 
 	private Gtk.HBox createHBoxStartAndLabel(Task t, Pixbuf pixbuf)
