@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -189,7 +189,7 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 	{
 		data = SqliteEncoder.Select(
 				false, -1, currentPerson.UniqueID, currentSession.UniqueID, encoderGI,
-				exerciseID, "curve", EncoderSQL.Eccons.ALL, 
+				exerciseID, "curve", EncoderSQL.Eccons.ALL, "",
 				false, true);
 	}
 
@@ -216,6 +216,8 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 			"RL",
 			Catalog.GetString("Extra weight"),
 			Catalog.GetString("Mean Power"),
+			Catalog.GetString("Mean Speed"),
+			Catalog.GetString("Mean Force"),
 			Catalog.GetString("Encoder"),
 			Catalog.GetString("Contraction"),
 			Catalog.GetString("Date"),
@@ -254,10 +256,10 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 				string.Format(Catalog.GetString("Saved repetitions of athlete {0} on this session."), 
 					currentPerson.Name) + "\n" + 
 				Catalog.GetString("Activate the repetitions you want to use clicking on first column.") + "\n" +
-				Catalog.GetString("If you want to edit or delete a row, right click on it.") + "\n",
+				Catalog.GetString("If you want to delete a row, right click on it.") + "\n",
 				bigArray);
 
-		genericWinESR.SetTreeview(columnsString, true, dataPrint, new ArrayList(), Constants.ContextMenu.EDITDELETE, false);
+		genericWinESR.SetTreeview(columnsString, true, dataPrint, new ArrayList(), GenericWindow.EditActions.DELETE, false);
 
 		genericWinESR.ResetComboCheckBoxesOptions();
 		//genericWinESR.AddOptionsToComboCheckBoxesOptions(encoderExercisesNames);
@@ -274,11 +276,6 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 		int count = 0;
 	        foreach	(Person p in personsPre)
 			persons[count++] = p.UniqueID.ToString() + ":" + p.Name;
-		genericWinESR.SetComboValues(persons, currentPerson.UniqueID + ":" + currentPerson.Name);
-		genericWinESR.SetComboLabel(Catalog.GetString("Change the owner of selected repetition") + 
-				" (" + Catalog.GetString("code") + ":" + Catalog.GetString("name") + ")");
-		genericWinESR.ShowEditRow(false);
-		genericWinESR.CommentColumn = 10;
 		
 		genericWinESR.ShowButtonCancel(false);
 		genericWinESR.SetButtonAcceptSensitive(true);
@@ -303,20 +300,12 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 		//manage selected, unselected curves
 		genericWinESR.Button_accept.Clicked -= new EventHandler(on_show_repetitions_done);
 		genericWinESR.Button_accept.Clicked += new EventHandler(on_show_repetitions_done);
-		
-		genericWinESR.Button_row_edit.Clicked -= new EventHandler(on_show_repetitions_row_edit);
-		genericWinESR.Button_row_edit.Clicked += new EventHandler(on_show_repetitions_row_edit);
 
-		genericWinESR.Button_row_edit_apply.Clicked -= new EventHandler(on_show_repetitions_row_edit_apply);
-		genericWinESR.Button_row_edit_apply.Clicked += new EventHandler(on_show_repetitions_row_edit_apply);
-		
 		genericWinESR.Button_row_delete.Clicked -= new EventHandler(on_show_repetitions_row_delete_pre);
 		genericWinESR.Button_row_delete.Clicked += new EventHandler(on_show_repetitions_row_delete_pre);
 	}
 	protected override void removeCallbacks() {
 		genericWinESR.Button_accept.Clicked -= new EventHandler(on_show_repetitions_done);
-		genericWinESR.Button_row_edit.Clicked -= new EventHandler(on_show_repetitions_row_edit);
-		genericWinESR.Button_row_edit_apply.Clicked -= new EventHandler(on_show_repetitions_row_edit_apply);
 		genericWinESR.Button_row_delete.Clicked -= new EventHandler(on_show_repetitions_row_delete_pre);
 	}
 	
@@ -331,7 +320,7 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 
 		ArrayList data = SqliteEncoder.Select(
 				false, -1, currentPerson.UniqueID, currentSession.UniqueID, encoderGI,
-				exerciseID, "curve", EncoderSQL.Eccons.ALL, 
+				exerciseID, "curve", EncoderSQL.Eccons.ALL, "",
 				false, true);
 
 		//update on database the curves that have been selected/deselected
@@ -344,7 +333,10 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 
 
 	// --------------- edit curves start ---------------
-	
+
+	/*
+	 * now cannot change the person who has done some repetitions. better like this.
+	 *
 	protected void on_show_repetitions_row_edit (object o, EventArgs args) {
 		LogB.Information(genericWinESR.TreeviewSelectedUniqueID.ToString());
 		genericWinESR.ShowEditRow(true);
@@ -382,6 +374,7 @@ public class EncoderSelectRepetitionsIndividualCurrentSession : EncoderSelectRep
 		genericWinESR.ShowEditRow(false);
 	}
 	
+	*/
 	// --------------- edit curves end ---------------
 	
 	
@@ -513,7 +506,7 @@ public class EncoderSelectRepetitionsIndividualAllSessions : EncoderSelectRepeti
 			dataConverted.Add(encPS.ToStringArray(true));
 		}
 
-		genericWinESR.SetTreeview(columnsString, true, dataConverted, nonSensitiveRows, Constants.ContextMenu.NONE, false);
+		genericWinESR.SetTreeview(columnsString, true, dataConverted, nonSensitiveRows, GenericWindow.EditActions.NONE, false);
 
 		genericWinESR.ResetComboCheckBoxesOptions();
 		genericWinESR.CreateComboCheckBoxes();
@@ -599,7 +592,7 @@ public class EncoderSelectRepetitionsGroupalCurrentSession : EncoderSelectRepeti
 		foreach(Person p in dataPre) {
 			ArrayList eSQLarray = SqliteEncoder.Select(
 					false, -1, p.UniqueID, currentSession.UniqueID, encoderGI,
-					exerciseID, "curve", EncoderSQL.Eccons.ALL, 
+					exerciseID, "curve", EncoderSQL.Eccons.ALL, "",
 					false, true);
 
 			int allCurves = eSQLarray.Count;
@@ -677,7 +670,7 @@ public class EncoderSelectRepetitionsGroupalCurrentSession : EncoderSelectRepeti
 		genericWinESR = GenericWindow.Show(Catalog.GetString("Persons compare"), false,	//don't show now
 				Catalog.GetString("Select persons to compare"), bigArray);
 
-		genericWinESR.SetTreeview(columnsString, true, data, nonSensitiveRows, Constants.ContextMenu.NONE, false);
+		genericWinESR.SetTreeview(columnsString, true, data, nonSensitiveRows, GenericWindow.EditActions.NONE, false);
 
 		//select this person row
 		genericWinESR.SelectRowWithID(0, currentPerson.UniqueID);
