@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -31,6 +31,7 @@ using Mono.Unix;
 
 public partial class ChronoJumpWindow 
 {
+	[Widget] Gtk.SpinButton spin_encoder_capture_curves_best_n;
 
 	/* TreeView stuff */	
 
@@ -63,6 +64,12 @@ public partial class ChronoJumpWindow
 
 		bool showStartAndDuration = preferences.encoderShowStartAndDuration;
 
+		string workString = Catalog.GetString("Work");
+		if(preferences.encoderWorkKcal)
+			workString += "\n (KCal)";
+		else
+			workString += "\n (J)";
+
 		string [] columnsString = {
 			Catalog.GetString("n") + "\n",
 			Catalog.GetString("Start") + "\n (s)",
@@ -74,10 +81,13 @@ public partial class ChronoJumpWindow
 			"p" + "\n (W)",
 			"pmax" + "\n (W)",
 			"t->pmax" + "\n (s)",
-			"pmax/t->pmax" + "\n (W/s)",
+			"RPD" + "\n (W/s)",
 			"F" + "\n (N)",
 			"Fmax" + "\n (N)",
-			"t->Fmax" + "\n (s)"
+			"t->Fmax" + "\n (s)",
+			"RFD" + "\n (N/s)",
+			workString,
+			Catalog.GetString("Impulse") + "\n (N*s)"
 		};
 
 		encoderCaptureCurves = new ArrayList ();
@@ -128,7 +138,9 @@ public partial class ChronoJumpWindow
 						cells[8], cells[9], cells[10], 	//meanSpeed, maxSpeed, maxSpeedT
 						cells[11], cells[12], cells[13],//meanPower, peakPower, peakPowerT
 						cells[14],			//peakPower / peakPowerT
-						cells[15], cells[16], cells[17] //meanForce, maxForce maxForceT
+						cells[15], cells[16], cells[17], //meanForce, maxForce maxForceT
+						cells[18], 			//meanForce / meanForceT
+						cells[19], cells[20] 		//work, impulse
 						));
 
 		}
@@ -144,10 +156,18 @@ public partial class ChronoJumpWindow
 		encoderCaptureListStore = new Gtk.ListStore (typeof (EncoderCurve));
 		
 		repetitiveConditionsWin.ResetBestSetValue(RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK);
-		foreach (EncoderCurve curve in encoderCaptureCurves) {
+		bool eccPhase = true;
+		foreach (EncoderCurve curve in encoderCaptureCurves)
+		{
 			encoderCaptureListStore.AppendValues (curve);
 				
-			repetitiveConditionsWin.UpdateBestSetValue(curve);
+			if( ecconLast == "c" ||
+					preferences.encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.BOTH ||
+					preferences.encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.ECC && eccPhase ||
+					preferences.encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.CON && ! eccPhase )
+				repetitiveConditionsWin.UpdateBestSetValue(curve);
+
+			eccPhase = ! eccPhase;
 		}
 
 		treeview_encoder_capture_curves.Model = encoderCaptureListStore;
@@ -226,6 +246,15 @@ public partial class ChronoJumpWindow
 				case 13:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForceT));
 					break;
+				case 14:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce_maxForceT));
+					break;
+				case 15:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderWork));
+					break;
+				case 16:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderImpulse));
+					break;
 			}
 					
 			if( ! ( (i == 1 || i == 2) && ! showStartAndDuration ) )
@@ -265,6 +294,7 @@ public partial class ChronoJumpWindow
 		}
 	}
 
+	private string encoderCaptureItemToggledArgsPath = "";
 	void EncoderCaptureItemToggled(object o, ToggledArgs args)
 	{
 		//cannot toggle item while capturing or recalculating
@@ -281,11 +311,18 @@ public partial class ChronoJumpWindow
 				inertialStart = 2 * preferences.encoderCaptureInertialDiscardFirstN;
 		}
 
+		string myArgsPath = "";
+		if(encoderCaptureItemToggledArgsPath != "")
+			myArgsPath = encoderCaptureItemToggledArgsPath;
+		else
+			myArgsPath = args.Path;
+
+		//LogB.Information("myArgsPath: " + myArgsPath);
 		TreeIter iter;
 		int column = 0;
-		if (encoderCaptureListStore.GetIterFromString (out iter, args.Path)) 
+		if (encoderCaptureListStore.GetIterFromString (out iter, myArgsPath))
 		{
-			int rowNum = Convert.ToInt32(args.Path); //starts at zero
+			int rowNum = Convert.ToInt32(myArgsPath); //starts at zero
 
 			//do not allow to click a discarded repetition
 			if(rowNum < inertialStart)
@@ -293,7 +330,7 @@ public partial class ChronoJumpWindow
 			
 			//on "ecS" don't pass the 2nd row, pass always the first
 			//then need to move the iter to previous row
-			TreePath path = new TreePath(args.Path);
+			TreePath path = new TreePath(myArgsPath);
 			if(ecconLast != "c" && ! Util.IsEven(rowNum)) {
 				rowNum --;
 				path.Prev();
@@ -356,6 +393,8 @@ public partial class ChronoJumpWindow
 	{
 		int bestRow = 0;
 		int numRows = 0;
+		List<int> list_bestN = new List<int>();
+		int bestN = Convert.ToInt32(spin_encoder_capture_curves_best_n.Value);
 
 		int inertialStart = 0;
 		if( current_menuitem_mode == Constants.Menuitem_modes.POWERINERTIAL)
@@ -366,20 +405,40 @@ public partial class ChronoJumpWindow
 				inertialStart = 2 * preferences.encoderCaptureInertialDiscardFirstN;
 		}
 
-		if(saveOption == Constants.EncoderAutoSaveCurve.BEST || saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE) {
+		if(saveOption == Constants.EncoderAutoSaveCurve.BEST ||
+				saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE ||
+				saveOption == Constants.EncoderAutoSaveCurve.BESTN ||
+				saveOption == Constants.EncoderAutoSaveCurve.BESTNCONSECUTIVE)
+		{
 			if(ecconLast == "c") {
 				//get the concentric curves
 				EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.CON));
-				bestRow = encoderSignal.FindPosOfBest(inertialStart, mainVariable);
-				numRows = encoderSignal.CurvesNum();
+
+				if(saveOption == Constants.EncoderAutoSaveCurve.BEST)
+					bestRow = encoderSignal.FindPosOfBest(inertialStart, mainVariable);
+				else if(saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE)
+					numRows = encoderSignal.CurvesNum();
+				else if(saveOption == Constants.EncoderAutoSaveCurve.BESTN)
+					list_bestN = encoderSignal.FindPosOfBestN(inertialStart, mainVariable,
+							bestN, EncoderSignal.Contraction.C);
+				else if(saveOption == Constants.EncoderAutoSaveCurve.BESTNCONSECUTIVE)
+					bestRow = encoderSignal.FindPosOfBestNConsecutive(inertialStart, mainVariable,
+							bestN);
 			} else {
 				EncoderSignal encoderSignal = new EncoderSignal(treeviewEncoderCaptureCurvesGetCurves(AllEccCon.ALL));
-				bestRow = encoderSignal.FindPosOfBestEccCon(inertialStart, mainVariable); //will be pos of the ecc
-				numRows = encoderSignal.CurvesNum();
+				if(saveOption == Constants.EncoderAutoSaveCurve.BEST)
+					bestRow = encoderSignal.FindPosOfBestEccCon(inertialStart, mainVariable); //will be pos of the ecc
+				else if(saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE)
+					numRows = encoderSignal.CurvesNum();
+				else if(saveOption == Constants.EncoderAutoSaveCurve.BESTN)
+					list_bestN = encoderSignal.FindPosOfBestN(inertialStart, mainVariable,
+							bestN, EncoderSignal.Contraction.EC);
+				else if(saveOption == Constants.EncoderAutoSaveCurve.BESTNCONSECUTIVE)
+					bestRow = encoderSignal.FindPosOfBestNConsecutiveEccCon(inertialStart, mainVariable,
+							bestN);
 			}
 		}
 
-
 		int i = 0; //on "c" and ! "c": i is every row
 		string sep = "";
 		string messageRows = "";
@@ -417,8 +476,14 @@ public partial class ChronoJumpWindow
 			if(
 					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.ALL) ||
 					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.BEST && i == bestRow) ||
+					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.BESTN && Util.FoundInListInt(list_bestN, i)) ||
+					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.BESTNCONSECUTIVE &&
+					 i >= bestRow && ( (ecconLast == "c" && i < bestRow + bestN) || (ecconLast != "c" && i < bestRow + 2*bestN) )) ||
 					(! curve.Record && ! thisRowDiscarded && saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE && fromValidToPenult) ||
 					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.BEST && i != bestRow)) ||
+					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.BESTN && ! Util.FoundInListInt(list_bestN, i))) ||
+					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.BESTNCONSECUTIVE && //! (i >= bestRow && i < bestRow + bestN))) ||
+					! (i >= bestRow && ( (ecconLast == "c" && i < bestRow + bestN) || (ecconLast != "c" && i < bestRow + 2*bestN) )))) ||
 					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.NONE)) ||
 					(curve.Record && (thisRowDiscarded || saveOption == Constants.EncoderAutoSaveCurve.FROM4TOPENULTIMATE && ! fromValidToPenult)) )
 			{ 
@@ -534,6 +599,12 @@ public partial class ChronoJumpWindow
 			distanceUnits = "(mm)";
 		}
 
+		string workString = Catalog.GetString("Work");
+		if(preferences.encoderWorkKcal)
+			workString += "\n (KCal)";
+		else
+			workString += "\n (J)";
+
 		string [] treeviewEncoderAnalyzeHeaders = {
 			Catalog.GetString("Repetition") + "\n",
 			Catalog.GetString("Series") + "\n",
@@ -551,10 +622,13 @@ public partial class ChronoJumpWindow
 			"p" + "\n(W)",
 			"pmax" + "\n(W)",
 			"t->pmax" + "\n" + timeUnits,
-			"pmax/t->pmax" + "\n(W/s)",
+			"RPD" + "\n(W/s)",
 			"F" + "\n(N)",
 			"Fmax" + "\n(N)",
-			"t->Fmax" + "\n" + timeUnits
+			"t->Fmax" + "\n" + timeUnits,
+			"RFD" + "\n(N/s)",
+			workString,
+			Catalog.GetString("Impulse") + "\n (N*s)"
 		};
 		return treeviewEncoderAnalyzeHeaders;
 	}
@@ -631,15 +705,17 @@ public partial class ChronoJumpWindow
 							cells[0], 
 							cells[1],	//seriesName 
 							exerciseName,
-							cells[18],	//laterality
-							Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4])),
-							totalMass,
-							Convert.ToInt32(cells[19]),
+							cells[21],	//laterality
+							Convert.ToDouble(Util.ChangeDecimalSeparator(cells[4])), 	//extraWeight
+							totalMass, 							//displaceWeight
+							Convert.ToInt32(cells[22]), 					//inertia
 							cells[5], cells[6], cells[7], 
 							cells[8], cells[9], cells[10], 
 							cells[11], cells[12], cells[13],
 							cells[14],
-							cells[15], cells[16], cells[17] //meanForce, maxSForce maxForceT
+							cells[15], cells[16], cells[17], //meanForce, maxForce maxForceT
+							cells[18],
+							cells[19], cells[20]
 							));
 
 			} while(true);
@@ -648,10 +724,18 @@ public partial class ChronoJumpWindow
 		encoderAnalyzeListStore = new Gtk.ListStore (typeof (EncoderCurve));
 	
 		repetitiveConditionsWin.ResetBestSetValue(RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK);
-		foreach (EncoderCurve curve in encoderAnalyzeCurves) {
+		bool eccPhase = true;
+		foreach (EncoderCurve curve in encoderAnalyzeCurves)
+		{
 			encoderAnalyzeListStore.AppendValues (curve);
-		
-			repetitiveConditionsWin.UpdateBestSetValue(curve);
+
+			if( ecconLast == "c" ||
+					preferences.encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.BOTH ||
+					preferences.encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.ECC && eccPhase ||
+					preferences.encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.CON && ! eccPhase )
+				repetitiveConditionsWin.UpdateBestSetValue(curve);
+
+			eccPhase = ! eccPhase;
 		}
 
 		treeview_encoder_analyze_curves.Model = encoderAnalyzeListStore;
@@ -732,6 +816,15 @@ public partial class ChronoJumpWindow
 				case 19:
 					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForceT));
 					break;
+				case 20:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderMaxForce_maxForceT));
+					break;
+				case 21:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderWork));
+					break;
+				case 22:
+					aColumn.SetCellDataFunc (aCell, new Gtk.TreeCellDataFunc (RenderImpulse));
+					break;
 			}
 			
 			treeview_encoder_analyze_curves.AppendColumn (aColumn);
@@ -920,7 +1013,7 @@ public partial class ChronoJumpWindow
 		//Check if it's number
 		if(! curve.IsNumberN()) {
 			(cell as Gtk.CellRendererText).Text = "";
-			LogB.Error("Curve is not number at RenderN:" + curve.ToCSV(true, "COMMA"));
+			LogB.Error("Curve is not number at RenderN:" + curve.ToCSV(true, "COMMA", preferences.encoderWorkKcal, ""));
 			return;
 		}
 		
@@ -957,7 +1050,7 @@ public partial class ChronoJumpWindow
 		//Check if it's valid
 		if(! curve.IsValidN()) {
 			(cell as Gtk.CellRendererText).Text = "";
-			LogB.Error("Curve is not valid at RenderNAnalyze:" + curve.ToCSV(false, "COMMA"));
+			LogB.Error("Curve is not valid at RenderNAnalyze:" + curve.ToCSV(false, "COMMA", preferences.encoderWorkKcal, ""));
 			return;
 		}
 			
@@ -1113,9 +1206,10 @@ public partial class ChronoJumpWindow
 		if(curve.N == "MAX" || curve.N == "AVG" || curve.N == "SD")
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 		else {
+			Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
 			string myColor = repetitiveConditionsWin.AssignColorAutomatic(
 					RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
-					curve, Constants.MeanSpeed);
+					curve, Constants.MeanSpeed, phaseEnum);
 
 			if(myColor == "")
 				myColor = assignColor(
@@ -1142,9 +1236,10 @@ public partial class ChronoJumpWindow
 		if(curve.N == "MAX" || curve.N == "AVG" || curve.N == "SD")
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 		else {
+			Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
 			string myColor = repetitiveConditionsWin.AssignColorAutomatic(
 					RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
-					curve, Constants.MaxSpeed);
+					curve, Constants.MaxSpeed, phaseEnum);
 
 			if(myColor == "")
 				myColor = assignColor(
@@ -1179,9 +1274,10 @@ public partial class ChronoJumpWindow
 		if(curve.N == "MAX" || curve.N == "AVG" || curve.N == "SD")
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 		else {
+			Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
 			string myColor = repetitiveConditionsWin.AssignColorAutomatic(
 					RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
-					curve, Constants.MeanPower);
+					curve, Constants.MeanPower, phaseEnum);
 
 			if(myColor == "")
 				myColor = assignColor(
@@ -1207,9 +1303,10 @@ public partial class ChronoJumpWindow
 		if(curve.N == "MAX" || curve.N == "AVG" || curve.N == "SD")
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 		else {
+			Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
 			string myColor = repetitiveConditionsWin.AssignColorAutomatic(
 					RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
-					curve, Constants.PeakPower);
+					curve, Constants.PeakPower, phaseEnum);
 
 			if(myColor == "")
 				myColor = assignColor(
@@ -1252,9 +1349,10 @@ public partial class ChronoJumpWindow
 		if(curve.N == "MAX" || curve.N == "AVG" || curve.N == "SD")
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 		else {
+			Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
 			string myColor = repetitiveConditionsWin.AssignColorAutomatic(
 					RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
-					curve, Constants.MeanForce);
+					curve, Constants.MeanForce, phaseEnum);
 
 			if(myColor == "")
 				myColor = assignColor(
@@ -1280,9 +1378,10 @@ public partial class ChronoJumpWindow
 		if(curve.N == "MAX" || curve.N == "AVG" || curve.N == "SD")
 			(cell as Gtk.CellRendererText).Foreground = null;	//will show default color
 		else {
+			Preferences.EncoderPhasesEnum phaseEnum = getEncoderCurvePhaseEnum(curve);
 			string myColor = repetitiveConditionsWin.AssignColorAutomatic(
 					RepetitiveConditionsWindow.BestSetValueEnum.AUTOMATIC_FEEDBACK,
-					curve, Constants.MaxForce);
+					curve, Constants.MaxForce, phaseEnum);
 
 			if(myColor == "")
 				myColor = assignColor(
@@ -1309,7 +1408,64 @@ public partial class ChronoJumpWindow
 		renderBoldIfNeeded(cell, curve, str);
 	}
 
+	private void RenderMaxForce_maxForceT (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		string str = String.Format(UtilGtk.TVNumPrint(curve.MaxForce_MaxForceT,6,1),Convert.ToDouble(curve.MaxForce_MaxForceT));
+		renderBoldIfNeeded(cell, curve, str);
+	}
 	
+	private void RenderWork (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+
+		double workValueD = curve.WorkJD;
+		int decimals = 1;
+		if(preferences.encoderWorkKcal)
+		{
+			workValueD = curve.WorkKcalD;
+			decimals = 3;
+		}
+
+		string str = String.Format(UtilGtk.TVNumPrint(workValueD.ToString(),6, decimals), workValueD);
+		renderBoldIfNeeded(cell, curve, str);
+	}
+
+	private void RenderImpulse (Gtk.TreeViewColumn column, Gtk.CellRenderer cell, Gtk.TreeModel model, Gtk.TreeIter iter)
+	{
+		EncoderCurve curve = (EncoderCurve) model.GetValue (iter, 0);
+		string str = String.Format(UtilGtk.TVNumPrint(curve.Impulse,6,3),Convert.ToDouble(curve.Impulse));
+		renderBoldIfNeeded(cell, curve, str);
+	}
+
+	private Preferences.EncoderPhasesEnum getEncoderCurvePhaseEnum(EncoderCurve curve)
+	{
+		//LogB.Information("getEncoderCurvePhaseEnum curve: " + curve.ToCSV(false, ";", false, ""));
+
+		//if N contains the e or c, use that
+		if(curve.IsNumberNandEorC())
+			return curve.GetPhaseEnum();
+
+		if (ecconLast == "ec" || ecconLast == "ecS")
+		{
+			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
+			if(isEven)
+				return Preferences.EncoderPhasesEnum.CON;
+			else
+				return Preferences.EncoderPhasesEnum.ECC;
+		}
+		else if (ecconLast == "ce" || ecconLast == "ceS")
+		{
+			bool isEven = Util.IsEven(Convert.ToInt32(curve.N));
+			if(isEven)
+				return Preferences.EncoderPhasesEnum.ECC;
+			else
+				return Preferences.EncoderPhasesEnum.CON;
+		}
+		else // (ecconLast == "c")
+			return Preferences.EncoderPhasesEnum.BOTH;
+	}
+
 	/* end of rendering capture and analyze cols */
 
 	/* start rendering neuromuscular cols */
@@ -1423,9 +1579,10 @@ public partial class ChronoJumpWindow
 	private bool fixDecimalsWillWork(bool captureOrAnalyze, string [] cells)
 	{
 		LogB.Information(string.Format("captureOrAnalyze: {0}, cells.Length: {1}", captureOrAnalyze, cells.Length));
-		if(captureOrAnalyze && cells.Length < 18) 		//from 0 to 17
+		//LogB.Information(string.Format("cellsString: {0}", Util.StringArrayToString(cells, ";")));
+		if(captureOrAnalyze && cells.Length < 21) 		//from 0 to 20
 			return false;
-		else if(! captureOrAnalyze && cells.Length < 20) 	//from 0 to 19
+		else if(! captureOrAnalyze && cells.Length < 23) 	//from 0 to 22
 			return false;
 
 		return true;
@@ -1433,6 +1590,8 @@ public partial class ChronoJumpWindow
 	//captureOrAnalyze is true on capture, false on analyze
 	private string [] fixDecimals(bool captureOrAnalyze, string [] cells) 
 	{
+		LogB.Information("fixDecimals: ");
+		LogB.Information(Util.StringArrayToString(cells, ";"));
 		//start, width, height
 		for(int i=5; i <= 7; i++)
 			cells[i] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[i])),1);
@@ -1449,13 +1608,23 @@ public partial class ChronoJumpWindow
 		for(int i=15; i <= 17; i++)
 			cells[i] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[i])),3);
 
-		//cells[18] laterality
+		//maxForce_maxForceT
+		int maxForce_maxForceT = 18;
+		cells[maxForce_maxForceT] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[maxForce_maxForceT])),1);
+
+		LogB.Information("cells19: " + cells[19]);
+		LogB.Information("cells20: " + cells[20]);
+		//work, impulse
+		cells[19] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[19])),3);
+		cells[20] = Util.TrimDecimals(Convert.ToDouble(Util.ChangeDecimalSeparator(cells[20])),3);
+
+		//cells[21] laterality
 
 		//capture does not return inerta
 		//analyze returns inertia (can be different on "saved curves") comes as Kg*m^2, convert it to Kg*cm^2
 		if(! captureOrAnalyze) {
-			double inertiaInM = Convert.ToDouble(Util.ChangeDecimalSeparator(cells[19]));
-			cells[19] = (Convert.ToInt32(inertiaInM * 10000)).ToString();
+			double inertiaInM = Convert.ToDouble(Util.ChangeDecimalSeparator(cells[22]));
+			cells[22] = (Convert.ToInt32(inertiaInM * 10000)).ToString();
 		}
 
 		return cells;
