@@ -49,7 +49,9 @@ public class GenericWindow
 
 	[Widget] Gtk.SpinButton spin_double;
 	[Widget] Gtk.Box hbox_height_metric;
-	
+
+	[Widget] Gtk.CheckButton check1;
+
 	[Widget] Gtk.HButtonBox hbuttonbox_middle;
 	[Widget] Gtk.Button button_middle;
 
@@ -58,7 +60,7 @@ public class GenericWindow
 	[Widget] Gtk.Label hbox_combo_label;
 	[Widget] Gtk.Box hbox_combo;
 	[Widget] Gtk.ComboBox combo;
-	[Widget] Gtk.Button hbox_combo_button;
+	[Widget] Gtk.Button hbox_combo_button_apply;
 	[Widget] Gtk.Entry entry_edit_row;
 	
 	[Widget] Gtk.Box hbox_all_none_selected;
@@ -72,11 +74,16 @@ public class GenericWindow
 	[Widget] Gtk.TreeView treeview;
 	[Widget] Gtk.Button button_accept;
 	[Widget] Gtk.Button button_cancel;
-	[Widget] Gtk.Button button_delete; //currently only on encoder exercise edit
-	
+
 	//treeview fake buttons
 	[Widget] Gtk.Button button_row_edit;
+	[Widget] Gtk.Button button_row_play;
 	[Widget] Gtk.Button button_row_delete;
+
+	[Widget] Gtk.Button button_treeviewload_row_edit;
+	[Widget] Gtk.Button button_treeviewload_row_delete;
+	[Widget] Gtk.Button button_treeviewload_row_play;
+	[Widget] Gtk.Image image_treeviewload_row_play;
 	
 	[Widget] Gtk.Box hbox_entry2;
 	[Widget] Gtk.Label label_entry2;
@@ -89,16 +96,15 @@ public class GenericWindow
 	[Widget] Gtk.Label label_spin_double2;
 	[Widget] Gtk.SpinButton spin_double2;
 	
-	[Widget] Gtk.Image image_delete;
-	
 	private ArrayList nonSensitiveRows;
 
 	static GenericWindow GenericWindowBox;
 	
 	private TreeStore store;
-	private Constants.ContextMenu genericWinContextMenu;
 	private bool textviewChanging = false;
 
+	public enum EditActions { NONE, EDITPLAYDELETE, DELETE }
+
 	//used to read data, see if it's ok, and print an error message.
 	//if all is ok, destroy it with HideAndNull()
 	public bool HideOnAccept;
@@ -107,10 +113,10 @@ public class GenericWindow
 	//and we want to ensure next window will be created at needed size
 	public bool DestroyOnAccept;
 	public int TreeviewSelectedUniqueID;
+	private int videoColumn = 0;
 	private int commentColumn;
 
 	public int uniqueID; 			//used on encoder & forceSensor edit exercise
-	public string nameUntranslated;		//used on encoder edit exercise
 
 	public enum Types { UNDEFINED, ENCODER_SESSION_LOAD, 
 		ENCODER_SEL_REPS_IND_CURRENT_SESS, ENCODER_SEL_REPS_IND_ALL_SESS, ENCODER_SEL_REPS_GROUP_CURRENT_SESS };
@@ -151,8 +157,8 @@ public class GenericWindow
 		foreach(ArrayList widgetArray in array)
 			GenericWindowBox.showWidgetsPowerful(widgetArray);
 
-		Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "stock_delete.png");
-		GenericWindowBox.image_delete.Pixbuf = pixbuf;
+		Pixbuf pixbuf = new Pixbuf (null, Util.GetImagePath(false) + "video_play.png");
+		GenericWindowBox.image_treeviewload_row_play.Pixbuf = pixbuf;
 
 		if(showNow)
 			GenericWindowBox.generic_window.Show ();
@@ -161,7 +167,7 @@ public class GenericWindow
 	}
 
 	//for only one widget
-	static public GenericWindow Show (string title, string textHeader, Constants.GenericWindowShow stuff)
+	static public GenericWindow Show (string title, string textHeader, Constants.GenericWindowShow stuff, bool sensitive)
 	{
 		if (GenericWindowBox == null) {
 			GenericWindowBox = new GenericWindow(title, textHeader);
@@ -174,7 +180,7 @@ public class GenericWindow
 
 		GenericWindowBox.hideWidgets();
 
-		GenericWindowBox.showWidget(stuff);
+		GenericWindowBox.showWidget(stuff, sensitive);
 		GenericWindowBox.generic_window.Show ();
 		
 		return GenericWindowBox;
@@ -206,7 +212,11 @@ public class GenericWindow
 		spin_double.Hide();
 		hbox_spin_double2.Hide();
 		hbox_height_metric.Hide();
+		check1.Hide();
 		hbox_edit_row.Hide();
+		button_treeviewload_row_edit.Hide();
+		button_treeviewload_row_play.Hide();
+		button_treeviewload_row_delete.Hide();
 		hbox_all_none_selected.Hide();
 		hbox_combo_all_none_selected.Hide();
 		hbuttonbox_middle.Hide();
@@ -262,6 +272,10 @@ public class GenericWindow
 		else if(stuff == Constants.GenericWindowShow.HEIGHTMETRIC) {
 			hbox_height_metric.Show();
 		}
+		else if(stuff == Constants.GenericWindowShow.CHECK1) {
+			check1.Active = (text == "TRUE");
+			check1.Show();
+		}
 		else if(stuff == Constants.GenericWindowShow.COMBO) {
 			/*
 			hbox_combo.Show();
@@ -287,25 +301,58 @@ public class GenericWindow
 		
 	}
 
-	void showWidget(Constants.GenericWindowShow stuff) {
+	void showWidget(Constants.GenericWindowShow stuff, bool sensitive)
+	{
 		if(stuff == Constants.GenericWindowShow.ENTRY)
+		{
 			entry.Show();
+			entry.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.ENTRY2)
+		{
 			hbox_entry2.Show();
+			hbox_entry2.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.ENTRY3)
+		{
 			hbox_entry3.Show();
+			hbox_entry3.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.SPININT)
+		{
 			hbox_spin_int.Show();
+			hbox_spin_int.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.SPINDOUBLE)
+		{
 			spin_double.Show();
+			spin_double.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.HBOXSPINDOUBLE2)
+		{
 			hbox_spin_double2.Show();
+			hbox_spin_double2.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.HEIGHTMETRIC)
+		{
 			hbox_height_metric.Show();
+			hbox_height_metric.Sensitive = sensitive;
+		}
+		else if(stuff == Constants.GenericWindowShow.CHECK1)
+		{
+			check1.Show();
+			check1.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.SPININT2)
+		{
 			hbox_spin_int2.Show();
+			hbox_spin_int2.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.SPININT3)
+		{
 			hbox_spin_int3.Show();
+			hbox_spin_int3.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.COMBO) {
 			//do later, we need to create them first
 			/*
@@ -314,11 +361,20 @@ public class GenericWindow
 			*/
 		}
 		else if(stuff == Constants.GenericWindowShow.BUTTONMIDDLE)
+		{
 			hbuttonbox_middle.Show();
+			hbuttonbox_middle.Sensitive = sensitive;
+		}
 		else if(stuff == Constants.GenericWindowShow.TEXTVIEW)
+		{
 			scrolled_window_textview.Show();
+			scrolled_window_textview.Sensitive = sensitive;
+		}
 		else //if(stuff == Constants.GenericWindowShow.TREEVIEW)
+		{
 			scrolled_window_treeview.Show();
+			scrolled_window_treeview.Sensitive = sensitive;
+		}
 	}
 
 	private void on_entries_changed (object o, EventArgs args)
@@ -384,7 +440,12 @@ public class GenericWindow
 	public void SetComboValues(string [] values, string current) {
 		combo = ComboBox.NewText ();
 		UtilGtk.ComboUpdate(combo, values, "");
-		
+
+		//if there hbox already has a combo (window has not been properly destroyed)
+		//remove that combo (to not have two combos)
+		if(hbox_combo.Children.Length > 0)
+			hbox_combo.Remove(combo);
+
 		hbox_combo.PackStart(combo, true, true, 0);
 		hbox_combo.ShowAll();
 		combo.Sensitive = true;
@@ -398,6 +459,9 @@ public class GenericWindow
 		hbox_edit_row.Visible = show;
 	}
 
+	public void SetCheck1Label(string s) {
+		check1.Label = s;
+	}
 	
 	private static string [] comboCheckBoxesOptionsDefault = {
 		Catalog.GetString("All"),
@@ -520,7 +584,8 @@ public class GenericWindow
 	bool activateRowAcceptsWindow;
 	//data is an ArrayList of strings[], each string [] is a row, each of its strings is a column
 	public void SetTreeview(string [] columnsString, bool addCheckbox, 
-			ArrayList data, ArrayList myNonSensitiveRows, Constants.ContextMenu contextMenu,
+			ArrayList data, ArrayList myNonSensitiveRows,
+			EditActions editAction,
 			bool activateRowAcceptsWindow	//this param makes button_accept the window if 'enter' on a row or double click
 			) 
 	{
@@ -543,20 +608,27 @@ public class GenericWindow
 		}
 		LogB.Debug("aaaaaaaaaaaaaaaa2");	
 
-		genericWinContextMenu = contextMenu;
 		this.activateRowAcceptsWindow = activateRowAcceptsWindow;
 
-		treeview.CursorChanged += on_treeview_cursor_changed; 
-		if(contextMenu == Constants.ContextMenu.EDITDELETE) {
+		if(editAction == EditActions.EDITPLAYDELETE)
+		{
+			button_treeviewload_row_edit.Sensitive = false;
+			button_treeviewload_row_edit.Visible = true;
+			button_treeviewload_row_play.Sensitive = false;
+			button_treeviewload_row_play.Visible = true;
+			button_treeviewload_row_delete.Sensitive = false;
+			button_treeviewload_row_delete.Visible = true;
 			button_row_edit = new Gtk.Button();
+			button_row_play = new Gtk.Button();
 			button_row_delete = new Gtk.Button();
-			treeview.ButtonReleaseEvent -= on_treeview_button_release_event;
-			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
-		} else if(contextMenu == Constants.ContextMenu.DELETE) {
+		} else if(editAction == EditActions.DELETE)
+		{
 			button_row_delete = new Gtk.Button();
-			treeview.ButtonReleaseEvent -= on_treeview_button_release_event;
-			treeview.ButtonReleaseEvent += on_treeview_button_release_event;
+			button_treeviewload_row_delete.Sensitive = false;
+			button_treeviewload_row_delete.Visible = true;
 		}
+
+		treeview.CursorChanged += on_treeview_cursor_changed;
 	}
 
 	public void SelectRowWithID(int colNum, int id) 
@@ -624,14 +696,38 @@ public class GenericWindow
 	{
 		TreeIter iter = new TreeIter();
 		TreeModel myModel = treeview.Model;
-		if (treeview.Selection.GetSelected (out myModel, out iter)) 
+		if (treeview.Selection.GetSelected (out myModel, out iter))
+		{
 			SetButtonAcceptSensitive(true);
+			button_treeviewload_row_edit.Sensitive = true;
+			button_treeviewload_row_delete.Sensitive = true;
+
+			string video = (string) myModel.GetValue (iter, videoColumn);
+			button_treeviewload_row_play.Sensitive = (video == Catalog.GetString("Yes"));
+		}
 		else
+		{
 			SetButtonAcceptSensitive(false);
+			button_treeviewload_row_edit.Sensitive = false;
+			button_treeviewload_row_delete.Sensitive = false;
+			button_treeviewload_row_play.Sensitive = false;
+		}
 
 		ShowEditRow(false);
 	}
 
+	public void SensitiveEditDeleteIfSelected()
+	{
+		TreeIter iter = new TreeIter();
+		TreeModel myModel = treeview.Model;
+		if (treeview.Selection.GetSelected (out myModel, out iter))
+		{
+			button_treeviewload_row_edit.Sensitive = true;
+			button_treeviewload_row_play.Sensitive = true;
+			button_treeviewload_row_delete.Sensitive = true;
+		}
+	}
+
 	//get the selected	
 	public int TreeviewSelectedRowID() {
 		TreeIter iter = new TreeIter();
@@ -760,59 +856,22 @@ public class GenericWindow
 			}
 		}
 	}
-	
-
-	private void on_treeview_button_release_event (object o, ButtonReleaseEventArgs args) {
-		//TreeviewSelectedUniqueID = -1;
-
-                Gdk.EventButton e = args.Event;
-                Gtk.TreeView tv = (Gtk.TreeView) o;
-		TreeModel model = treeview.Model;
-		if (e.Button == 3) {
-			TreeIter iter = new TreeIter();
-			if (tv.Selection.GetSelected (out model, out iter)) {
-				TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
-				treeviewContextMenu();
-			}
-		}
-		ShowEditRow(false);
-	}
-
-	Menu menuCtx;
-	private void treeviewContextMenu() {
-		menuCtx = new Menu ();
-		Gtk.MenuItem myItem;
-
-		if(genericWinContextMenu == Constants.ContextMenu.EDITDELETE) {
-			myItem = new MenuItem ( Catalog.GetString("Edit selected") );
-			myItem.Activated += on_edit_selected_clicked;
-			menuCtx.Attach( myItem, 0, 1, 0, 1 );
-
-			myItem = new MenuItem ( Catalog.GetString("Delete selected") );
-			myItem.Activated += on_delete_selected_clicked;
-			menuCtx.Attach( myItem, 0, 1, 1, 2 );
-		}
-		else if(genericWinContextMenu == Constants.ContextMenu.DELETE) {
-			myItem = new MenuItem ( Catalog.GetString("Delete selected") );
-			myItem.Activated += on_delete_selected_clicked;
-			menuCtx.Attach( myItem, 0, 1, 0, 1 );
-		} else {
-			//don't show nothing if there are no options
-			menuCtx.Popdown();
-			return; 
-		}
-
-		menuCtx.Popup();
-		menuCtx.ShowAll();
-	}
 
 	private void on_edit_selected_clicked (object o, EventArgs args) 
 	{
 		TreeModel model;
 		TreeIter iter = new TreeIter();
-		treeview.Selection.GetSelected (out model, out iter);
+		if(! treeview.Selection.GetSelected (out model, out iter))
+			return;
+
+		TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
+
 		entry_edit_row.Text = (string) model.GetValue (iter, commentColumn);
 
+		button_treeviewload_row_edit.Sensitive = false;
+		button_treeviewload_row_play.Sensitive = false;
+		button_treeviewload_row_delete.Sensitive = false;
+
 		button_row_edit.Click();
 	}
 	
@@ -827,14 +886,34 @@ public class GenericWindow
 		store.SetValue (iter, commentColumn, entry_edit_row.Text);
 	}
 
-	//this method is only used when try to delete an encoder exercise,
-	//and cannot because there are encoder rows done with this exercise.
+	private void on_play_selected_clicked (object o, EventArgs args)
+	{
+		TreeModel model;
+		TreeIter iter = new TreeIter();
+		if(! treeview.Selection.GetSelected (out model, out iter))
+			return;
+
+		TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
+		button_row_play.Click();
+	}
+
+	public void on_hbox_combo_button_cancel_clicked (object o, EventArgs args)
+	{
+		button_treeviewload_row_edit.Sensitive = true;
+		button_treeviewload_row_play.Sensitive = true;
+		button_treeviewload_row_delete.Sensitive = true;
+		hbox_edit_row.Hide();
+	}
+
+	//this method is only used when try to delete an encoder/forceSensor exercise,
+	//and cannot because there are rows done with this exercise.
 	//Just unsensitive some stuff now in order to not be able to change them
 	public void DeletingExerciseHideSomeWidgets() {
 		hbox_spin_int.Hide();
 		hbox_entry2.Hide();
 		hbox_entry3.Hide();
 		hbox_spin_double2.Hide();
+		check1.Hide();
 
 		SetButtonAcceptLabel(Catalog.GetString("Close"));
 	}	
@@ -843,7 +922,18 @@ public class GenericWindow
 		store = UtilGtk.RemoveRow(treeview, store);
 	}
 
-	private void on_delete_selected_clicked (object o, EventArgs args) {
+	private void on_delete_selected_clicked (object o, EventArgs args)
+	{
+		TreeModel model;
+		TreeIter iter = new TreeIter();
+		if(! treeview.Selection.GetSelected (out model, out iter))
+			return;
+
+		TreeviewSelectedUniqueID = Convert.ToInt32((string) store.GetValue (iter, 0));
+		button_treeviewload_row_edit.Sensitive = false;
+		button_treeviewload_row_play.Sensitive = false;
+		button_treeviewload_row_delete.Sensitive = false;
+
 		//activate button to manage on gui/encoder.cs in order to delete from SQL
 		button_row_delete.Click();
 	}
@@ -852,7 +942,6 @@ public class GenericWindow
 	public void Delete_row_accepted() {
 		//remove selected row from treeview
 		store = UtilGtk.RemoveRow(treeview, store);
-		menuCtx.Popdown();
 	}
 	
 	public void Row_add(string [] row) {
@@ -869,10 +958,6 @@ public class GenericWindow
 		scrolled_window_treeview.Show();
 	}
 
-	public void ShowButtonDelete(bool show) {
-		button_delete.Visible = show;
-	}
-
 	public void SetButtonAcceptLabel(string str) {
 		button_accept.Label=str;
 	}
@@ -884,10 +969,13 @@ public class GenericWindow
 	public void SetButtonCancelLabel(string str) {
 		button_cancel.Label=str;
 	}
-	
+
 	public void ShowButtonCancel(bool show) {
 		button_cancel.Visible = show;
 	}
+	public void ShowButtonAccept(bool show) {
+		button_accept.Visible = show;
+	}
 
 	private void on_button_cancel_clicked (object o, EventArgs args)
 	{
@@ -917,8 +1005,12 @@ public class GenericWindow
 	
 	//when ! HideOnAccept, use this to close window
 	//also is better to call it always tat is closed clicking on accept (after data has been readed)
-	public void HideAndNull() {
-		GenericWindowBox.generic_window.Hide();
+	public void HideAndNull()
+	{
+		//this check is extra safety if there are extra EventHandlers opened with +=
+		if(GenericWindowBox.generic_window != null)
+			GenericWindowBox.generic_window.Hide();
+
 		GenericWindowBox = null;
 	}
 	
@@ -932,12 +1024,6 @@ public class GenericWindow
 		get { return button_middle; }
 	}
 	
-	public Button Button_delete {
-		set { button_delete = value; }
-		get { return button_delete; }
-	}
-		
-
 	public Button Button_accept {
 		set { button_accept = value; }
 		get { return button_accept; }
@@ -947,16 +1033,23 @@ public class GenericWindow
 		set { button_row_edit = value; }
 		get { return button_row_edit; }
 	}
-	
+
+	public Button Button_row_play {
+		get { return button_row_play; }
+	}
+
 	public Button Button_row_edit_apply {
-		set { hbox_combo_button = value; }
-		get { return hbox_combo_button; }
+		set { hbox_combo_button_apply = value; }
+		get { return hbox_combo_button_apply; }
+	}
+
+	public int VideoColumn {
+	       set { videoColumn = value; }
 	}
-	
 	public int CommentColumn {
 		set { commentColumn = value; }
 	}
-		
+
 	public Button Button_row_delete {
 		set { button_row_delete = value; }
 		get { return button_row_delete; }
@@ -1031,6 +1124,10 @@ public class GenericWindow
 		get { return UtilGtk.ComboGetActive(combo); }
 	}
 
+	public bool GetCheck1 {
+		get { return check1.Active; }
+	}
+
 
 	~GenericWindow() {}
 	
