@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 
@@ -29,6 +29,7 @@ using System.Collections; //ArrayList
 using System.Collections.Generic; //List
 using System.Diagnostics; //Process
 using System.Threading;
+using Mono.Unix;
 	
 public partial class ChronoJumpWindow 
 {
@@ -38,7 +39,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.VBox vbox_start_window_sub;
 	[Widget] Gtk.Alignment alignment_start_window;
 	[Widget] Gtk.Alignment alignment_encoder_capture_options;
-			
+	[Widget] Gtk.Button button_activate_chronopics_networks_problems;
+
 	//RFID
 	[Widget] Gtk.Label label_rfid_wait;
 	[Widget] Gtk.Label label_rfid_encoder_wait;
@@ -52,8 +54,8 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.HBox hbox_encoder_im_weights_n;
 	
 	//config.EncoderNameAndCapture
-	[Widget] Gtk.Box hbox_top_person;
-	[Widget] Gtk.Box hbox_top_person_encoder;
+	[Widget] Gtk.HBox hbox_top_person;
+	[Widget] Gtk.HBox hbox_top_person_encoder;
 	[Widget] Gtk.Label label_top_person_name;
 	[Widget] Gtk.Label label_top_encoder_person_name;
 	[Widget] Gtk.Button button_image_current_person_zoom;
@@ -61,7 +63,6 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.Image image_current_person;
 	[Widget] Gtk.Button button_contacts_person_change;
 	[Widget] Gtk.Button button_encoder_person_change;
-	[Widget] Gtk.VBox vbox_encoder_capture_1_or_cont;
 
 	//encoder exercise stuff
 	[Widget] Gtk.Label label_encoder_exercise_encoder;
@@ -77,33 +78,42 @@ public partial class ChronoJumpWindow
 	//encoder ...
 	[Widget] Gtk.Button button_encoder_monthly_change_current_session;
 	[Widget] Gtk.Button button_encoder_analyze_image_compujump_send_email;
+	/*
+	[Widget] Gtk.Label label_RFID_disconnected;
+	[Widget] Gtk.Label label_chronopic_encoder;
+	[Widget] Gtk.Image image_chronopic_encoder_no;
+	[Widget] Gtk.Image image_chronopic_encoder_yes;
+	*/
+	[Widget] Gtk.HBox hbox_encoder_disconnected;
+	[Widget] Gtk.HBox hbox_RFID_disconnected;
+	[Widget] Gtk.Label label_encoder_checked_error;
 
 	//runsInterval
-	[Widget] Gtk.HBox hbox_runs_interval_compujump;
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_5m;
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_10m;
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_15m;
 	[Widget] Gtk.RadioButton radio_run_interval_compujump_20m;
 
 	//shown when menu is hidden
-	[Widget] Gtk.HBox hbox_menu_and_preferences_outside_menu_contacts;
-	[Widget] Gtk.HBox hbox_menu_and_preferences_outside_menu_encoder;
-	[Widget] Gtk.Button button_menu_outside_menu;
-	[Widget] Gtk.Button button_menu_outside_menu1;
+	//[Widget] Gtk.HBox hbox_menu_and_preferences_outside_menu_contacts;
+	//[Widget] Gtk.HBox hbox_menu_and_preferences_outside_menu_encoder;
+	//[Widget] Gtk.Button button_menu_outside_menu;
+	//[Widget] Gtk.Button button_menu_outside_menu1;
 
 	private enum linuxTypeEnum { NOTLINUX, LINUX, RASPBERRY, NETWORKS }
 	private bool encoderUpdateTreeViewWhileCapturing = true;
 
 	static Thread threadRFID;
 	public RFID rfid;
-	private static string capturedRFID;
+	private static string capturedRFID; //current RFID in use
 	private static bool shouldUpdateRFIDGui;
 	private static bool shouldShowRFIDDisconnected;
 	private static bool updatingRFIDGuiStuff;
 	private static bool networksRunIntervalCanChangePersonSQLReady;
-	private static DateTime startedRFIDWait;
+	private static DateTime startedRFIDWait; //just to display a message at the moment of try to wristband change while capturing
 	private bool rfidProcessCancel;
 	private bool rfidIsDifferent;
+	private bool needManageCompujumpCapturingReset; //useful to manage wristbands while capture
 	//private bool compujumpAutologout;
 	//private static CompujumpAutologout compujumpAutologout;
 	private CompujumpAutologout compujumpAutologout;
@@ -118,6 +128,13 @@ public partial class ChronoJumpWindow
 	private void configInitRead()
 	{
 		configChronojump.Read();
+
+		if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
+		{
+			button_show_modes_contacts.Visible = false;
+			button_show_modes_encoder.Visible = false;
+		}
+
 		if(
 				configChronojump.Compujump &&
 				configChronojump.CompujumpServerURL != null &&
@@ -135,9 +152,6 @@ public partial class ChronoJumpWindow
 			//button_encoder_person_change.Visible = false;
 			//TODO: don't allow edit person on person treeview
 
-			//don't allow to change persons view options
-			view_menuitem.Visible = false;
-
 			//dont't show persons_bottom hbox where users can be edited, deleted if persons at lateral is selected on preferences
 			vbox_persons_bottom.Visible = false;
 
@@ -145,8 +159,13 @@ public partial class ChronoJumpWindow
 			label_encoder_exercise_encoder.Visible = false;
 			hbox_encoder_exercise_encoder.Visible = false;
 
-			//don't show encoder 1-cont buttons
-			vbox_encoder_capture_1_or_cont.Visible = false;
+			//on networks do not show tooltip of button_encoder_capture_finish button
+			//because on pressing capture, the position pressed on the screen corresponds to the finish button
+			//and then tooltip appears during all capture, so hide this tooltip
+			button_encoder_capture_finish.TooltipText = "";
+
+			//do not allow to capture infinite (cont)
+			preferences.encoderCaptureInfinite = false;
 
 			//don't allow to edit exercises
 			button_encoder_exercise_edit.Visible = false;
@@ -169,7 +188,7 @@ public partial class ChronoJumpWindow
 
 			if(configChronojump.CompujumpStationMode != Constants.Menuitem_modes.UNDEFINED)
 			{
-				//select_menuitem_mode_toggled(configChronojump.CompujumpStationMode);
+				//changeMode (configChronojump.CompujumpStationMode);
 				//better do like this because radiobuttons are not set. TODO: remove radiobuttons checks
 				if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.RUNSINTERVALLIC)
 					on_button_selector_start_runs_intervallic_clicked(new object (), new EventArgs());
@@ -178,12 +197,8 @@ public partial class ChronoJumpWindow
 				else //if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
 					on_button_selector_start_encoder_inertial_clicked(new object (), new EventArgs());
 
-				hbox_runs_interval.Visible = false;
-				hbox_runs_interval_compujump.Visible = true;
-
-				menuitem_mode.Visible = false;
-				button_menu_outside_menu.Visible = false;
-				button_menu_outside_menu1.Visible = false;
+				vbox_runs_interval.Visible = false;
+				vbox_runs_interval_compujump.Visible = true;
 			}
 
 			Json.ChangeServerUrl(configChronojump.CompujumpServerURL);
@@ -197,6 +212,7 @@ public partial class ChronoJumpWindow
 			chronopicRegisterUpdate(false);
 			if(chronopicRegister != null && chronopicRegister.GetRfidPortName() != "")
 			{
+				networksShowDeviceMissingRFID (false);
 				rfid = new RFID(chronopicRegister.GetRfidPortName());
 				rfid.FakeButtonChange.Clicked += new EventHandler(rfidChanged);
 				rfid.FakeButtonReopenDialog.Clicked += new EventHandler(rfidReopenDialog);
@@ -208,7 +224,8 @@ public partial class ChronoJumpWindow
 
 				LogB.ThreadStart();
 				threadRFID.Start();
-			}
+			} else
+				networksShowDeviceMissingRFID (true);
 
 			if(configChronojump.CompujumpAdminEmail != "")
 				button_encoder_analyze_image_compujump_send_email.Visible = true;
@@ -228,6 +245,7 @@ public partial class ChronoJumpWindow
 		rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
 		LogB.Information("networksRI: " + networksRunIntervalCanChangePersonSQLReady.ToString());
 
+		needManageCompujumpCapturingReset = false;
 		LogB.Information("RFID Start");
 		rfid.Start();
 	}
@@ -318,11 +336,9 @@ public partial class ChronoJumpWindow
 			{
 				app1.Unmaximize();
 				app1.Decorated = true;
-				button_start_quit.Visible = false;
 			} else {
 				app1.Decorated = (configChronojump.Maximized != Preferences.MaximizedTypes.YESUNDECORATED);
 				app1.Maximize();
-				button_start_quit.Visible = ! app1.Decorated;
 			}
 			maximizeWindowAtStartDone = true;
 		}
@@ -397,11 +413,7 @@ public partial class ChronoJumpWindow
 		encoderUpdateTreeViewWhileCapturing = configChronojump.EncoderUpdateTreeViewWhileCapturing;
 
 		showPersonsOnTop(configChronojump.PersonWinHide);
-		menuitem_view_persons_on_top.Active = configChronojump.PersonWinHide;
-
 		showPersonPhoto(preferences.personPhoto);
-		menuitem_view_persons_show_photo.Active = preferences.personPhoto;
-
 
 		if(configChronojump.EncoderAnalyzeHide) {
 			hbox_encoder_sup_capture_analyze_two_buttons.Visible = false;
@@ -410,10 +422,14 @@ public partial class ChronoJumpWindow
 		if(currentSession == null && //this is going to be called one time because currentSession will change
 			       ( configChronojump.SessionMode == Config.SessionModeEnum.UNIQUE || configChronojump.SessionMode == Config.SessionModeEnum.MONTHLY) )
 		{
-			//main_menu.Visible = false;
 			//app1.Decorated = false;
-			hbox_menu_and_preferences_outside_menu_contacts.Visible = true;
-			hbox_menu_and_preferences_outside_menu_encoder.Visible = true;
+			//hbox_menu_and_preferences_outside_menu_contacts.Visible = true;
+			//hbox_menu_and_preferences_outside_menu_encoder.Visible = true;
+
+			//hide session controls on UNIQUE and MONTHLY
+			vbox_menu_session.Visible = false;
+			vbox_menu_session1.Visible = false;
+
 
 			if(configChronojump.SessionMode == Config.SessionModeEnum.UNIQUE)
 			{
@@ -445,10 +461,9 @@ public partial class ChronoJumpWindow
 		/*
 		if(linuxType == linuxTypeEnum.NETWORKS) {
 			//mostrar directament el power
-			select_menuitem_mode_toggled(Constants.Menuitem_modes.POWER);
+			changeMode (Constants.Menuitem_modes.POWER);
 			
 			//no mostrar menu
-			main_menu.Visible = false;
 			
 			//no mostrar persones
 			//vbox_persons.Visible = false;
@@ -513,10 +528,13 @@ public partial class ChronoJumpWindow
 	{
 		if(shouldShowRFIDDisconnected)
 		{
-			new DialogMessage(Constants.MessageTypes.WARNING, Constants.RFIDDisconnectedMessage);
+			//new DialogMessage(Constants.MessageTypes.WARNING, Constants.RFIDDisconnectedMessage());
+			networksShowDeviceMissingRFID (true);
 
 			if(dialogPersonPopup != null)
 				dialogPersonPopup.DestroyDialog();
+
+			shouldShowRFIDDisconnected = false;
 		}
 
 		if(! threadRFID.IsAlive || rfidProcessCancel)
@@ -536,6 +554,7 @@ public partial class ChronoJumpWindow
 		TimeSpan span = DateTime.Now - startedRFIDWait;
 		if(span.TotalSeconds < 2) {
 			label_rfid_wait.Visible = true;
+			label_rfid_encoder_wait.Text = Catalog.GetString("Please, wait!");
 			label_rfid_encoder_wait.Visible = true;
 		} else {
 			label_rfid_wait.Visible = false;
@@ -544,8 +563,14 @@ public partial class ChronoJumpWindow
 
 		if(isCompujumpCapturing ()) {
 			Thread.Sleep (100);
+			needManageCompujumpCapturingReset = true;
 			return true;
 		}
+		else if (needManageCompujumpCapturingReset) {
+			//reset lastRFID in order to be able to use that RFID after capture (if same wristband is used again)
+			rfid.ResetLastRFID();
+			needManageCompujumpCapturingReset = false;
+		}
 
 		//---- end of checking if we are on the middle of capture.
 
@@ -569,7 +594,8 @@ public partial class ChronoJumpWindow
 				LogB.Information("rest seconds: " + rfidWaitingAdminGuiObjects.RestSeconds().ToString());
 				if(rfidWaitingAdminGuiObjects.RestSeconds() != -1) {
 					label_rfid_encoder_wait.Text =
-						string.Format("Identify with admin ID wristband before {0} s.", rfidWaitingAdminGuiObjects.RestSeconds());
+						string.Format(Catalog.GetString("Identify with admin ID wristband before {0} s."),
+								rfidWaitingAdminGuiObjects.RestSeconds());
 					label_rfid_encoder_wait.Visible = true;
 				} else {
 					rfidWaitingAdminGuiObjects = new RFIDWaitingAdminGuiObjects();
@@ -578,8 +604,7 @@ public partial class ChronoJumpWindow
 				}
 				Thread.Sleep (100);
 				return true;
-			} else
-				label_rfid_encoder_wait.Text = "";
+			}
 		}
 
 
@@ -619,12 +644,14 @@ public partial class ChronoJumpWindow
 			Person pServer = json.GetPersonByRFID(capturedRFID);
 
 			if(! json.Connected) {
-				LogB.Information("Server is disconnected!");
+				LogB.Information("Cannot connect with server!");
 				if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
 				{
+					NetworksCheckDevices ncd = new NetworksCheckDevices();
 					dialogMessageNotAtServer = new DialogMessage(
 							Constants.MessageTypes.WARNING,
-							Constants.ServerDisconnectedMessage
+							ncd.ToString() + "\n\n" +
+							Constants.ServerDisconnectedMessage()
 							); //GTK
 
 					compujumpPersonLogoutDo();
@@ -634,7 +661,7 @@ public partial class ChronoJumpWindow
 				LogB.Information("Person NOT found on server!");
 				if(dialogMessageNotAtServer == null || ! dialogMessageNotAtServer.Visible)
 				{
-					dialogMessageNotAtServer = new DialogMessage(Constants.MessageTypes.WARNING, Constants.RFIDNotInServerMessage); //GTK
+					dialogMessageNotAtServer = new DialogMessage(Constants.MessageTypes.WARNING, Constants.RFIDNotInServerMessage()); //GTK
 
 					compujumpPersonLogoutDo();
 				}
@@ -798,7 +825,10 @@ public partial class ChronoJumpWindow
 					Constants.SportUndefinedID,
 					Constants.SpeciallityUndefinedID,
 					Constants.LevelUndefinedID,
-					"", false); //comments, dbconOpened
+					"", 	//comments
+					Constants.TrochanterToeUndefinedID,
+					Constants.TrochanterFloorOnFlexionUndefinedID,
+					false); //dbconOpened
 		else
 			currentPersonSession = ps;
 	}
@@ -851,11 +881,15 @@ public partial class ChronoJumpWindow
 		//3) get other stationsCount
 		List<StationCount> stationsCount = json.GetOtherStationsWithPendingTasks(currentPerson.UniqueID, configChronojump.CompujumpStationID);
 
-		//4) show dialog
-		showDialogPersonPopup(tasks, stationsCount, json.Connected);
+		//4) check if there are active Internet devices
+		NetworksCheckDevices ncd = new NetworksCheckDevices();
+
+		//5) show dialog
+		showDialogPersonPopup(tasks, stationsCount, ncd.ToString(), json.Connected);
 	}
 
-	private void showDialogPersonPopup(List<Task> tasks, List<StationCount> stationsCount, bool serverConnected)
+
+	private void showDialogPersonPopup(List<Task> tasks, List<StationCount> stationsCount, string networkDevices, bool serverConnected)
 	{
 		if(dialogPersonPopup != null)
 			dialogPersonPopup.DestroyDialog();
@@ -865,8 +899,8 @@ public partial class ChronoJumpWindow
 
 		dialogPersonPopup = new DialogPersonPopup(
 				currentPerson.UniqueID, currentPerson.Name, capturedRFID, tasks, stationsCount,
-				serverConnected, compujumpAutologout.Active,
-				configChronojump.CompujumpDjango);
+				networkDevices, serverConnected, compujumpAutologout.Active,
+				configChronojump.CompujumpDjango, configChronojump.CompujumpHideTaskDone);
 
 		dialogPersonPopup.Fake_button_start_task.Clicked -= new EventHandler(compujumpTaskStart);
 		dialogPersonPopup.Fake_button_start_task.Clicked += new EventHandler(compujumpTaskStart);
@@ -1019,6 +1053,49 @@ public partial class ChronoJumpWindow
 		//other future send email send objects
 	}
 
+	private void networksShowDeviceMissingEncoder (bool missing)
+	{
+		if(missing) {
+			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.NETWORKSPROBLEMS);
+			hbox_RFID_disconnected.Visible = false;
+			hbox_encoder_disconnected.Visible = true;
+			label_encoder_checked_error.Visible = false;
+			button_activate_chronopics_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
+		}
+		else {
+			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.ENCODER);
+			hbox_RFID_disconnected.Visible = false;
+			hbox_encoder_disconnected.Visible = false;
+		}
+	}
+
+	private void networksShowDeviceMissingRFID (bool missing)
+	{
+		if(missing) {
+			hbox_RFID_disconnected.Visible = true;
+
+			/*
+			 * note rfid missing is more important than encoder missing,
+			 * if both messages are active, then user can connect encoder, press check button
+			 * and it will take to normal capture window (while rfid is not ok or Chronojump has to reboot)
+			 * so do not show the encoder message
+			 */
+			notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.NETWORKSPROBLEMS);
+			button_activate_chronopics_networks_problems.Sensitive = preferences.networksAllowChangeDevices;
+			hbox_encoder_disconnected.Visible = false;
+		}
+		else {
+			//notebook_start.CurrentPage = Convert.ToInt32(notebook_start_pages.PROGRAM);
+			if(configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERGRAVITATORY ||
+					configChronojump.CompujumpStationMode == Constants.Menuitem_modes.POWERINERTIAL)
+				notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.ENCODER);
+			else
+				notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.CONTACTS);
+
+			hbox_RFID_disconnected.Visible = false;
+		}
+	}
+
 	/*
 	 *
 	 * This code uses a watcher to see changes on a filename
@@ -1322,7 +1399,7 @@ public class CompujumpAutologout
 	}
 }
 
-//this class manages the wating of admin wristband in tasks like sending an email with the analyze image
+//this class manages the waiting of admin wristband in tasks like sending an email with the analyze image
 public class RFIDWaitingAdminGuiObjects
 {
 	public bool Waiting;
