@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -30,13 +30,9 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Notebook notebook_main;
 	//[Widget] Gtk.ScrolledWindow scrolled_conditions;
 
-	[Widget] Gtk.Frame frame_best_and_worst;
 	[Widget] Gtk.Box hbox_jump_best_worst;
 	[Widget] Gtk.Box hbox_run_best_worst;
 	
-	[Widget] Gtk.VBox vbox_encoder_stuff;
-	[Widget] Gtk.Frame frame_conditions;
-
 	/* jumps */	
 	[Widget] Gtk.Box hbox_jump_conditions;
 	[Widget] Gtk.CheckButton checkbutton_jump_tf_tc_best;
@@ -72,16 +68,22 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.SpinButton spinbutton_time_lower;
 
 	/* encoder */
-	[Widget] Gtk.Frame frame_encoder_automatic_conditions;
 	[Widget] Gtk.HBox hbox_combo_encoder_main_variable;
 	[Widget] Gtk.ComboBox combo_encoder_main_variable;
 	[Widget] Gtk.RadioButton radio_encoder_relative_to_set;
 	[Widget] Gtk.RadioButton radio_encoder_relative_to_historical;
-	[Widget] Gtk.Label label_main_variable_text;
 	[Widget] Gtk.CheckButton checkbutton_encoder_automatic_greater;
 	[Widget] Gtk.CheckButton checkbutton_encoder_automatic_lower;
 	[Widget] Gtk.SpinButton spinbutton_encoder_automatic_greater;
 	[Widget] Gtk.SpinButton spinbutton_encoder_automatic_lower;
+	[Widget] Gtk.CheckButton check_encoder_show_secondary_variable;
+	[Widget] Gtk.HBox hbox_combo_encoder_secondary_variable;
+	[Widget] Gtk.ComboBox combo_encoder_secondary_variable;
+	[Widget] Gtk.RadioButton radio_encoder_eccon_both;
+	[Widget] Gtk.RadioButton radio_encoder_eccon_ecc;
+	[Widget] Gtk.RadioButton radio_encoder_eccon_con;
+	[Widget] Gtk.CheckButton check_encoder_inertial_ecc_overload;
+	[Widget] Gtk.CheckButton check_encoder_inertial_ecc_overload_percent;
 
 	[Widget] Gtk.VBox vbox_encoder_manual;
 	[Widget] Gtk.CheckButton checkbutton_encoder_show_manual_feedback;
@@ -121,6 +123,7 @@ public class RepetitiveConditionsWindow
 
 
 	[Widget] Gtk.Button button_test_good;
+	[Widget] Gtk.Button button_test_bad;
 	[Widget] Gtk.Label label_test_sound_result;
 	[Widget] Gtk.Button button_close;
 
@@ -141,6 +144,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_encoder_power_higher;
 	[Widget] Gtk.Image image_encoder_peakpower_higher;
 	[Widget] Gtk.Image image_repetitive_test_good;
+	[Widget] Gtk.Image image_repetitive_test_good1;
 	//bells bad (red)
 	[Widget] Gtk.Image image_repetitive_worst_tf_tc;
 	[Widget] Gtk.Image image_repetitive_worst_time;
@@ -158,6 +162,7 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.Image image_encoder_power_lower;
 	[Widget] Gtk.Image image_encoder_peakpower_lower;
 	[Widget] Gtk.Image image_repetitive_test_bad;
+	[Widget] Gtk.Image image_repetitive_test_bad1;
 
 	//encoder rhythm
 	[Widget] Gtk.Label label_rhythm_tab;
@@ -181,9 +186,17 @@ public class RepetitiveConditionsWindow
 	[Widget] Gtk.HBox hbox_rhythm_rest_reps_value;
 	[Widget] Gtk.CheckButton check_rhythm_rest_reps;
 
+	//forceSensor
+	[Widget] Gtk.CheckButton check_force_sensor_capture_feedback;
+	[Widget] Gtk.HBox hbox_force_sensor_capture_feedback;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_at;
+	[Widget] Gtk.SpinButton spin_force_sensor_capture_feedback_range;
 
-	const int FEEDBACKPAGE = 0;
-	const int RHYTHMPAGE = 1;
+	const int JUMPSRUNSPAGE = 0;
+	const int ENCODERPAGE = 1;
+	const int ENCODERRHYTHMPAGE = 2;
+	const int FORCESENSORPAGE = 3;
+	const int TESTBELLSPAGE = 4;
 
 	public Gtk.Button FakeButtonClose;
 
@@ -194,6 +207,7 @@ public class RepetitiveConditionsWindow
 	public enum BestSetValueEnum { CAPTURE_MAIN_VARIABLE, AUTOMATIC_FEEDBACK}
 	private double bestSetValueCaptureMainVariable;
 	private double bestSetValueAutomaticFeedback;
+	private bool update_checkbuttons_encoder_automatic;
 	
 	static RepetitiveConditionsWindow RepetitiveConditionsWindowBox;
 		
@@ -212,7 +226,7 @@ public class RepetitiveConditionsWindow
 		FakeButtonClose = new Gtk.Button();
 		
 		//createComboEncoderAutomaticVariable();
-		createComboEncoderMainVariable();
+		createComboEncoderMainAndSecondaryVariables();
 
 		bestSetValueCaptureMainVariable = 0;
 		bestSetValueCaptureMainVariable = 0;
@@ -234,94 +248,225 @@ public class RepetitiveConditionsWindow
 		
 		return RepetitiveConditionsWindowBox;
 	}
-	
-	public void View (Constants.BellModes bellMode, bool volumeOn, Preferences.GstreamerTypes gstreamer,
-			Constants.EncoderVariablesCapture encoderMainVariable, EncoderRhythm encoderRhythm)
+
+	public void View (Constants.BellModes bellMode, Preferences preferences, EncoderRhythm encoderRhythm, bool viewWindow)
 	{
 		//when user "deleted_event" the window
 		if (RepetitiveConditionsWindowBox == null) {
 			RepetitiveConditionsWindowBox = new RepetitiveConditionsWindow (); 
 		}
-		RepetitiveConditionsWindowBox.showWidgets(bellMode, encoderMainVariable, encoderRhythm);
+		RepetitiveConditionsWindowBox.update_checkbuttons_encoder_automatic = true;
+		RepetitiveConditionsWindowBox.showWidgets(bellMode,
+				preferences.encoderCaptureMainVariable, preferences.encoderCaptureSecondaryVariable,
+				preferences.encoderCaptureSecondaryVariableShow,
+				preferences.encoderCaptureInertialEccOverloadMode,
+				preferences.encoderCaptureMainVariableThisSetOrHistorical,
+				preferences.encoderCaptureMainVariableGreaterActive,
+				preferences.encoderCaptureMainVariableGreaterValue,
+				preferences.encoderCaptureMainVariableLowerActive,
+				preferences.encoderCaptureMainVariableLowerValue,
+				preferences.encoderCaptureFeedbackEccon,
+				encoderRhythm,
+				preferences.forceSensorCaptureFeedbackActive,
+				preferences.forceSensorCaptureFeedbackAt,
+				preferences.forceSensorCaptureFeedbackRange);
 
-		RepetitiveConditionsWindowBox.repetitive_conditions.Show ();
-		RepetitiveConditionsWindowBox.volumeOn = volumeOn;
-		RepetitiveConditionsWindowBox.gstreamer = gstreamer;
+		if(viewWindow)
+			RepetitiveConditionsWindowBox.repetitive_conditions.Show ();
+
+		RepetitiveConditionsWindowBox.volumeOn = preferences.volumeOn;
+		RepetitiveConditionsWindowBox.gstreamer = preferences.gstreamer;
 	}
 
-	void showWidgets(Constants.BellModes bellMode, Constants.EncoderVariablesCapture encoderMainVariable, EncoderRhythm encoderRhythm)
+	void showWidgets(Constants.BellModes bellMode,
+			Constants.EncoderVariablesCapture encoderMainVariable,
+			Constants.EncoderVariablesCapture encoderSecondaryVariable,
+			bool encoderSecondaryVariableShow,
+			Preferences.encoderCaptureEccOverloadModes encoderCaptureEccOverloadMode,
+			bool encoderCaptureMainVariableThisSetOrHistorical,
+			bool encoderCaptureMainVariableGreaterActive,
+			int encoderCaptureMainVariableGreaterValue,
+			bool encoderCaptureMainVariableLowerActive,
+			int encoderCaptureMainVariableLowerValue,
+			Preferences.EncoderPhasesEnum encoderCaptureFeedbackEccon,
+			EncoderRhythm encoderRhythm,
+			bool forceSensorCaptureFeedbackActive,
+			int forceSensorCaptureFeedbackAt,
+			int forceSensorCaptureFeedbackRange)
 	{
-		frame_best_and_worst.Hide();
-		frame_conditions.Hide();
 		hbox_jump_best_worst.Hide();
 		hbox_run_best_worst.Hide();
 		hbox_jump_conditions.Hide();
 		hbox_run_conditions.Hide();
-		frame_encoder_automatic_conditions.Hide();
 		vbox_encoder_manual.Hide();
 		notebook_encoder_conditions.Hide();
-		vbox_encoder_stuff.Hide();
 
-		notebook_main.GetNthPage(RHYTHMPAGE).Hide();
+		notebook_main.GetNthPage(JUMPSRUNSPAGE).Hide();
+		notebook_main.GetNthPage(ENCODERPAGE).Hide();
+		notebook_main.GetNthPage(ENCODERRHYTHMPAGE).Hide();
+		notebook_main.GetNthPage(FORCESENSORPAGE).Hide();
+		notebook_main.GetNthPage(TESTBELLSPAGE).Hide();
 		notebook_main.ShowTabs = false;
 
-		if(bellMode == Constants.BellModes.JUMPS) {
-			frame_best_and_worst.Show();
-			hbox_jump_best_worst.Show();
-			hbox_jump_conditions.Show();
-			frame_conditions.Show();
-		} else if(bellMode == Constants.BellModes.RUNS) {
-			frame_best_and_worst.Show();
-			hbox_run_best_worst.Show();
-			hbox_run_conditions.Show();
-			frame_conditions.Show();
-		} else { //encoder (grav and inertial)
-			vbox_encoder_stuff.Show();
-			frame_encoder_automatic_conditions.Show();
-			notebook_main.ShowTabs = true;
+		if(bellMode == Constants.BellModes.JUMPS || bellMode == Constants.BellModes.RUNS)
+		{
+			if(bellMode == Constants.BellModes.JUMPS)
+			{
+				hbox_jump_best_worst.Show();
+				hbox_jump_conditions.Show();
+			}
+			else if(bellMode == Constants.BellModes.RUNS)
+			{
+				hbox_run_best_worst.Show();
+				hbox_run_conditions.Show();
+			}
 
+			notebook_main.GetNthPage(JUMPSRUNSPAGE).Show();
+			notebook_main.GetNthPage(TESTBELLSPAGE).Show();
+			notebook_main.CurrentPage = JUMPSRUNSPAGE;
+			notebook_main.ShowTabs = true;
+		}
+		else if (bellMode == Constants.BellModes.ENCODERGRAVITATORY || bellMode == Constants.BellModes.ENCODERINERTIAL)
+		{
 			vbox_encoder_manual.Show();
 			if(checkbutton_encoder_show_manual_feedback.Active)
 				notebook_encoder_conditions.Show();
 
 			combo_encoder_main_variable.Active = UtilGtk.ComboMakeActive(combo_encoder_main_variable,
 					Constants.GetEncoderVariablesCapture(encoderMainVariable));
+			combo_encoder_secondary_variable.Active = UtilGtk.ComboMakeActive(combo_encoder_secondary_variable,
+					Constants.GetEncoderVariablesCapture(encoderSecondaryVariable));
+
+			if(encoderCaptureEccOverloadMode == Preferences.encoderCaptureEccOverloadModes.NOT_SHOW) {
+				check_encoder_inertial_ecc_overload.Active = false;
+				check_encoder_inertial_ecc_overload_percent.Active = false;
+				check_encoder_inertial_ecc_overload_percent.Visible = false;
+			} else if (encoderCaptureEccOverloadMode == Preferences.encoderCaptureEccOverloadModes.SHOW_LINE) {
+				check_encoder_inertial_ecc_overload.Active = true;
+				check_encoder_inertial_ecc_overload_percent.Active = false;
+				check_encoder_inertial_ecc_overload_percent.Visible = true;
+			} else { // (encoderCaptureEccOverloadMode == Preferences.encoderCaptureEccOverloadModes.SHOW_LINE_AND_PERCENT)
+				check_encoder_inertial_ecc_overload.Active = true;
+				check_encoder_inertial_ecc_overload_percent.Active = true;
+				check_encoder_inertial_ecc_overload_percent.Visible = true;
+			}
+
+			if(encoderSecondaryVariableShow)
+				check_encoder_show_secondary_variable.Active = true;
+			else
+				check_encoder_show_secondary_variable.Active = false;
+
+			//need to do it "manually" at start
+			hbox_combo_encoder_secondary_variable.Visible = check_encoder_show_secondary_variable.Active;
+
+			//MeanPower, MeanSpeed, MeanFOrce can be historical
+			if(encoderCaptureMainVariableThisSetOrHistorical || (
+						encoderMainVariable != Constants.EncoderVariablesCapture.MeanPower &&
+						encoderMainVariable != Constants.EncoderVariablesCapture.MeanSpeed &&
+						encoderMainVariable != Constants.EncoderVariablesCapture.MeanForce
+					  ) )
+			{
+				radio_encoder_relative_to_set.Active = true;
+
+				if(encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.ECC)
+					radio_encoder_eccon_ecc.Active = true;
+				else if(encoderCaptureFeedbackEccon == Preferences.EncoderPhasesEnum.CON)
+					radio_encoder_eccon_con.Active = true;
+				else
+					radio_encoder_eccon_both.Active = true;
+			} else
+			{
+				radio_encoder_relative_to_historical.Active = true;
+
+				radio_encoder_eccon_both.Active = true;
+				radio_encoder_eccon_ecc.Sensitive = false;
+				radio_encoder_eccon_con.Sensitive = false;
+			}
+
+			//the change on spinbuttons here will not have to provoque changes on checkbuttons
+			update_checkbuttons_encoder_automatic = false;
+			checkbutton_encoder_automatic_greater.Active = encoderCaptureMainVariableGreaterActive;
+			spinbutton_encoder_automatic_greater.Value = encoderCaptureMainVariableGreaterValue;
+			checkbutton_encoder_automatic_lower.Active = encoderCaptureMainVariableLowerActive;
+			spinbutton_encoder_automatic_lower.Value = encoderCaptureMainVariableLowerValue;
+			update_checkbuttons_encoder_automatic = true;
+
+			notebook_main.GetNthPage(ENCODERPAGE).Show();
+			notebook_main.GetNthPage(ENCODERRHYTHMPAGE).Show();
+			notebook_main.GetNthPage(TESTBELLSPAGE).Show();
+			notebook_main.CurrentPage = ENCODERPAGE;
+			notebook_main.ShowTabs = true;
 
-			notebook_main.GetNthPage(RHYTHMPAGE).Show();
 			encoder_rhythm_set_values(encoderRhythm);
 		}
+		else if(bellMode == Constants.BellModes.FORCESENSOR)
+		{
+			if(forceSensorCaptureFeedbackActive)
+			{
+				check_force_sensor_capture_feedback.Active = true;
+				hbox_force_sensor_capture_feedback.Sensitive = true;
+			} else {
+				check_force_sensor_capture_feedback.Active = false;
+				hbox_force_sensor_capture_feedback.Sensitive = false;
+			}
+
+			spin_force_sensor_capture_feedback_at.Value = forceSensorCaptureFeedbackAt;
+			spin_force_sensor_capture_feedback_range.Value = forceSensorCaptureFeedbackRange;
+
+			notebook_main.GetNthPage(FORCESENSORPAGE).Show();
+		}
 
 		label_test_sound_result.Text = "";
 	}
 		
-	private void createComboEncoderMainVariable()
+	private void createComboEncoderMainAndSecondaryVariables()
 	{
+		//1 mainVariable
 		combo_encoder_main_variable = ComboBox.NewText ();
-
-		comboEncoderMainVariableFill();
+		comboEncoderVariableFill(combo_encoder_main_variable);
 
 		hbox_combo_encoder_main_variable.PackStart(combo_encoder_main_variable, false, false, 0);
 		hbox_combo_encoder_main_variable.ShowAll();
 		combo_encoder_main_variable.Sensitive = true;
 		combo_encoder_main_variable.Changed += new EventHandler (on_combo_encoder_main_variable_changed);
+
+		//1 secondaryVariable
+		combo_encoder_secondary_variable = ComboBox.NewText ();
+		comboEncoderVariableFill(combo_encoder_secondary_variable);
+
+		hbox_combo_encoder_secondary_variable.PackStart(combo_encoder_secondary_variable, false, false, 0);
+		hbox_combo_encoder_secondary_variable.ShowAll();
+		combo_encoder_secondary_variable.Sensitive = true;
+		//combo_encoder_secondary_variable.Changed += new EventHandler (on_combo_encoder_secondary_variable_changed);
 	}
-
-	private void comboEncoderMainVariableFill()
+	private void comboEncoderVariableFill(Gtk.ComboBox combo)
 	{
-		string [] values = { Constants.MeanSpeed, Constants.MaxSpeed, Constants.MeanForce, Constants.MaxForce, Constants.MeanPower, Constants.PeakPower };
+		string [] values = { Constants.RangeAbsolute, Constants.MeanSpeed, Constants.MaxSpeed, Constants.MeanForce, Constants.MaxForce, Constants.MeanPower, Constants.PeakPower };
 
-		UtilGtk.ComboUpdate(combo_encoder_main_variable, values, "");
+		UtilGtk.ComboUpdate(combo, values, "");
 	}
 
 	private void on_combo_encoder_main_variable_changed (object o, EventArgs args)
 	{
 		string mainVariable = UtilGtk.ComboGetActive(combo_encoder_main_variable);
 
-		radio_encoder_relative_to_historical.Visible = (mainVariable == "Mean power");
-		if(mainVariable != "Mean power")
-			radio_encoder_relative_to_set.Active = true;
+		radio_encoder_relative_to_historical.Visible =
+			(mainVariable == "Mean power" || mainVariable == "Mean speed" || mainVariable == "Mean force");
 
-		label_main_variable_text.Text = mainVariable;
+		if(mainVariable != "Mean power" && mainVariable != "Mean speed" && mainVariable != "Mean force")
+			radio_encoder_relative_to_set.Active = true;
+	}
+
+	private void on_check_encoder_show_secondary_variable_toggled (object o, EventArgs args)
+	{
+		hbox_combo_encoder_secondary_variable.Visible = check_encoder_show_secondary_variable.Active;
+	}
+
+	private void on_check_encoder_inertial_ecc_overload_toggled (object o, EventArgs args)
+	{
+		check_encoder_inertial_ecc_overload_percent.Visible = check_encoder_inertial_ecc_overload.Active;
+		if(! check_encoder_inertial_ecc_overload.Active)
+			check_encoder_inertial_ecc_overload_percent.Active = false;
 	}
 
 	private void putNonStandardIcons() {
@@ -373,10 +518,11 @@ public class RepetitiveConditionsWindow
 			Util.TestSound = true;
 
 			label_test_sound_result.Text = "";
+
 			Util.SoundCodes sc;
-			if (o == button_test_good) 
+			if (o == button_test_good)
 				sc = Util.PlaySound(Constants.SoundTypes.GOOD, true, gstreamer);
-			else //button_test_bad
+			else //if (o == button_test_bad)
 				sc = Util.PlaySound(Constants.SoundTypes.BAD, true, gstreamer);
 
 			if(sc == Util.SoundCodes.OK)
@@ -422,7 +568,8 @@ public class RepetitiveConditionsWindow
 			if(checkbutton_time_lower.Active || checkbutton_time_greater.Active)
 				return true;
 		}
-		else { //encoder (grav and inertial)
+		else if (bellMode == Constants.BellModes.ENCODERGRAVITATORY || bellMode == Constants.BellModes.ENCODERINERTIAL)
+		{
 			if(checkbutton_encoder_automatic_greater.Active || checkbutton_encoder_automatic_lower.Active ||
 					checkbutton_encoder_height_higher.Active || checkbutton_encoder_height_lower.Active ||
 					checkbutton_encoder_mean_speed_higher.Active || checkbutton_encoder_mean_speed_lower.Active ||
@@ -433,6 +580,8 @@ public class RepetitiveConditionsWindow
 					checkbutton_encoder_peakpower_higher.Active || checkbutton_encoder_peakpower_lower.Active)
 				return true;
 		}
+		else if(bellMode == Constants.BellModes.FORCESENSOR)
+			return check_force_sensor_capture_feedback.Active;
 
 		return false;
 	}
@@ -493,14 +642,29 @@ public class RepetitiveConditionsWindow
 		else
 			comboEncoderAutomaticVariableFillHistorical();
 			*/
+
+		//historical does not allow to differentiate between phases
+		if(radio_encoder_relative_to_set.Active)
+		{
+			radio_encoder_eccon_ecc.Sensitive = true;
+			radio_encoder_eccon_con.Sensitive = true;
+		} else {
+			radio_encoder_eccon_both.Active = true;
+			radio_encoder_eccon_ecc.Sensitive = false;
+			radio_encoder_eccon_con.Sensitive = false;
+		}
 	}
 
 
-	void on_spinbutton_encoder_automatic_greater_value_changed (object o, EventArgs args) {
-		checkbutton_encoder_automatic_greater.Active = true;
+	void on_spinbutton_encoder_automatic_greater_value_changed (object o, EventArgs args)
+	{
+		if(update_checkbuttons_encoder_automatic)
+			checkbutton_encoder_automatic_greater.Active = true;
 	}
-	void on_spinbutton_encoder_automatic_lower_value_changed (object o, EventArgs args) {
-		checkbutton_encoder_automatic_lower.Active = true;
+	void on_spinbutton_encoder_automatic_lower_value_changed (object o, EventArgs args)
+	{
+		if(update_checkbuttons_encoder_automatic)
+			checkbutton_encoder_automatic_lower.Active = true;
 	}
 
 	void on_button_encoder_automatic_greater_minus_1_clicked (object o, EventArgs args)
@@ -596,7 +760,7 @@ public class RepetitiveConditionsWindow
 	{
 		BestSetValueEnum b = BestSetValueEnum.AUTOMATIC_FEEDBACK;
 		string encoderVar = GetMainVariable;
-		if(encoderAutomaticHigher || encoderAutomaticLower) 
+		if(EncoderAutomaticHigherActive || EncoderAutomaticLowerActive)
 		{
 			if(encoderVar == Constants.MeanSpeed)
 				UpdateBestSetValue(b, curve.MeanSpeedD);
@@ -624,23 +788,30 @@ public class RepetitiveConditionsWindow
 				bestSetValueCaptureMainVariable = d;
 		}
 	}
-		
+
 	//called from gui/encoderTreeviews.cs
-	public string AssignColorAutomatic(BestSetValueEnum b, EncoderCurve curve, string variable)
+	public string AssignColorAutomatic(BestSetValueEnum b, EncoderCurve curve, string variable, Preferences.EncoderPhasesEnum phaseEnum)
 	{
 		if(GetMainVariable != variable)
 			return UtilGtk.ColorNothing;
 
 		double currentValue = curve.GetParameter(variable);
 
-		return AssignColorAutomatic(b, currentValue);
+		return AssignColorAutomatic(b, currentValue, phaseEnum);
 	}
 	//called from previous function, gui/encoder.cs plotCurvesGraphDoPlot
-	public string AssignColorAutomatic(BestSetValueEnum b, double currentValue)
+	public string AssignColorAutomatic(BestSetValueEnum b, double currentValue, Preferences.EncoderPhasesEnum phaseEnum)
 	{
-		if(encoderAutomaticHigher && currentValue > getBestSetValue(b) * encoderAutomaticHigherValue / 100)
+		//note on "c" phaseEnum will be BOTH
+
+		if(radio_encoder_eccon_ecc.Active && phaseEnum == Preferences.EncoderPhasesEnum.CON)
+			return UtilGtk.ColorGray;
+		else if(radio_encoder_eccon_con.Active && phaseEnum == Preferences.EncoderPhasesEnum.ECC)
+			return UtilGtk.ColorGray;
+
+		if(EncoderAutomaticHigherActive && currentValue > getBestSetValue(b) * EncoderAutomaticHigherValue / 100)
 			return UtilGtk.ColorGood;
-		else if (encoderAutomaticLower && currentValue < getBestSetValue(b) * encoderAutomaticLowerValue/ 100)
+		else if (EncoderAutomaticLowerActive && currentValue < getBestSetValue(b) * EncoderAutomaticLowerValue/ 100)
 			return UtilGtk.ColorBad;
 
 		return UtilGtk.ColorNothing;
@@ -774,6 +945,23 @@ public class RepetitiveConditionsWindow
 				reps_cluster, restClusters);
 	}
 
+	/* FORCESENSOR */
+
+	private void on_check_force_sensor_capture_feedback_toggled (object o, EventArgs args)
+	{
+		hbox_force_sensor_capture_feedback.Sensitive = check_force_sensor_capture_feedback.Active;
+	}
+
+	public bool GetForceSensorFeedbackActive {
+		get { return check_force_sensor_capture_feedback.Active; }
+	}
+	public int GetForceSensorFeedbackAt {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_at.Value); }
+	}
+	public int GetForceSensorFeedbackRange {
+		get { return Convert.ToInt32(spin_force_sensor_capture_feedback_range.Value); }
+	}
+
 
 	/* JUMPS */
 	public bool TfTcBest {
@@ -864,16 +1052,16 @@ public class RepetitiveConditionsWindow
 	/* ENCODER */
 	//automatic
 
-	private bool encoderAutomaticHigher {
+	public bool EncoderAutomaticHigherActive {
 		get { return checkbutton_encoder_automatic_greater.Active; }
 	}
-	private int encoderAutomaticHigherValue {
+	public int EncoderAutomaticHigherValue {
 		get { return Convert.ToInt32(spinbutton_encoder_automatic_greater.Value); }
 	}
-	private bool encoderAutomaticLower {
+	public bool EncoderAutomaticLowerActive {
 		get { return checkbutton_encoder_automatic_lower.Active; }
 	}
-	private int encoderAutomaticLowerValue {
+	public int EncoderAutomaticLowerValue {
 		get { return Convert.ToInt32(spinbutton_encoder_automatic_lower.Value); }
 	}
 
@@ -884,6 +1072,34 @@ public class RepetitiveConditionsWindow
 	public string GetMainVariable {
 		get { return UtilGtk.ComboGetActive(combo_encoder_main_variable); }
 	}
+	public string GetSecondaryVariable {
+		get { return UtilGtk.ComboGetActive(combo_encoder_secondary_variable); }
+	}
+	public bool GetSecondaryVariableShow {
+		get { return check_encoder_show_secondary_variable.Active; }
+	}
+
+	public Preferences.EncoderPhasesEnum GetEncoderCaptureFeedbackEccon {
+		get {
+			if(radio_encoder_eccon_ecc.Active)
+				return Preferences.EncoderPhasesEnum.ECC;
+			else if(radio_encoder_eccon_con.Active)
+				return Preferences.EncoderPhasesEnum.CON;
+			else
+				return Preferences.EncoderPhasesEnum.BOTH;
+		}
+	}
+
+	public Preferences.encoderCaptureEccOverloadModes GetEncoderCaptureEccOverloadMode {
+		get {
+			if(check_encoder_inertial_ecc_overload_percent.Active)
+				return Preferences.encoderCaptureEccOverloadModes.SHOW_LINE_AND_PERCENT;
+			else if (check_encoder_inertial_ecc_overload.Active)
+				return Preferences.encoderCaptureEccOverloadModes.SHOW_LINE;
+			else
+				return Preferences.encoderCaptureEccOverloadModes.NOT_SHOW;
+		}
+	}
 
 	public double GetMainVariableHigher(string mainVariable) 
 	{
