@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2017-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -38,7 +38,7 @@ public partial class ChronoJumpWindow
 	[Widget] Gtk.RadioButton radio_log_portuguese;
 	[Widget] Gtk.TextView textview_comments;
 	[Widget] Gtk.Button button_send_log;
-	[Widget] Gtk.Label label_send_log_message;
+	[Widget] Gtk.TextView textview_send_log_message;
 
 	string emailStored;
 	private void show_send_log(string sendLogMessage, string logLanguage)
@@ -110,7 +110,9 @@ public partial class ChronoJumpWindow
 			LogB.Error(js.ResultMessage);
 		}
 
-		label_send_log_message.Text = js.ResultMessage;
+		TextBuffer tb = new TextBuffer (new TextTagTable());
+		tb.Text = js.ResultMessage;
+		textview_send_log_message.Buffer = tb;
 	}
 
 	private void on_button_check_last_version_clicked (object o, EventArgs args)
@@ -118,18 +120,20 @@ public partial class ChronoJumpWindow
 		Json js = new Json();
 		bool success = js.GetLastVersion(progVersion);
 
-		if(success) {
+		if(success)
 			LogB.Information(js.ResultMessage);
-			label_send_log_message.Text = js.ResultMessage;
-		}
-		else {
+		else
 			LogB.Error(js.ResultMessage);
-			label_send_log_message.Text = js.ResultMessage;
-		}
+
+		TextBuffer tb = new TextBuffer (new TextTagTable());
+		tb.Text = js.ResultMessage;
+		textview_send_log_message.Buffer = tb;
 	}
 
 	private void on_button_open_chronojump_clicked(object o, EventArgs args)
 	{
-		notebook_start.CurrentPage = 0;
+		notebook_start.CurrentPage = Convert.ToInt32(notebook_start_pages.PROGRAM);
+		notebook_sup.CurrentPage = Convert.ToInt32(notebook_sup_pages.START);
+		new ChronojumpLogo (drawingarea_chronojump_logo, viewport_chronojump_logo, preferences.logoAnimatedShow);
 	}
 }
