@@ -15,13 +15,14 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Data;
 using Gtk;
 using System.Collections; //ArrayList
+using System.Collections.Generic; //List<T>
 
 //this file has classes to allow to pass gui objectes easily
 public class ExecutingGraphData
@@ -56,9 +57,10 @@ public class ExecutingGraphData
 	}
 }	
 
-public class PrepareEventGraphJumpSimple {
+public class PrepareEventGraphJumpSimple
+{
 	//sql data of previous jumps to plot graph and show stats at bottom
-	public string [] jumpsAtSQL;
+	public List<Jump> jumpsAtSQL;
 	
 	public double personMAXAtSQLAllSessions;
 	public double personMAXAtSQL;
@@ -70,29 +72,50 @@ public class PrepareEventGraphJumpSimple {
 	//current data
 	public double tv;
 	public double tc;
+	public string type; //jumpType (useful to know if "all jumps" (type == "")
+	public bool djShowHeights; //if djShowHeights and is a dj, graph falling height and jump height
+
 		
 	private enum jumpVariables { HEIGHT, TVTC, TC }
 
 	public PrepareEventGraphJumpSimple() {
 	}
 
-	public PrepareEventGraphJumpSimple(double tv, double tc, int sessionID, int personID, string table, string type) 
+	//allPersons is for searching the jumps of current of allpersons
+	//personID we need to the personsMAX/AVG sql calls
+	//type can be "" for all jumps, then write it under bar
+	public PrepareEventGraphJumpSimple(double tv, double tc, int sessionID,
+			int personID, bool allPersons, int limit,
+			string table, string type, bool djShowHeights)
 	{
+		int personIDTemp = personID;
+		if(allPersons)
+			personIDTemp = -1;
+
+		jumpsAtSQL = SqliteJump.SelectJumps (sessionID, personIDTemp, type,
+				Sqlite.Orders_by.ID_DESC, limit,
+				allPersons); //show names on comments only if "all persons"
+
 		Sqlite.Open();
 
-		//select data from SQL to update graph	
-		jumpsAtSQL = SqliteJump.SelectJumps(true, sessionID, personID, "", type,
-				Sqlite.Orders_by.ID_DESC, 10); //select only last 10
 
 		string sqlSelect = "";
+		/*
 		if(tv > 0) {
 			if(tc <= 0)
 				sqlSelect = "100*4.9*(TV/2)*(TV/2)";
-			else
-				sqlSelect = "TV"; //if tc is higher than tv it will be fixed on PrepareJumpSimpleGraph
+			else {
+				if(djShowHeights)
+					sqlSelect = "100*4.9*(TV/2)*(TV/2)";
+				else
+					sqlSelect = "TV"; //if tc is higher than tv it will be fixed on PrepareJumpSimpleGraph
+			}
 		} else
 			sqlSelect = "TC";
-		
+		*/
+		//always use heights to be able to do comparisons between different jump types
+		sqlSelect = "100*4.9*(TV/2)*(TV/2)";
+
 		personMAXAtSQLAllSessions = SqliteSession.SelectMAXEventsOfAType(true, -1, personID, table, type, sqlSelect);
 		personMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, personID, table, type, sqlSelect);
 		sessionMAXAtSQL = SqliteSession.SelectMAXEventsOfAType(true, sessionID, -1, table, type, sqlSelect);
@@ -104,6 +127,8 @@ public class PrepareEventGraphJumpSimple {
 			
 		this.tv = tv;
 		this.tc = tc;
+		this.type = type;
+		this.djShowHeights = djShowHeights;
 		
 		Sqlite.Close();
 	}
@@ -132,7 +157,7 @@ public class PrepareEventGraphJumpReactive {
 
 public class PrepareEventGraphRunSimple {
 	//sql data of previous runs to plot graph and show stats at bottom
-	public string [] runsAtSQL;
+	public List<Run> runsAtSQL;
 	
 	public double personMAXAtSQLAllSessions;
 	public double personMAXAtSQL;
@@ -143,17 +168,25 @@ public class PrepareEventGraphRunSimple {
 	
 	public double time;
 	public double speed;
+	public string type; //jumpType (useful to know if "all jumps" (type == "")
 
 	public PrepareEventGraphRunSimple() {
 	}
 
-	public PrepareEventGraphRunSimple(double time, double speed, int sessionID, int personID, string table, string type) 
+	public PrepareEventGraphRunSimple(double time, double speed, int sessionID,
+			int personID, bool allPersons, int limit,
+			string table, string type)
 	{
 		Sqlite.Open();
 		
+		int personIDTemp = personID;
+		if(allPersons)
+			personIDTemp = -1;
+
 		//obtain data
-		runsAtSQL = SqliteRun.SelectRuns(true, sessionID, personID, type,
-				Sqlite.Orders_by.ID_DESC, 10); //select only last 10
+		runsAtSQL = SqliteRun.SelectRuns (true, sessionID, personIDTemp, type,
+				Sqlite.Orders_by.ID_DESC, limit,
+				allPersons); //show names on comments only if "all persons"
 
 		
 		string sqlSelect = "distance/time";
@@ -174,6 +207,7 @@ public class PrepareEventGraphRunSimple {
 		
 		this.time = time;
 		this.speed = speed;
+		this.type = type;
 		
 		Sqlite.Close();
 	}
@@ -188,18 +222,20 @@ public class PrepareEventGraphRunInterval {
 	public double distanceTotal; //we pass this because it's dificult to calculate in runs with variable distances
 	public string distancesString; //we pass this because it's dificult to calculate in runs with variable distances
 	public bool startIn;
+	public bool finished;
 
 	public PrepareEventGraphRunInterval() {
 	}
 
 	public PrepareEventGraphRunInterval(double distance, double lastTime, string timesString,
-			double distanceTotal, string distancesString, bool startIn) {
+			double distanceTotal, string distancesString, bool startIn, bool finished) {
 		this.distance = distance;
 		this.lastTime = lastTime;
 		this.timesString = timesString;
 		this.distanceTotal = distanceTotal;
 		this.distancesString = distancesString;
 		this.startIn = startIn;
+		this.finished = finished;
 	}
 
 	~PrepareEventGraphRunInterval() {}
@@ -378,14 +414,14 @@ public class MovingStartButton
 public class MovingBar 
 {
 	public int X;
-	public int Y; 
+	public int Y;  //current value on animation
 	/*
 	 * y will go from (y + alto -speed) to (ytop)
 	 * eg a vertical bar that goes from the bottom to the top, will go from:
 	 * YTop 37, Y 380
 	 * to
 	 * YTop 37, Y 37
-	 * so y will be decreasing
+	 * so it will be decreasing
 	 */
 	
 	public int Width;
@@ -394,20 +430,19 @@ public class MovingBar
 	public int AltoTop; //stored alto value
 	
 	public Gdk.GC Pen_bar_bg;
-	public bool Simulated;
 	public double Result;
 	public int Step;
 	public Pango.Layout Layout;
-	
+
 	public MovingBar(int x, int y, int width, int yTop, int altoTop, 
-			Gdk.GC pen_bar_bg, bool simulated, double result, Pango.Layout layout) {
+			Gdk.GC pen_bar_bg, double result, Pango.Layout layout)
+	{
 		this.X = x;
 		this.Y = y;
 		this.Width = width;
 		this.YTop = yTop;
 		this.AltoTop = altoTop;
 		this.Pen_bar_bg = pen_bar_bg;
-		this.Simulated = simulated;
 		this.Result = result;
 		this.Layout = layout;
 	} 
@@ -419,3 +454,43 @@ public class MovingBar
 
 	~MovingBar() {}
 }
+
+//to store the xStart and xEnd of every encoder or forceSensor capture reptition
+//in order to be saved or not on clicking screen
+//note every rep will be c or ec
+public class RepetitionMouseLimits
+{
+	private List<PointStartEnd> list;
+	private int current;
+
+	public RepetitionMouseLimits()
+	{
+		list = new List<PointStartEnd>();
+		current = 0;
+	}
+
+	public void Add (double start, double end)
+	{
+		PointStartEnd p = new PointStartEnd(current ++, start, end);
+		list.Add(p);
+		LogB.Information("Added: " + p.ToString());
+	}
+
+	public int FindBarInPixel (double pixel)
+	{
+		foreach(PointStartEnd p in list)
+			if(pixel >= p.Start && pixel <= p.End)
+				return p.Id;
+
+		return -1;
+	}
+
+	public double GetStartOfARep(int rep)
+	{
+		return ((PointStartEnd) list[rep]).Start;
+	}
+	public double GetEndOfARep(int rep)
+	{
+		return ((PointStartEnd) list[rep]).End;
+	}
+}
