@@ -15,13 +15,13 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
 using System.Data;
 using System.Text; //StringBuilder
-
+using System.Collections.Generic; //List
 using Mono.Unix;
 
 public class Jump : Event 
@@ -35,12 +35,13 @@ public class Jump : Event
 	//for not checking always in database
 	protected bool hasFall;
 	private double angle;
+	protected string datetime;
 
 	public Jump() {
 	}
 	
 	//after inserting database (SQL)
-	public Jump(int uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weight, string description, double angle, int simulated)
+	public Jump(int uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weight, string description, double angle, int simulated, string datetime)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -53,9 +54,10 @@ public class Jump : Event
 		this.description = description;
 		this.angle = angle;
 		this.simulated = simulated;
+		this.datetime = datetime;
 	}
 
-	//used to select a jump at SqliteJump.SelectNormalJumpData and at Sqlite.converTables
+	//used to select a jump at SqliteJump.SelectJumpData and at Sqlite.converTables
 	public Jump(string [] eventString)
 	{
 		this.uniqueID = Convert.ToInt32(eventString[0]);
@@ -69,8 +71,17 @@ public class Jump : Event
 		this.description = eventString[8].ToString();
 		this.angle = Convert.ToDouble(Util.ChangeDecimalSeparator(eventString[9]));
 		this.simulated = Convert.ToInt32(eventString[10]);
+		this.datetime = eventString[11];
 	}
 
+	public static List<Event> JumpListToEventList(List<Jump> jumps)
+	{
+		List<Event> events = new List<Event>();
+		foreach(Jump jump in jumps)
+			events.Add((Event) jump);
+
+		return events;
+	}
 
 	public override int InsertAtDB (bool dbconOpened, string tableName) {
 		return SqliteJump.Insert(dbconOpened, tableName, 
@@ -78,7 +89,7 @@ public class Jump : Event
 				personID, sessionID, 
 				type, tv, tc, fall, 
 				weight, description, 
-				angle, simulated);
+				angle, simulated, datetime);
 	}
 	
 	public virtual double Stiffness(double personMassInKg, double extraMass) 
@@ -88,7 +99,7 @@ public class Jump : Event
 	
 
 	public override string ToString() {
-		return uniqueID + ":" + personID + ":" + sessionID + ":" + type + ":" + tv + ":" + tc; //...
+		return uniqueID + ":" + personID + ":" + sessionID + ":" + type + ":" + tv + ":" + tc + ":" + datetime + ":" + description;
 	}
 
 	public virtual bool TypeHasWeight {
@@ -123,6 +134,12 @@ public class Jump : Event
 		get { return angle; }
 		set { angle = value; }
 	}
+
+	public string Datetime {
+		get { return datetime; }
+		set { datetime = value; }
+	}
+
 	
 	~Jump() {}
 	   
@@ -144,7 +161,7 @@ public class JumpRj : Jump
 	//after inserting database (SQL)
 	public JumpRj(int uniqueID, int personID, int sessionID, string type, 
 			string tvString, string tcString, double fall, double weight, 
-			string description, int jumps, double time, string limited, string angleString, int simulated)
+			string description, int jumps, double time, string limited, string angleString, int simulated, string datetime)
 	{
 		this.uniqueID = uniqueID;
 		this.personID = personID;
@@ -160,6 +177,7 @@ public class JumpRj : Jump
 		this.limited = limited;
 		this.angleString = angleString;
 		this.simulated = simulated;
+		this.datetime = datetime;
 	}
 	
 	//used to select a jump at SqliteJump.SelectRjJumpData and at Sqlite.convertTables
@@ -182,6 +200,7 @@ public class JumpRj : Jump
 		this.limited = eventString[15];
 		this.angleString = eventString[16];
 		this.simulated = Convert.ToInt32(eventString[17]);
+		this.datetime = eventString[18];
 	}
 	
 
@@ -193,7 +212,7 @@ public class JumpRj : Jump
 				type, TvMax, TcMax, fall, weight,
 				description, TvAvg, TcAvg, tvString, tcString,
 				jumps, time, limited, 
-				angleString, simulated);
+				angleString, simulated, datetime);
 	}
 
 
