@@ -103,14 +103,14 @@ public class Report : ExportSession
 		Sqlite.Open(); // ------------------------------
 		
 		if(ShowSimpleJumps) {
-			myJumps= SqliteJump.SelectJumps(true, sessionID, -1, "", "", 
+			myJumps= SqliteJump.SelectJumpsSA (true, sessionID, -1, "", "",
 					Sqlite.Orders_by.DEFAULT, -1);
 		}
 		if(ShowReactiveJumps) {
 			myJumpsRj = SqliteJumpRj.SelectJumps(true, sessionID, -1, "", "");
 		}
 		if(ShowSimpleRuns) {
-			myRuns= SqliteRun.SelectRuns(true, sessionID, -1, "",
+			myRuns= SqliteRun.SelectRunsSA (true, sessionID, -1, "",
 					Sqlite.Orders_by.DEFAULT, -1);
 		}
 		if (ShowIntervalRuns) {
