@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -60,8 +60,8 @@ class SqliteEncoder : Sqlite
 			"encoderConfiguration TEXT, " +	//text separated by ':'
 		       	"future1 TEXT, " +	//Since 1.4.4 (DB 1.06) this stores last meanPower detected on a curve 
 						//(as string with '.' because future1 was created as TEXT)
-		       	"future2 TEXT, " + 
-		       	"future3 TEXT )";
+			"future2 TEXT, " + 	//same as future1
+			"future3 TEXT )"; 	//same as future1
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -86,12 +86,12 @@ class SqliteEncoder : Sqlite
 			es.exerciseID + ", \"" + es.eccon + "\", \"" +
 			es.LateralityToEnglish() + "\", \"" + Util.ConvertToPoint(es.extraWeight) + "\", \"" +
 			es.signalOrCurve + "\", \"" + es.filename + "\", \"" +
-			removeURLpath(es.url) + "\", " + 
+			Util.MakeURLrelative(es.url) + "\", " +
 			es.time + ", " + es.minHeight + ", \"" + es.description + 
 			"\", \"" + es.status + "\", \"" + 
-			removeURLpath(es.videoURL) + "\", \"" + 
+			Util.MakeURLrelative(es.videoURL) + "\", \"" +
 			es.encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL) + "\", \"" +
-			Util.ConvertToPoint(es.future1) + "\", \"" + es.future2 + "\", \"" + es.future3 + "\")";
+			Util.ConvertToPoint(es.future1) + "\", \"" + Util.ConvertToPoint(es.future2) + "\", \"" + Util.ConvertToPoint(es.future3) + "\")";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -134,16 +134,16 @@ class SqliteEncoder : Sqlite
 				"\", extraWeight = \"" + Util.ConvertToPoint(es.extraWeight) +
 				"\", signalOrCurve = \"" + es.signalOrCurve +
 				"\", filename = \"" + es.filename +
-				"\", url = \"" + removeURLpath(es.url) +
+				"\", url = \"" + Util.MakeURLrelative(es.url) +
 				"\", time = " + es.time +
 				", minHeight = " + es.minHeight +
 				", description = \"" + es.description + 
 				"\", status = \"" + es.status + 
-				"\", videoURL = \"" + removeURLpath(es.videoURL) + 
+				"\", videoURL = \"" + Util.MakeURLrelative(es.videoURL) +
 				"\", encoderConfiguration = \"" + es.encoderConfiguration.ToStringOutput(EncoderConfiguration.Outputs.SQL) +
-				"\", future1 = \"" + Util.ConvertToPoint(es.future1) + 
-				"\", future2 = \"" + es.future2 + 
-				"\", future3 = \"" + es.future3 + 
+				"\", future1 = \"" + Util.ConvertToPoint(es.future1) +
+				"\", future2 = \"" + Util.ConvertToPoint(es.future2) +
+				"\", future3 = \"" + Util.ConvertToPoint(es.future3) +
 				"\" WHERE uniqueID == " + es.uniqueID ;
 
 		LogB.SQL(mycmd.CommandText.ToString());
@@ -208,7 +208,7 @@ class SqliteEncoder : Sqlite
 	//	(to delete them if they are old copies)
 	public static ArrayList Select (
 			bool dbconOpened, int uniqueID, int personID, int sessionID, Constants.EncoderGI encoderGI, 
-			int exerciseID, string signalOrCurve, EncoderSQL.Eccons ecconSelect,
+			int exerciseID, string signalOrCurve, EncoderSQL.Eccons ecconSelect, string lateralityEnglish,
 			bool onlyActive, bool orderIDascendent)
 	{
 		if(! dbconOpened)
@@ -226,14 +226,18 @@ class SqliteEncoder : Sqlite
 		if(exerciseID != -1)
 			exerciseIDStr = " exerciseID = " + exerciseID + " AND ";
 
+		string lateralityEnglishStr = "";
+		if(lateralityEnglish != "")
+			lateralityEnglishStr = " laterality = \"" + lateralityEnglish + "\" AND ";
+
 		string selectStr = "";
 		if(uniqueID != -1)
 			selectStr = Constants.EncoderTable + ".uniqueID = " + uniqueID;
 		else {
 			if(signalOrCurve == "all")
-				selectStr = personIDStr + sessionIDStr + exerciseIDStr;
+				selectStr = personIDStr + sessionIDStr + exerciseIDStr + lateralityEnglishStr;
 			else
-				selectStr = personIDStr + sessionIDStr + exerciseIDStr + " signalOrCurve = \"" + signalOrCurve + "\"";
+				selectStr = personIDStr + sessionIDStr + exerciseIDStr + lateralityEnglishStr + " signalOrCurve = \"" + signalOrCurve + "\"";
 		
 			if(ecconSelect != EncoderSQL.Eccons.ALL)
 				selectStr += " AND " + Constants.EncoderTable + ".eccon = \"" + EncoderSQL.Eccons.ecS.ToString() + "\"";
@@ -290,7 +294,7 @@ class SqliteEncoder : Sqlite
 			//if there's video, will be with full path
 			string videoURL = "";
 			if(reader[14].ToString() != "")
-				videoURL = addURLpath(fixOSpath(reader[14].ToString()));
+				videoURL = Util.MakeURLabsolute(fixOSpath(reader[14].ToString()));
 			
 			//LogB.SQL(econf.ToString(":", true));
 			eSQL = new EncoderSQL (
@@ -303,7 +307,7 @@ class SqliteEncoder : Sqlite
 					Util.ChangeDecimalSeparator(reader[6].ToString()),	//extraWeight
 					reader[7].ToString(),			//signalOrCurve
 					reader[8].ToString(),			//filename
-					addURLpath(fixOSpath(reader[9].ToString())),	//url
+					Util.MakeURLabsolute(fixOSpath(reader[9].ToString())),	//url
 					Convert.ToInt32(reader[10].ToString()),	//time
 					Convert.ToInt32(reader[11].ToString()),	//minHeight
 					reader[12].ToString(),			//description
@@ -311,8 +315,8 @@ class SqliteEncoder : Sqlite
 					videoURL,				//videoURL
 					econf,					//encoderConfiguration
 					Util.ChangeDecimalSeparator(reader[16].ToString()),	//future1 (meanPower on curves)
-					reader[17].ToString(),			//future2
-					reader[18].ToString(),			//future3
+					Util.ChangeDecimalSeparator(reader[17].ToString()),	//future2 (meanSpeed on curves)
+					Util.ChangeDecimalSeparator(reader[18].ToString()),	//future3 (meanForce on curves)
 					reader[19].ToString()			//EncoderExercise.name
 					);
 			array.Add (eSQL);
@@ -471,7 +475,7 @@ class SqliteEncoder : Sqlite
 			Sqlite.Open();
 	
 		dbcmd.CommandText = 
-			"SELECT person77.name, person77.sex, encoder.encoderConfiguration, encoderExercise.name, (personSession77.weight * encoderExercise.percentBodyWeight/100) + encoder.extraWeight, COUNT(*)" +
+			"SELECT person77.uniqueID, person77.name, person77.sex, encoder.encoderConfiguration, encoderExercise.name, (personSession77.weight * encoderExercise.percentBodyWeight/100) + encoder.extraWeight, COUNT(*)" +
 			" FROM person77, personSession77, encoderExercise, encoder" + 
 			" WHERE person77.uniqueID == encoder.personID AND personSession77.personID == encoder.personID AND personSession77.sessionID == encoder.sessionID AND encoderExercise.uniqueID==encoder.exerciseID AND signalOrCurve == \"signal\" AND encoder.sessionID == " + sessionID + 
 			" GROUP BY encoder.personID, exerciseID, extraWeight" +
@@ -486,7 +490,7 @@ class SqliteEncoder : Sqlite
 		while(reader.Read())
 		{
 			//discard if != encoderGI
-			string [] strFull = reader[2].ToString().Split(new char[] {':'});
+			string [] strFull = reader[3].ToString().Split(new char[] {':'});
 			EncoderConfiguration econf = new EncoderConfiguration(
 				(Constants.EncoderConfigurationNames) 
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
@@ -500,19 +504,21 @@ class SqliteEncoder : Sqlite
 			if(encoderGI == Constants.EncoderGI.GRAVITATORY)
 			{
 				string [] s = { 
-					reader[0].ToString(), 	//person name
-					reader[1].ToString(), 	//person sex
-					reader[3].ToString(), 	//encoder exercise name
-					reader[4].ToString(),	//displaced mass (includes percentBodyeight)
-					reader[5].ToString()	//sets count
+					reader[0].ToString(), 	//person uniqueID
+					reader[1].ToString(), 	//person name
+					reader[2].ToString(), 	//person sex
+					reader[4].ToString(), 	//encoder exercise name
+					reader[5].ToString(),	//displaced mass (includes percentBodyeight)
+					reader[6].ToString()	//sets count
 				};
 				array.Add (s);
 			} else {
 				string [] s = { 
-					reader[0].ToString(), 	//person name
-					reader[1].ToString(), 	//person sex
-					reader[3].ToString(), 	//encoder exercise name
-					reader[5].ToString()	//sets count
+					reader[0].ToString(), 	//person uniqueID
+					reader[1].ToString(), 	//person name
+					reader[2].ToString(), 	//person sex
+					reader[4].ToString(), 	//encoder exercise name
+					reader[6].ToString()	//sets count
 				};
 				array.Add (s);
 			}
@@ -531,7 +537,7 @@ class SqliteEncoder : Sqlite
 			Sqlite.Open();
 
 		dbcmd.CommandText =
-			"SELECT person77.name, person77.sex, encoder.encoderConfiguration, encoderExercise.name, encoder.extraWeight, encoder.future1 " +
+			"SELECT person77.uniqueID, person77.name, person77.sex, encoder.encoderConfiguration, encoderExercise.name, encoder.extraWeight, encoder.future1 " + //TODO: future2, future3
 			"FROM person77, encoderExercise, encoder " +
 			"WHERE sessionID = " + sessionID.ToString() +
 		        " AND signalOrCurve = \"curve\" " +
@@ -548,7 +554,7 @@ class SqliteEncoder : Sqlite
 		while(reader.Read())
 		{
 			//discard if != encoderGI
-			string [] strFull = reader[2].ToString().Split(new char[] {':'});
+			string [] strFull = reader[3].ToString().Split(new char[] {':'});
 			EncoderConfiguration econf = new EncoderConfiguration(
 				(Constants.EncoderConfigurationNames)
 				Enum.Parse(typeof(Constants.EncoderConfigurationNames), strFull[0]) );
@@ -562,19 +568,23 @@ class SqliteEncoder : Sqlite
 			if(encoderGI == Constants.EncoderGI.GRAVITATORY)
 			{
 				string [] s = {
-					reader[0].ToString(), 	//person name
-					reader[1].ToString(), 	//person sex
-					reader[3].ToString(), 	//encoder exercise name
-					Util.ChangeDecimalSeparator(reader[4].ToString()),	//extra mass
-					reader[5].ToString()	//power
+					reader[0].ToString(), 	//person uniqueID
+					reader[1].ToString(), 	//person name
+					reader[2].ToString(), 	//person sex
+					reader[4].ToString(), 	//encoder exercise name
+					Util.ChangeDecimalSeparator(reader[5].ToString()),	//extra mass
+					reader[6].ToString()	//power
+						//TODO: speed, force
 				};
 				array.Add (s);
 			} else {
 				string [] s = {
-					reader[0].ToString(), 	//person name
-					reader[1].ToString(), 	//person sex
-					reader[3].ToString(), 	//encoder exercise name
-					reader[5].ToString()	//power
+					reader[0].ToString(), 	//person uniqueID
+					reader[1].ToString(), 	//person name
+					reader[2].ToString(), 	//person sex
+					reader[4].ToString(), 	//encoder exercise name
+					reader[6].ToString()	//power
+						//TODO: speed, force
 				};
 				array.Add (s);
 			}
@@ -599,7 +609,7 @@ class SqliteEncoder : Sqlite
 			"signalID INT, " +
 			"curveID INT, " +
 			"msCentral INT, " +
-			"future1 TEXT )"; //need future2, future3. Better to use alter table here and on encoder table
+			"future1 TEXT )"; //right now unused. need future2, future3. Better to use alter table here and on encoder table
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -690,33 +700,6 @@ class SqliteEncoder : Sqlite
 			Sqlite.Close();
 	}
 	
-	//when select from database, ensure path separators are ok for this platform
-	//useful if person moved database between diff OS
-	private static string fixOSpath(string url) {
-		if(UtilAll.IsWindows())
-			return url.Replace("/","\\");
-		else
-			return url.Replace("\\","/");
-	}
-	//url and videoURL stored path is relative to be able to move data between computers
-	//then SELECT: makes it abolute (addURLpath)
-	//INSERT and UPDATE: makes it relative (removeURLpath)
-	private static string addURLpath(string url) {
-		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
-		if( ! url.StartsWith(parentDir) )
-			url = parentDir + url; 
-
-		return url;
-	}
-	private static string removeURLpath(string url) {
-		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
-		if( url.StartsWith(parentDir) )
-			url = url.Replace(parentDir, ""); 
-
-		return url;
-	}
-
-
 	/*
 	 * EncoderExercise stuff
 	 */
@@ -808,7 +791,26 @@ class SqliteEncoder : Sqlite
 		}
 	}
 
-	public static void UpdateExercise(bool dbconOpened, string nameOld, string name, int percentBodyWeight, 
+	public static void UpdateExercise (bool dbconOpened, EncoderExercise ex)
+	{
+		if(! dbconOpened)
+			Sqlite.Open();
+
+		dbcmd.CommandText = "UPDATE " + Constants.EncoderExerciseTable + " SET" +
+				" name = \"" + ex.Name +
+				"\", percentBodyWeight = " + ex.PercentBodyWeight +
+				", ressistance = \"" + ex.Ressistance +
+				"\", description = \"" + ex.Description +
+				"\", future1 = \"" + Util.ConvertToPoint(ex.Speed1RM) +
+				"\" WHERE uniqueID = " + ex.UniqueID;
+
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+
+		if(! dbconOpened)
+			Sqlite.Close();
+	}
+	public static void UpdateExerciseByName_old_do_not_use(bool dbconOpened, string nameOld, string name, int percentBodyWeight,
 			string ressistance, string description, string speed1RM)
 	{
 		if(! dbconOpened)
@@ -936,7 +938,7 @@ class SqliteEncoder : Sqlite
 		return l;
 	}
 
-	public static ArrayList SelectEncoderRowsOfAnExercise(bool dbconOpened, int exerciseID) 
+	public static ArrayList SelectEncoderSetsOfAnExercise(bool dbconOpened, int exerciseID)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -946,7 +948,8 @@ class SqliteEncoder : Sqlite
 			Constants.SessionTable + ".name, " + 
 			Constants.SessionTable + ".date " + 
 			" FROM " + Constants.EncoderTable + ", " + Constants.PersonTable + ", " + Constants.SessionTable +
-			" WHERE exerciseID == " + exerciseID + 
+			" WHERE exerciseID == " + exerciseID +
+		        " AND signalOrCurve = \"signal\" " +
 			" AND " + Constants.PersonTable + ".uniqueID == " + Constants.EncoderTable + ".personID " +
 		        " AND " + Constants.SessionTable + ".uniqueID == " + Constants.EncoderTable + ".sessionID " + 
 			" GROUP BY sessionID, personID";
