@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -52,10 +52,11 @@ class SqliteJump : Sqlite
 			"weight TEXT, " + //string because can contain "33%" or "50Kg"
 			"description TEXT, " +
 			"angle FLOAT, " + //-1.0 if undef
-			"simulated INT )"; 	//since db: 0.60 (cj 0.8.1.2) simulated = -1, real test (not uploaded to server) = 0, 
+			"simulated INT, " + 	//since db: 0.60 (cj 0.8.1.2) simulated = -1, real test (not uploaded to server) = 0,
 						//positive numbers represent the serverUniqueID
 						//the simulated has two purposes, but it's logical because 
 						//only real tests can be uploaded
+			"datetime TEXT )";
 		dbcmd.ExecuteNonQuery();
 	}
 	
@@ -65,7 +66,7 @@ class SqliteJump : Sqlite
 	 */
 	
 	//public static int Insert(int personID, int sessionID, string type, double tv, double tc, int fall, double weight, string limited, string description, int simulated)
-	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weight, string description, double angle, int simulated)
+	public static int Insert(bool dbconOpened, string tableName, string uniqueID, int personID, int sessionID, string type, double tv, double tc, double fall, double weight, string description, double angle, int simulated, string datetime)
 	{
 		if(! dbconOpened)
 			Sqlite.Open();
@@ -74,12 +75,12 @@ class SqliteJump : Sqlite
 			uniqueID = "NULL";
 
 		dbcmd.CommandText = "INSERT INTO " + tableName +  
-				" (uniqueID, personID, sessionID, type, tv, tc, fall, weight, description, angle, simulated)" +
+				" (uniqueID, personID, sessionID, type, tv, tc, fall, weight, description, angle, simulated, datetime)" +
 				" VALUES (" + uniqueID + ", "
 				+ personID + ", " + sessionID + ", \"" + type + "\", "
 				+ Util.ConvertToPoint(tv) + ", " + Util.ConvertToPoint(tc) + ", " + Util.ConvertToPoint(fall) + ", \"" 
 				+ Util.ConvertToPoint(weight) + "\", \"" + description + "\", "
-				+ Util.ConvertToPoint(angle) + ", " + simulated +")" ;
+				+ Util.ConvertToPoint(angle) + ", " + simulated + ", \"" + datetime + "\")" ;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -95,11 +96,13 @@ class SqliteJump : Sqlite
 		return myLast;
 	}
 
+	//like SelectJumps, but this returns a string[] :( better use below method if possible
 	//if all sessions, put -1 in sessionID
 	//if all persons, put -1 in personID
 	//if all types put, "" in filterType
 	//unlimited put -1 in limit
-	public static string[] SelectJumps(bool dbconOpened, int sessionID, int personID, string filterWeight, string filterType, 
+	//SA for String Array
+	public static string[] SelectJumpsSA (bool dbconOpened, int sessionID, int personID, string filterWeight, string filterType,
 			Orders_by order, int limit) 
 	{
 		if(!dbconOpened)
@@ -155,8 +158,8 @@ class SqliteJump : Sqlite
 		int count = new int();
 		count = 0;
 		
-		while(reader.Read()) {
-
+		while(reader.Read())
+		{
 			myArray.Add (reader[0].ToString() + ":" +	//person.name
 					reader[1].ToString() + ":" +	//jump.uniqueID
 					reader[2].ToString() + ":" + 	//jump.personID
@@ -169,7 +172,8 @@ class SqliteJump : Sqlite
 					reader[9].ToString() + ":" +	//description
 					Util.ChangeDecimalSeparator(reader[10].ToString()) + ":" +	//angle
 					reader[11].ToString() + ":" +	//simulated
-					reader[12].ToString() 		//person.weight
+					reader[12].ToString() + ":" + 	//datetime
+					reader[13].ToString() 		//person.weight
 					);
 			count ++;
 		}
@@ -189,6 +193,81 @@ class SqliteJump : Sqlite
 		return myJumps;
 	}
 
+	/*
+	 * like SelectJumpsSA above method but much better: return list of jumps
+	 * sID -1 means all sessions
+	 * pID -1 means all persons
+	 * jumpType "" means all jumps
+	 * limit -1 means no limit
+	 * personNameInComment is used to be able to display names in graphs
+	 *   because event.PersonName makes individual SQL SELECTs
+	 */
+	public static List<Jump> SelectJumps (int sID, int pID, string jumpType, Orders_by order, int limit, bool personNameInComment)
+	{
+	  //jumps previous to DB 1.82 have no datetime on jump
+	  //find session datetime for that jumps
+	  List<Session> session_l = SqliteSession.SelectAll();
+
+	  //for personNameInComment
+	  List<Person> person_l =
+			SqlitePersonSession.SelectCurrentSessionPersonsAsList(sID);
+
+	  string andString = "";
+	  string sessionString = "";
+	  if(sID != -1)
+	  {
+		  sessionString = " sessionID == " + sID.ToString();
+		  andString = " AND ";
+	  }
+
+	  string personString = "";
+	  if(pID != -1)
+	  {
+		  personString = andString + " personID == " + pID.ToString();
+		  andString = " AND ";
+	  }
+
+	  string jumpTypeString = "";
+	  if(jumpType != "")
+	  {
+		  jumpTypeString = andString + " jump.type = \"" + jumpType + "\" ";
+		  andString = " AND ";
+	  }
+
+	  string whereString = "";
+	  if(sessionString != "" || personString != "" || jumpTypeString != "")
+		  whereString = " WHERE ";
+
+	  string orderByString = " ORDER BY jump.uniqueID ";
+	  if(order == Orders_by.ID_DESC)
+		  orderByString = " ORDER BY jump.uniqueID DESC ";
+
+	  string limitString = "";
+	  if(limit != -1)
+		  limitString = " LIMIT " + limit;
+
+
+	  Sqlite.Open(); //  --------------------
+
+	  // Selecciona les dades de tots els salts
+	  dbcmd.CommandText = "SELECT * FROM jump " +
+		  whereString + sessionString + personString + jumpTypeString +
+		  orderByString + limitString;
+
+	  LogB.SQL(dbcmd.CommandText.ToString());
+	  dbcmd.ExecuteNonQuery();
+
+	  SqliteDataReader reader;
+	  reader = dbcmd.ExecuteReader();
+
+	  List<Jump> jmp_l = DataReaderToJump (reader, session_l, person_l, personNameInComment);
+
+	  reader.Close();
+	  Sqlite.Close(); // --------------------
+
+	  return jmp_l;
+	}
+
 	public static Jump SelectJumpData(int uniqueID, bool dbconOpened)
 	{
 		if(!dbconOpened)
@@ -203,7 +282,7 @@ class SqliteJump : Sqlite
 		reader = dbcmd.ExecuteReader();
 		reader.Read();
 
-		Jump myJump = new Jump(DataReaderToStringArray(reader, 11));
+		Jump myJump = new Jump(DataReaderToStringArray(reader, 12));
 	
 		reader.Close();
 		
@@ -302,6 +381,152 @@ class SqliteJump : Sqlite
 		return l;
 	}
 
+	private static List<Jump> DataReaderToJump (SqliteDataReader reader, List<Session> session_l)
+	{
+		return DataReaderToJump (reader, session_l, new List<Person> (), false);
+	}
+	private static List<Jump> DataReaderToJump (SqliteDataReader reader, List<Session> session_l,
+			List<Person> person_l, bool personNameInComment)
+	{
+	  List<Jump> jmp_l = new List<Jump>();
+	  Jump jmp;
+
+	  LogB.Information("Imprimire Jumps:");
+	  while(reader.Read()) {
+		  jmp = new Jump (
+				  Convert.ToInt32(reader[0].ToString()),              //uniqueID
+				  Convert.ToInt32(reader[1].ToString()),	            //personID
+				  Convert.ToInt32(reader[2].ToString()),	            //sessionID
+				  reader[3].ToString(),                               //type
+				  Convert.ToDouble(Util.ChangeDecimalSeparator(
+						  reader[4].ToString())),                         //tv
+				  Convert.ToDouble(Util.ChangeDecimalSeparator(
+						  reader[5].ToString())),                          //tc
+				  Convert.ToDouble(Util.ChangeDecimalSeparator(
+						  reader[6].ToString())),                          //fall
+				  Convert.ToDouble(Util.ChangeDecimalSeparator(
+						  reader[7].ToString())),                        //weight
+				  reader[8].ToString(),                                // description
+				  Convert.ToDouble(Util.ChangeDecimalSeparator(
+						  reader[9].ToString())),                          //angle
+				  Convert.ToInt32(reader[10].ToString()),              //simulated
+				  reader[11].ToString()                               //datetime
+				 );
+
+		  //jumps previous to DB 1.82 have no datetime on jump
+		  //find session datetime for that jumps
+		  if(jmp.Datetime == "")
+			  foreach(Session session in session_l)
+				  if(session.UniqueID == jmp.SessionID)
+					  jmp.Datetime = UtilDate.ToFile(session.Date);
+
+		  if(personNameInComment)
+			  foreach(Person person in person_l)
+				  if(person.UniqueID == jmp.PersonID)
+					  jmp.Description = person.Name;
+
+
+		  jmp_l.Add(jmp);
+		  LogB.Information(jmp.ToString());
+	  }
+	  return jmp_l;
+	}
+
+	//last boolean: on JumpsDj analyze graph, only show the higher of values of the same fall
+	public static List<Jump> SelectDJ (int pID, int sID, string jumpType, bool onlyHigherOfSameFall)
+	{
+	  //jumps previous to DB 1.82 have no datetime on jump
+	  //find session datetime for that jumps
+	  List<Session> session_l = SqliteSession.SelectAll();
+
+	  string personID = pID.ToString();
+	  string sessionID = sID.ToString();
+
+	  Sqlite.Open();
+
+	  // Selecciona les dades de tots els salts
+	  dbcmd.CommandText = "SELECT * FROM jump WHERE personID = " + personID +
+	  " AND sessionID = " + sessionID  +  " AND jump.type = \"" + jumpType + "\"";
+
+	  if(onlyHigherOfSameFall)
+		  dbcmd.CommandText += " ORDER BY fall DESC, tv DESC";
+
+	  LogB.SQL(dbcmd.CommandText.ToString());
+	  dbcmd.ExecuteNonQuery();
+
+	  SqliteDataReader reader;
+	  reader = dbcmd.ExecuteReader();
+
+	  List<Jump> jmp_l = DataReaderToJump (reader, session_l);
+
+	  reader.Close();
+	  Sqlite.Close();
+
+	  if(onlyHigherOfSameFall)
+	  {
+		  List<Jump> jmp_l_purged = new List<Jump>();
+		  double lastFall = 0;
+		  foreach(Jump j in jmp_l)
+		  {
+			  if(j.Fall != lastFall)
+				  jmp_l_purged.Add(j);
+
+			  lastFall = j.Fall;
+		  }
+		  return jmp_l_purged;
+	  }
+
+	  return jmp_l;
+	}
+
+	//TODO: too similar to above method, unify them
+	//TODO: note we do not want % weight, we want absolute weight so we need to select on personSession77 table
+	public static List<Jump> SelectJumpsWeightFVProfile (int pID, int sID, bool onlyHigherOfSameWeight)
+	{
+	  //jumps previous to DB 1.82 have no datetime on jump
+	  //find session datetime for that jumps
+	  List<Session> session_l = SqliteSession.SelectAll();
+
+	  string personID = pID.ToString();
+	  string sessionID = sID.ToString();
+
+	  Sqlite.Open();
+
+	  // Selecciona les dades de tots els salts
+	  dbcmd.CommandText = "SELECT * FROM jump WHERE personID = " + personID +
+	  " AND sessionID = " + sessionID  +  " AND (jump.type = \"SJ\" OR jump.type = \"SJl\")";
+
+	  if(onlyHigherOfSameWeight)
+		  dbcmd.CommandText += " ORDER BY weight DESC, tv DESC";
+
+	  LogB.SQL(dbcmd.CommandText.ToString());
+	  dbcmd.ExecuteNonQuery();
+
+	  SqliteDataReader reader;
+	  reader = dbcmd.ExecuteReader();
+
+	  List<Jump> jmp_l = DataReaderToJump (reader, session_l);
+
+	  reader.Close();
+	  Sqlite.Close();
+
+	  if(onlyHigherOfSameWeight)
+	  {
+		  LogB.Information("PPPP");
+		  List<Jump> jmp_l_purged = new List<Jump>();
+		  double lastWeight = 0;
+		  foreach(Jump j in jmp_l)
+		  {
+			  if(j.Weight != lastWeight)
+				  jmp_l_purged.Add(j);
+
+			  lastWeight = j.Weight;
+		  }
+		  return jmp_l_purged;
+	  }
+
+	  return jmp_l;
+	}
 
 	public static void Update(int jumpID, string type, string tv, string tc, string fall, int personID, double weight, string description, double angle)
 	{
