@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -47,14 +47,14 @@ class SqlitePersonSession : Sqlite
 			"speciallityID INT, " +
 			"practice INT, " + //also called "level"
 			"comments TEXT, " +
-			"future1 TEXT, " +
-			"future2 TEXT)";
+			"future1 TEXT, " + 	//since Chronojump 2.0 trochanterToe
+			"future2 TEXT)"; 	//since Chronojump 2.0 trochanterFloorOnFlexion
 		dbcmd.ExecuteNonQuery();
 	 }
 
 	public static int Insert(bool dbconOpened, string uniqueID, int personID, int sessionID, 
 			double height, double weight, int sportID, int speciallityID, int practice,
-			string comments) 
+			string comments, double trochanterToe, double trochanterFloorOnFlexion)
 	{
 		if(!dbconOpened)
 			Sqlite.Open();
@@ -71,8 +71,9 @@ class SqlitePersonSession : Sqlite
 		        " VALUES ("
 			+ uniqueID + ", " + personID + ", " + sessionID + ", " + 
 			Util.ConvertToPoint(height) + ", " + Util.ConvertToPoint(weight) + ", " +
-			sportID + ", " + speciallityID + ", " + practice + ", \"" + 
-			comments + "\", \"\", \"\")"; 
+			sportID + ", " + speciallityID + ", " + practice + ", \"" + comments + "\", " +
+			Util.ConvertToPoint(trochanterToe) + ", " +
+			Util.ConvertToPoint(trochanterFloorOnFlexion) + ")";
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 
@@ -152,7 +153,9 @@ class SqlitePersonSession : Sqlite
 			", speciallityID = " + ps.SpeciallityID + 
 			", practice = " + ps.Practice + 
 			", comments = \"" + ps.Comments + 
-			"\" WHERE uniqueID == " + ps.UniqueID;
+			"\", future1 = " + Util.ConvertToPoint(ps.TrochanterToe) +
+			", future2 = " + Util.ConvertToPoint(ps.TrochanterFloorOnFlexion) +
+			" WHERE uniqueID == " + ps.UniqueID;
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
 		Sqlite.Close();
@@ -172,9 +175,11 @@ class SqlitePersonSession : Sqlite
 		Sqlite.Close();
 	}
 
-	public static bool PersonSelectExistsInSession(int myPersonID, int mySessionID)
+	public static bool PersonSelectExistsInSession(bool dbconOpened, int myPersonID, int mySessionID)
 	{
-		Sqlite.Open();
+		if(! dbconOpened)
+			Sqlite.Open();
+
 		dbcmd.CommandText = "SELECT * FROM " + Constants.PersonSessionTable +
 			" WHERE personID == " + myPersonID + 
 			" AND sessionID == " + mySessionID ; 
@@ -190,7 +195,10 @@ class SqlitePersonSession : Sqlite
 			exists = true;
 
 		reader.Close();
-		Sqlite.Close();
+
+		if(! dbconOpened)
+			Sqlite.Close();
+
 		return exists;
 	}
 
@@ -236,7 +244,9 @@ class SqlitePersonSession : Sqlite
 					Convert.ToInt32(reader[5].ToString()), 	//sportID
 					Convert.ToInt32(reader[6].ToString()), 	//speciallityID
 					Convert.ToInt32(reader[7].ToString()),	//practice
-					reader[8].ToString() 			//comments
+					reader[8].ToString(), 			//comments
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[9].ToString())), //trochanterToe
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[10].ToString())) //trochanterFloorOnFlexion
 					); 
 		}
 		
@@ -247,7 +257,50 @@ class SqlitePersonSession : Sqlite
 
 		return ps;
 	}
-	
+
+	//sessionID can be -1
+	//TODO: add the sessionID -1 code
+	public static List<Person> SelectCurrentSessionPersonsAsList (int sessionID)
+	{
+		string tp = Constants.PersonTable;
+		string tps = Constants.PersonSessionTable;
+
+		string tpsString = "";
+
+		Sqlite.Open();
+		dbcmd.CommandText = "SELECT " + tp + ".*" +
+			" FROM " + tp + ", " + tps +
+			" WHERE " + tps + ".sessionID == " + sessionID +
+			" AND " + tp + ".uniqueID == " + tps + ".personID " +
+			" ORDER BY upper(" + tp + ".name)";
+		LogB.SQL(dbcmd.CommandText.ToString());
+		dbcmd.ExecuteNonQuery();
+		SqliteDataReader reader;
+		reader = dbcmd.ExecuteReader();
+
+		List<Person> person_l = new List<Person>();
+		while(reader.Read())
+		{
+			Person person = new Person(
+					Convert.ToInt32(reader[0].ToString()),	//uniqueID
+					reader[1].ToString(),			//name
+					reader[2].ToString(),			//sex
+					UtilDate.FromSql(reader[3].ToString()),	//dateBorn
+					Convert.ToInt32(reader[4].ToString()),	//race
+					Convert.ToInt32(reader[5].ToString()),	//countryID
+					reader[6].ToString(),			//description
+					reader[7].ToString(),			//future1: rfid
+					reader[8].ToString(),			//future2: clubID
+					Convert.ToInt32(reader[9].ToString())	//serverUniqueID
+					);
+			person_l.Add(person);
+		}
+
+		reader.Close();
+		Sqlite.Close();
+
+		return person_l;
+	}
 	//the difference between this select and others, is that this returns and ArrayList of Persons
 	//this is better than return the strings that can produce bugs in the future
 	//use this in the future:
@@ -282,6 +335,7 @@ class SqlitePersonSession : Sqlite
 					Convert.ToInt32(reader[5].ToString()),	//countryID
 					reader[6].ToString(),			//description
 					reader[7].ToString(),			//future1: rfid
+					reader[8].ToString(),			//future2: clubID
 					Convert.ToInt32(reader[9].ToString())	//serverUniqueID
 					);
 
@@ -295,7 +349,9 @@ class SqlitePersonSession : Sqlite
 						Convert.ToInt32(reader[15].ToString()), 	//sportID
 						Convert.ToInt32(reader[16].ToString()), 	//speciallityID
 						Convert.ToInt32(reader[17].ToString()),	//practice
-						reader[18].ToString() 			//comments
+						reader[18].ToString(), 			//comments
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[19].ToString())), //trochanterToe
+						Convert.ToDouble(Util.ChangeDecimalSeparator(reader[20].ToString())) //trochanterFloorOnFlexion
 						);
 				myArray.Add(new PersonAndPS(person, ps));
 				
@@ -333,7 +389,9 @@ class SqlitePersonSession : Sqlite
 					Convert.ToInt32(reader[5].ToString()), 	//sportID
 					Convert.ToInt32(reader[6].ToString()), 	//speciallityID
 					Convert.ToInt32(reader[7].ToString()),	//practice
-					reader[8].ToString() 			//comments
+					reader[8].ToString(), 			//comments
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[9].ToString())), //trochanterToe
+					Convert.ToDouble(Util.ChangeDecimalSeparator(reader[10].ToString())) //trochanterFloorOnFlexion
 					);
 			list.Add(ps);
 		}
@@ -422,7 +480,7 @@ class SqlitePersonSession : Sqlite
 		//delete encoder signal and curves (and it's videos)
 		ArrayList encoderArray = SqliteEncoder.Select(
 				true, -1, Convert.ToInt32(personID), Convert.ToInt32(sessionID), Constants.EncoderGI.ALL,
-				-1, "signal", EncoderSQL.Eccons.ALL,
+				-1, "signal", EncoderSQL.Eccons.ALL, "",
 				false, true);
 
 		foreach(EncoderSQL eSQL in encoderArray) {
@@ -434,7 +492,7 @@ class SqlitePersonSession : Sqlite
 
 		encoderArray = SqliteEncoder.Select(
 				true, -1, Convert.ToInt32(personID), Convert.ToInt32(sessionID), Constants.EncoderGI.ALL,
-				-1, "curve", EncoderSQL.Eccons.ALL, 
+				-1, "curve", EncoderSQL.Eccons.ALL, "",
 				false, true);
 		
 		foreach(EncoderSQL eSQL in encoderArray) {
