@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -27,6 +27,16 @@ using System.Collections; //ArrayList
 
 class SqlitePreferences : Sqlite
 {
+	public const string UnitsStr = "units";
+	public const string MenuType = "menuType";
+	public const string ColorBackground = "colorBackground";
+	public const string LogoAnimatedShow = "logoAnimatedShow";
+
+	//contacts
+	public const string JumpsDjGraphHeights = "jumpsDjGraphHeights";
+
+	//encoder
+	public const string EncoderCaptureInfinite = "encoderCaptureInfinite";
 	public const string EncoderExerciseIDGravitatory = "encoderExerciseIDGravitatory";
 	public const string EncoderExerciseIDInertial = "encoderExerciseIDInertial";
 	public const string EncoderContractionGravitatory = "encoderContractionGravitatory";
@@ -36,11 +46,8 @@ class SqlitePreferences : Sqlite
 	public const string EncoderMassGravitatory = "encoderMassGravitatory";
 	public const string EncoderWeightsInertial = "encoderWeightsInertial";
 
-	public const string ForceSensorTareDateTimeStr = "forceSensorTareDateTime";
-	public const string ForceSensorTareStr = "forceSensorTare";
-	public const string ForceSensorCalibrationDateTimeStr = "forceSensorCalibrationDateTime";
-	public const string ForceSensorCalibrationWeightStr = "forceSensorCalibrationWeight";
-	public const string ForceSensorCalibrationFactorStr = "forceSensorCalibrationFactor";
+	public const string EncoderAutoSaveCurveBestNValue = "encoderAutoSaveCurveBestNValue";
+	public const string EncoderWorkKcal = "encoderWorkKcal";
 
 	public const string EncoderRhythmActiveStr = "encoderRhythmActive";
 	public const string EncoderRhythmRepsOrPhasesStr = "encoderRhythmRepsOrPhases";
@@ -51,6 +58,40 @@ class SqlitePreferences : Sqlite
 	public const string EncoderRhythmRestAfterEccStr = "encoderRhythmRestAfterEcc";
 	public const string EncoderRhythmRepsClusterStr = "encoderRhythmRepsCluster";
 	public const string EncoderRhythmRestClustersSecondsStr = "encoderRhythmRestClustersSeconds";
+	public const string EncoderCaptureMainVariableThisSetOrHistorical = "encoderCaptureMainVariableThisSetOrHistorical";
+	public const string EncoderCaptureMainVariableGreaterActive = "encoderCaptureMainVariableGreaterActive";
+	public const string EncoderCaptureMainVariableGreaterValue = "encoderCaptureMainVariableGreaterValue";
+	public const string EncoderCaptureMainVariableLowerActive = "encoderCaptureMainVariableLowerActive";
+	public const string EncoderCaptureMainVariableLowerValue = "encoderCaptureMainVariableLowerValue";
+	public const string EncoderCaptureFeedbackEccon = "encoderCaptureFeedbackEccon";
+	public const string EncoderCaptureInertialEccOverloadMode = "encoderCaptureInertialEccOverloadMode";
+
+	//forceSensor
+	public const string ForceSensorCaptureWidthSeconds = "forceSensorCaptureWidthSeconds";
+	public const string ForceSensorCaptureScroll = "forceSensorCaptureScroll";
+	public const string ForceSensorElasticEccMinDispl = "forceSensorElasticEccMinDispl";
+	public const string ForceSensorElasticConMinDispl = "forceSensorElasticConMinDispl";
+	public const string ForceSensorNotElasticEccMinForce = "forceSensorNotElasticEccMinForce";
+	public const string ForceSensorNotElasticConMinForce = "forceSensorNotElasticConMinForce";
+	public const string ForceSensorGraphsLineWidth = "forceSensorGraphsLineWidth";
+
+	public const string ForceSensorTareDateTimeStr = "forceSensorTareDateTime";
+	public const string ForceSensorTareStr = "forceSensorTare";
+	public const string ForceSensorCalibrationDateTimeStr = "forceSensorCalibrationDateTime";
+	public const string ForceSensorCalibrationWeightStr = "forceSensorCalibrationWeight";
+	public const string ForceSensorCalibrationFactorStr = "forceSensorCalibrationFactor";
+	public const string ForceSensorCaptureFeedbackActive = "forceSensorCaptureFeedbackActive";
+	public const string ForceSensorCaptureFeedbackAt = "forceSensorCaptureFeedbackAt";
+	public const string ForceSensorCaptureFeedbackRange = "forceSensorCaptureFeedbackRange";
+	public const string ForceSensorMIFDurationMode = "forceSensorMIFDurationMode";
+	public const string ForceSensorMIFDurationSeconds = "forceSensorMIFDurationSeconds";
+	public const string ForceSensorMIFDurationPercent = "forceSensorMIFDurationPercent";
+
+	//runEncoder
+	public const string RunEncoderMinAccel = "runEncoderMinAccel";
+
+	//advanced
+	public const string ImporterPythonVersion = "importerPythonVersion";
 
 	protected internal static new void createTable()
 	{
@@ -80,6 +121,11 @@ class SqlitePreferences : Sqlite
 				Insert ("maximized", Preferences.MaximizedTypes.NO.ToString(), dbcmdTr);
 				Insert ("personWinHide", "False", dbcmdTr);
 				Insert ("personPhoto", "True", dbcmdTr);
+				Insert (MenuType, Preferences.MenuTypes.ALL.ToString(), dbcmdTr);
+				Insert (LogoAnimatedShow, "True", dbcmdTr);
+				Insert (ColorBackground, "#0e1e46", dbcmdTr);
+				Insert (UnitsStr, Preferences.UnitsEnum.METRIC.ToString(), dbcmdTr);
+				Insert (EncoderCaptureInfinite, "False", dbcmdTr);
 				Insert ("encoderCaptureShowOnlyBars", "False", dbcmdTr);
 				Insert ("encoderCaptureShowNRepetitions", "-1", dbcmdTr);
 				Insert ("digitsNumber", "3", dbcmdTr);
@@ -89,6 +135,7 @@ class SqlitePreferences : Sqlite
 				Insert ("showAngle", "False", dbcmdTr); //for treeviewjumps
 				Insert ("showQIndex", "False", dbcmdTr); //for treeviewJumps
 				Insert ("showDjIndex", "False", dbcmdTr); //for treeviewJumps
+				Insert (JumpsDjGraphHeights, "True", dbcmdTr);
 				Insert ("simulated", "True", dbcmdTr);
 				Insert ("weightStatsPercent", "False", dbcmdTr);
 				Insert ("askDeletion", "True", dbcmdTr);
@@ -97,8 +144,16 @@ class SqlitePreferences : Sqlite
 				Insert ("language", "", dbcmdTr); 
 				Insert ("crashLogLanguage", "", dbcmdTr);
 				Insert ("allowFinishRjAfterTime", "True", dbcmdTr); 
-				Insert ("volumeOn", "True", dbcmdTr); 
-				Insert (Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_0_1.ToString(), dbcmdTr);
+				Insert ("volumeOn", "True", dbcmdTr);
+
+				UtilAll.OperatingSystems os = UtilAll.GetOSEnum();
+				if(os == UtilAll.OperatingSystems.WINDOWS)
+					Insert (Preferences.GstreamerStr, Preferences.GstreamerTypes.SYSTEMSOUNDS.ToString());
+				else if(os == UtilAll.OperatingSystems.MACOSX)
+					Insert (Preferences.GstreamerStr, Preferences.GstreamerTypes.FFPLAY.ToString(), dbcmdTr);
+				else
+					Insert (Preferences.GstreamerStr, Preferences.GstreamerTypes.GST_1_0.ToString(), dbcmdTr);
+
 				Insert ("videoOn", "True", dbcmdTr); 
 				Insert ("evaluatorServerID", "-1", dbcmdTr);
 				Insert ("versionAvailable", "", dbcmdTr);
@@ -125,6 +180,15 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderCaptureTime", "60", dbcmdTr);
 				Insert ("encoderCaptureInactivityEndTime", "3", dbcmdTr);
 				Insert ("encoderCaptureMainVariable", Constants.EncoderVariablesCapture.MeanPower.ToString(), dbcmdTr);
+				Insert ("encoderCaptureSecondaryVariable", Constants.EncoderVariablesCapture.RangeAbsolute.ToString(), dbcmdTr);
+				Insert ("encoderCaptureSecondaryVariableShow", "True", dbcmdTr);
+				Insert (EncoderCaptureFeedbackEccon, Preferences.EncoderPhasesEnum.BOTH.ToString(), dbcmdTr);
+				Insert (EncoderCaptureInertialEccOverloadMode, Preferences.encoderCaptureEccOverloadModes.SHOW_LINE.ToString(), dbcmdTr);
+				Insert (EncoderCaptureMainVariableThisSetOrHistorical, "True", dbcmdTr);
+				Insert (EncoderCaptureMainVariableGreaterActive, "False", dbcmdTr);
+				Insert (EncoderCaptureMainVariableGreaterValue, "90", dbcmdTr);
+				Insert (EncoderCaptureMainVariableLowerActive, "False", dbcmdTr);
+				Insert (EncoderCaptureMainVariableLowerValue, "70", dbcmdTr);
 				Insert ("encoderCaptureMinHeightGravitatory", "20", dbcmdTr);
 				Insert ("encoderCaptureMinHeightInertial", "5", dbcmdTr);
 				Insert ("encoderCaptureInertialDiscardFirstN", "3", dbcmdTr);
@@ -134,6 +198,8 @@ class SqlitePreferences : Sqlite
 				Insert ("encoderShowStartAndDuration", "False", dbcmdTr);
 				Insert ("encoderCaptureCutByTriggers", Preferences.TriggerTypes.NO_TRIGGERS.ToString(), dbcmdTr);
 				Insert ("encoderPropulsive", "True", dbcmdTr);
+				Insert (EncoderWorkKcal, "True", dbcmdTr);
+				Insert ("encoderWorkKcal", "True", dbcmdTr);
 				Insert ("encoderSmoothEccCon", "0.6", dbcmdTr);
 				Insert ("encoderSmoothCon", "0.7", dbcmdTr);
 				Insert ("encoder1RMMethod", Constants.Encoder1RMMethod.WEIGHTED2.ToString(), dbcmdTr);
@@ -170,24 +236,54 @@ class SqlitePreferences : Sqlite
 				Insert (EncoderRhythmRepsClusterStr, Util.ConvertToPoint(er.RepsCluster), dbcmdTr);
 				Insert (EncoderRhythmRestClustersSecondsStr, Util.ConvertToPoint(er.RestClustersSeconds), dbcmdTr);
 
-
-				Insert ("videoDevice", "", dbcmdTr); //first
-				Insert ("videoDevicePixelFormat", "", dbcmdTr);
-				Insert ("videoDeviceResolution", "", dbcmdTr);
-				Insert ("videoDeviceFramerate", "", dbcmdTr);
-				Insert ("videoStopAfter", "2", dbcmdTr);
-				Insert ("inertialmomentum", "0.01", dbcmdTr);
-				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
-				Insert ("RGraphsTranslate", "True", dbcmdTr);
-				Insert ("useHeightsOnJumpIndexes", "True", dbcmdTr);
-				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), dbcmdTr); 
-				Insert ("email", "", dbcmdTr);
-				Insert ("muteLogs", "False", dbcmdTr);
+				//forceSensor
+				Insert (ForceSensorCaptureWidthSeconds, "10", dbcmdTr);
+				Insert (ForceSensorCaptureScroll, "True", dbcmdTr); //scroll. not zoom out
+				Insert (ForceSensorElasticEccMinDispl, ".1", dbcmdTr);
+				Insert (ForceSensorElasticConMinDispl, ".1", dbcmdTr);
+				Insert (ForceSensorNotElasticEccMinForce, "100", dbcmdTr);
+				Insert (ForceSensorNotElasticConMinForce, "100", dbcmdTr);
+				Insert (ForceSensorGraphsLineWidth, "2", dbcmdTr);
+				Insert (ForceSensorCaptureFeedbackActive, "False", dbcmdTr);
+				Insert (ForceSensorCaptureFeedbackAt, "100", dbcmdTr);
+				Insert (ForceSensorCaptureFeedbackRange, "40", dbcmdTr);
 				Insert (ForceSensorTareDateTimeStr, "", dbcmdTr);
 				Insert (ForceSensorTareStr, "-1", dbcmdTr); //result value from sensor. Decimal is point!!
 				Insert (ForceSensorCalibrationDateTimeStr, "", dbcmdTr);
 				Insert (ForceSensorCalibrationWeightStr, "-1", dbcmdTr);
 				Insert (ForceSensorCalibrationFactorStr, "-1", dbcmdTr); //result value from sensor. Decimal is point!!
+				Insert (ForceSensorMIFDurationMode, Preferences.ForceSensorMIFDurationModes.SECONDS.ToString(), dbcmdTr);
+				Insert (ForceSensorMIFDurationSeconds, "2", dbcmdTr);
+				Insert (ForceSensorMIFDurationPercent, "5", dbcmdTr);
+
+				//runEncoder
+				Insert (RunEncoderMinAccel, "10.0", dbcmdTr);
+
+				Insert (Preferences.runEncoderAnalyzeAccel.Name,
+					Preferences.runEncoderAnalyzeAccel.SqlDefaultName, dbcmdTr);
+				Insert (Preferences.runEncoderAnalyzeForce.Name,
+					Preferences.runEncoderAnalyzeForce.SqlDefaultName, dbcmdTr);
+				Insert (Preferences.runEncoderAnalyzePower.Name,
+					Preferences.runEncoderAnalyzePower.SqlDefaultName, dbcmdTr);
+
+				//multimedia
+				Insert ("videoDevice", "", dbcmdTr); //first
+				Insert ("videoDevicePixelFormat", "", dbcmdTr);
+				Insert ("videoDeviceResolution", "", dbcmdTr);
+				Insert ("videoDeviceFramerate", "", dbcmdTr);
+				Insert ("videoStopAfter", "2", dbcmdTr);
+
+				//other
+				Insert ("inertialmomentum", "0.01", dbcmdTr);
+				Insert ("CSVExportDecimalSeparator", Util.GetDecimalSeparatorFromLocale(), dbcmdTr);
+				Insert ("RGraphsTranslate", "True", dbcmdTr);
+				Insert ("useHeightsOnJumpIndexes", "True", dbcmdTr);
+				Insert ("encoderAutoSaveCurve", Constants.EncoderAutoSaveCurve.BEST.ToString(), dbcmdTr); 
+				Insert (EncoderAutoSaveCurveBestNValue, "3", dbcmdTr);
+				Insert ("email", "", dbcmdTr);
+				Insert ("muteLogs", "False", dbcmdTr);
+				Insert (ImporterPythonVersion, Preferences.pythonVersionEnum.Python.ToString(), dbcmdTr);
+
 				
 				//removed on 1.37
 				//Insert ("encoderConfiguration", new EncoderConfiguration().ToStringOutput(EncoderConfiguration.Outputs.SQL), dbcmdTr);
@@ -288,6 +384,21 @@ class SqlitePreferences : Sqlite
 				preferences.personWinHide = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "personPhoto")
 				preferences.personPhoto = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == MenuType)
+				preferences.menuType = (Preferences.MenuTypes)
+					Enum.Parse(typeof(Preferences.MenuTypes), reader[1].ToString());
+			else if(reader[0].ToString() == ColorBackground)
+			{
+				preferences.colorBackgroundString = reader[1].ToString();
+				preferences.colorBackgroundIsDark = UtilGtk.ColorIsDark(reader[1].ToString());
+			}
+			else if(reader[0].ToString() == LogoAnimatedShow)
+				preferences.logoAnimatedShow = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == UnitsStr)
+				preferences.units = (Preferences.UnitsEnum)
+					Enum.Parse(typeof(Preferences.UnitsEnum), reader[1].ToString());
+			else if(reader[0].ToString() == EncoderCaptureInfinite)
+				preferences.encoderCaptureInfinite = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureShowOnlyBars")
 				preferences.encoderCaptureShowOnlyBars = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderCaptureShowNRepetitions")
@@ -304,6 +415,8 @@ class SqlitePreferences : Sqlite
 				preferences.showQIndex = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "showDjIndex")
 				preferences.showDjIndex = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == JumpsDjGraphHeights)
+				preferences.jumpsDjGraphHeights = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "weightStatsPercent")
 				preferences.weightStatsPercent = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "heightPreferred")
@@ -318,6 +431,27 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "encoderCaptureMainVariable")
 				preferences.encoderCaptureMainVariable = (Constants.EncoderVariablesCapture) 
 					Enum.Parse(typeof(Constants.EncoderVariablesCapture), reader[1].ToString()); 
+			else if(reader[0].ToString() == "encoderCaptureSecondaryVariable")
+				preferences.encoderCaptureSecondaryVariable = (Constants.EncoderVariablesCapture)
+					Enum.Parse(typeof(Constants.EncoderVariablesCapture), reader[1].ToString());
+			else if(reader[0].ToString() == "encoderCaptureSecondaryVariableShow")
+				preferences.encoderCaptureSecondaryVariableShow = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == EncoderCaptureFeedbackEccon)
+				preferences.encoderCaptureFeedbackEccon = (Preferences.EncoderPhasesEnum)
+					Enum.Parse(typeof(Preferences.EncoderPhasesEnum), reader[1].ToString());
+			else if(reader[0].ToString() == EncoderCaptureInertialEccOverloadMode)
+				preferences.encoderCaptureInertialEccOverloadMode = (Preferences.encoderCaptureEccOverloadModes)
+					Enum.Parse(typeof(Preferences.encoderCaptureEccOverloadModes), reader[1].ToString());
+			else if(reader[0].ToString() == EncoderCaptureMainVariableThisSetOrHistorical)
+				preferences.encoderCaptureMainVariableThisSetOrHistorical = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == EncoderCaptureMainVariableGreaterActive)
+				preferences.encoderCaptureMainVariableGreaterActive = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == EncoderCaptureMainVariableGreaterValue)
+				preferences.encoderCaptureMainVariableGreaterValue = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == EncoderCaptureMainVariableLowerActive)
+				preferences.encoderCaptureMainVariableLowerActive = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == EncoderCaptureMainVariableLowerValue)
+				preferences.encoderCaptureMainVariableLowerValue = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderCaptureMinHeightGravitatory")
 				preferences.encoderCaptureMinHeightGravitatory = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderCaptureMinHeightInertial")
@@ -331,6 +465,8 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "encoderAutoSaveCurve")
 				preferences.encoderAutoSaveCurve = (Constants.EncoderAutoSaveCurve) 
 					Enum.Parse(typeof(Constants.EncoderAutoSaveCurve), reader[1].ToString()); 
+			else if(reader[0].ToString() == EncoderAutoSaveCurveBestNValue)
+				preferences.encoderAutoSaveCurveBestNValue = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderCaptureBarplotFontSize")
 				preferences.encoderCaptureBarplotFontSize = Convert.ToInt32(reader[1].ToString());
 			else if(reader[0].ToString() == "encoderShowStartAndDuration")
@@ -341,6 +477,8 @@ class SqlitePreferences : Sqlite
 			//encoder other
 			else if(reader[0].ToString() == "encoderPropulsive")
 				preferences.encoderPropulsive = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == EncoderWorkKcal)
+				preferences.encoderWorkKcal = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "encoderSmoothCon")
 				preferences.encoderSmoothCon = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
@@ -399,8 +537,16 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "volumeOn")
 				preferences.volumeOn = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == Preferences.GstreamerStr)
+			{
 				preferences.gstreamer = (Preferences.GstreamerTypes)
 					Enum.Parse(typeof(Preferences.GstreamerTypes), reader[1].ToString());
+
+				//on 2.0 gstreamer is disabled on mac
+				if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX && (
+						preferences.gstreamer == Preferences.GstreamerTypes.GST_0_1 ||
+						preferences.gstreamer == Preferences.GstreamerTypes.GST_1_0 ) )
+					preferences.gstreamer = Preferences.GstreamerTypes.FFPLAY;
+			}
 			else if(reader[0].ToString() == "videoOn")
 				preferences.videoOn = reader[1].ToString() == "True";
 			else if(reader[0].ToString() == "evaluatorServerID")
@@ -426,6 +572,30 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "thresholdOther")
 				preferences.thresholdOther = Convert.ToInt32(reader[1].ToString());
 
+			//force sensor capture
+			else if(reader[0].ToString() == ForceSensorCaptureWidthSeconds)
+				preferences.forceSensorCaptureWidthSeconds = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorCaptureScroll)
+				preferences.forceSensorCaptureScroll = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == ForceSensorElasticEccMinDispl)
+				preferences.forceSensorElasticEccMinDispl = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == ForceSensorElasticConMinDispl)
+				preferences.forceSensorElasticConMinDispl = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == ForceSensorNotElasticEccMinForce)
+				preferences.forceSensorNotElasticEccMinForce = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorNotElasticConMinForce)
+				preferences.forceSensorNotElasticConMinForce = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorGraphsLineWidth)
+				preferences.forceSensorGraphsLineWidth = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorCaptureFeedbackActive)
+				preferences.forceSensorCaptureFeedbackActive = reader[1].ToString() == "True";
+			else if(reader[0].ToString() == ForceSensorCaptureFeedbackAt)
+				preferences.forceSensorCaptureFeedbackAt = Convert.ToInt32(reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorCaptureFeedbackRange)
+				preferences.forceSensorCaptureFeedbackRange = Convert.ToInt32(reader[1].ToString());
+
 			//force sensor tare
 			else if(reader[0].ToString() == ForceSensorTareDateTimeStr)
 				preferences.forceSensorTareDateTime = reader[1].ToString();
@@ -443,6 +613,29 @@ class SqlitePreferences : Sqlite
 				preferences.forceSensorCalibrationFactor = Convert.ToDouble(
 						Util.ChangeDecimalSeparator(reader[1].ToString()));
 
+			//force sensor MIF
+			else if(reader[0].ToString() == ForceSensorMIFDurationMode)
+				preferences.forceSensorMIFDurationMode = (Preferences.ForceSensorMIFDurationModes)
+					Enum.Parse(typeof(Preferences.ForceSensorMIFDurationModes), reader[1].ToString());
+			else if(reader[0].ToString() == ForceSensorMIFDurationSeconds)
+				preferences.forceSensorMIFDurationSeconds = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+			else if(reader[0].ToString() == ForceSensorMIFDurationPercent)
+				preferences.forceSensorMIFDurationPercent = Convert.ToInt32(
+						reader[1].ToString());
+
+			//runEncoder
+			else if(reader[0].ToString() == RunEncoderMinAccel)
+				preferences.runEncoderMinAccel = Convert.ToDouble(
+						Util.ChangeDecimalSeparator(reader[1].ToString()));
+
+			else if(reader[0].ToString() == Preferences.runEncoderAnalyzeAccel.Name)
+				Preferences.runEncoderAnalyzeAccel.SetCurrentFromSQL(reader[1].ToString());
+			else if(reader[0].ToString() == Preferences.runEncoderAnalyzeForce.Name)
+				Preferences.runEncoderAnalyzeForce.SetCurrentFromSQL(reader[1].ToString());
+			else if(reader[0].ToString() == Preferences.runEncoderAnalyzePower.Name)
+				Preferences.runEncoderAnalyzePower.SetCurrentFromSQL(reader[1].ToString());
+
 			//advanced tab
 			else if(reader[0].ToString() == "digitsNumber")
 				preferences.digitsNumber = Convert.ToInt32(reader[1].ToString());
@@ -455,6 +648,9 @@ class SqlitePreferences : Sqlite
 			else if(reader[0].ToString() == "multimediaStorage")
 				preferences.multimediaStorage = (Constants.MultimediaStorage) 
 					Enum.Parse(typeof(Constants.MultimediaStorage), reader[1].ToString()); 
+			else if(reader[0].ToString() == ImporterPythonVersion)
+				preferences.importerPythonVersion = (Preferences.pythonVersionEnum)
+					Enum.Parse(typeof(Preferences.pythonVersionEnum), reader[1].ToString());
 			else if(reader[0].ToString() == "databaseVersion")
 				preferences.databaseVersion = reader[1].ToString();
 		}
