@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- * Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ * Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -38,13 +38,17 @@ public class SqliteSessionSwitcher
 	* Doing this SessionLoadWindow can display sessions from other databases when SessionLoadWindow
 	* is used to import sessions from another Chronojump database instead of displaying sessions of the current
 	* database.
+	*
+	* on import we want to hide simulated, because we do not want to see that session
+	* on export we want to show it to delete it and all its tests
 	*/
 	private string databasePath;
 	private DatabaseType type;
 	public enum DatabaseType
 	{
 		DEFAULT,
-		SPECIFIC
+		IMPORT,
+		EXPORT
 	};
 	
 	public SqliteSessionSwitcher(DatabaseType type, string databasePath)
@@ -70,13 +74,14 @@ public class SqliteSessionSwitcher
 
 			string[] allSessions = SqliteSession.SelectAllSessions (filterName, dbcon);
 
-			// Filtered sessions will contain all sessions but not the "SIMULATED"
+			// on IMPORT, filtered sessions will contain all sessions but not the "SIMULATED"
 			List<string> filteredSessions = new List<string> ();
+			foreach(string session in allSessions)
+			{
+				if (type == DatabaseType.IMPORT && session.Split (':') [1] == "SIMULATED")
+					continue;
 
-			foreach(string session in allSessions) {
-				if (session.Split (':') [1] != "SIMULATED") {
-					filteredSessions.Add (session);
-				}
+				filteredSessions.Add (session);
 			}
 
 			return filteredSessions.ToArray();
@@ -115,6 +120,7 @@ public class SqliteSessionSwitcher
 				values[7] = reader[7].ToString();
 				values[8] = reader[8].ToString();
 			}
+			reader.Close();
 
 			Session mySession = new Session(values[0], 
 			                                values[1], values[2], UtilDate.FromSql(values[3]), 
@@ -124,6 +130,22 @@ public class SqliteSessionSwitcher
 			return mySession;
 		}
 	}
+
+	//for export session
+	//TODO; at the moment use the above string[] SelectAllSessions(string filterName)
+	/*
+	public List<Session> SelectAll()
+	{
+	}
+	*/
+
+	public void DeleteAllStuff(string sessionID)
+	{
+		SqliteGeneral sqliteGeneral = new SqliteGeneral(databasePath);
+		SqliteConnection dbcon = sqliteGeneral.connection;
+
+		SqliteSession.DeleteAllStuff (sessionID, dbcon);
+	}
 }
 
 class SqliteSession : Sqlite
@@ -222,21 +244,39 @@ class SqliteSession : Sqlite
 			Sqlite.Close();
 	}
 
+	// ---- use this methods ----
 
 	//by name (only in gui/networks.cs configInit
 	//be careful because name is not unique
 	public static Session SelectByName(string name)
 	{
-		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE name == \"" + name + "\""; 
-		return SelectDo(dbcmd);
+		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE name == \"" + name + "\"";
+
+		List<Session> session_l = selectDo(dbcmd);
+		if(session_l.Count == 0)
+			return new Session();
+
+		//return (Session) selectDo(dbcmd)[0];
+		return session_l[0];
 	}
 	//by ID (default
 	public static Session Select(string myUniqueID)
 	{
 		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable + " WHERE uniqueID == " + myUniqueID ; 
-		return SelectDo(dbcmd);
+
+		List<Session> session_l = selectDo(dbcmd);
+		if(session_l.Count == 0)
+			return new Session();
+
+		//return (Session) selectDo(dbcmd)[0];
+		return session_l[0];
 	}
-	public static Session SelectDo(SqliteCommand mydbcmd)
+	public static List<Session> SelectAll()
+	{
+		dbcmd.CommandText = "SELECT * FROM " + Constants.SessionTable;
+		return selectDo(dbcmd);
+	}
+	private static List<Session> selectDo(SqliteCommand mydbcmd)
 	{
 		try {
 			Sqlite.Open();
@@ -251,29 +291,28 @@ class SqliteSession : Sqlite
 		
 		SqliteDataReader reader;
 		reader = mydbcmd.ExecuteReader();
+		List<Session> session_l = new List<Session>();
 	
-		string [] values = new string[9];
-		
-		while(reader.Read()) {
-			values[0] = reader[0].ToString(); 
-			values[1] = reader[1].ToString(); 
-			values[2] = reader[2].ToString();
-			values[3] = reader[3].ToString();
-			values[4] = reader[4].ToString();
-			values[5] = reader[5].ToString();
-			values[6] = reader[6].ToString();
-			values[7] = reader[7].ToString();
-			values[8] = reader[8].ToString();
+		while(reader.Read())
+		{
+			Session session = new Session(
+					reader[0].ToString(),
+					reader[1].ToString(),
+					reader[2].ToString(),
+					UtilDate.FromSql(reader[3].ToString()),
+					Convert.ToInt32(reader[4].ToString()),
+					Convert.ToInt32(reader[5].ToString()),
+					Convert.ToInt32(reader[6].ToString()),
+					reader[7].ToString(),
+					Convert.ToInt32(reader[8].ToString())
+					);
+
+			session_l.Add(session);
 		}
 
-		Session mySession = new Session(values[0], 
-			values[1], values[2], UtilDate.FromSql(values[3]), 
-			Convert.ToInt32(values[4]), Convert.ToInt32(values[5]), Convert.ToInt32(values[6]), 
-			values[7], Convert.ToInt32(values[8]) );
-		
 		reader.Close();
 		Sqlite.Close();
-		return mySession;
+		return session_l;
 	}
 	
 	//used by the stats selector of sessions
@@ -350,7 +389,7 @@ class SqliteSession : Sqlite
 	private static string[] selectAllSessionsDo(string filterName, SqliteConnection dbcon)
 	{
 		// This method should NOT use Sqlite.open() / Sqlite.close(): it should only use dbcon
-		// to connect to the database. This methos is used by the importer after opening an arbitrary
+		// to connect to the database. This method is used by the importer after opening an arbitrary
 		// ChronoJump sqlite database. It needs to be refactored to the new database system.
 
 		dbcmd = dbcon.CreateCommand();
@@ -579,9 +618,47 @@ class SqliteSession : Sqlite
 
 		reader_enc.Close();
 
+		//select force sensor of each session
+		ArrayList myArray_fs = new ArrayList(2);
 
+		//if we are importing from a session who was not the forceSensor table (db version < 1.68)
+		if(tableExists(true, Constants.ForceSensorTable))
+		{
+			dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.ForceSensorTable +
+				" GROUP BY sessionID ORDER BY sessionID";
+			LogB.SQL(dbcmd.CommandText.ToString());
+			dbcmd.ExecuteNonQuery();
 
-		//mix nine arrayLists
+			SqliteDataReader reader_fs;
+			reader_fs = dbcmd.ExecuteReader();
+
+			while(reader_fs.Read()) {
+				myArray_fs.Add (reader_fs[0].ToString() + ":" + reader_fs[1].ToString() + ":" );
+			}
+			reader_fs.Close();
+		}
+
+		//select run encoder of each session
+		ArrayList myArray_re = new ArrayList(2);
+
+		//if we are importing from a session who was not the forceSensor table (db version < 1.70)
+		if(tableExists(true, Constants.RunEncoderTable))
+		{
+			dbcmd.CommandText = "SELECT sessionID, count(*) FROM " + Constants.RunEncoderTable +
+				" GROUP BY sessionID ORDER BY sessionID";
+			LogB.SQL(dbcmd.CommandText.ToString());
+			dbcmd.ExecuteNonQuery();
+
+			SqliteDataReader reader_re;
+			reader_re = dbcmd.ExecuteReader();
+
+			while(reader_re.Read()) {
+				myArray_re.Add (reader_re[0].ToString() + ":" + reader_re[1].ToString() + ":" );
+			}
+			reader_re.Close();
+		}
+
+		//mix ten arrayLists
 		string [] mySessions = new string[count];
 		count =0;
 		bool found;
@@ -712,6 +789,27 @@ class SqliteSession : Sqlite
 			}
 			lineNotReadOnly  = lineNotReadOnly + ":" + result_enc_s + " ; " + result_enc_r;
 
+			//add force sensor for each session
+			found = false;
+			foreach (string line_fs in myArray_fs) {
+				string [] myStringFull = line_fs.Split(new char[] {':'});
+				if(myStringFull[0] == mixingSessionID) {
+					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
+					found = true;
+				}
+			}
+			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
+
+			//add run encoder for each session
+			found = false;
+			foreach (string line_re in myArray_re) {
+				string [] myStringFull = line_re.Split(new char[] {':'});
+				if(myStringFull[0] == mixingSessionID) {
+					lineNotReadOnly  = lineNotReadOnly + ":" + myStringFull[1];
+					found = true;
+				}
+			}
+			if (!found) { lineNotReadOnly  = lineNotReadOnly + ":0"; }
 
 			mySessions [count++] = lineNotReadOnly;
 		}
@@ -728,6 +826,7 @@ class SqliteSession : Sqlite
 
 	//called from gui/event.cs for doing the graph
 	//we need to know the avg of events of a type (SJ, CMJ, free (pulse).. of a person, or of all persons on the session
+	//from 2.0 type can be "" so all types
 	public static double SelectAVGEventsOfAType(bool dbconOpened, int sessionID, int personID, string table, string type, string valueToSelect) 
 	{
 		return selectEventsOfAType(dbconOpened, sessionID, personID, table, type, valueToSelect, "AVG");
@@ -746,21 +845,34 @@ class SqliteSession : Sqlite
 		if(!dbconOpened)
 			Sqlite.Open();
 
-		//if personIDString == -1, the applies for all persons
-		
-		string personIDString = "";
-		if(personID != -1)
-			personIDString = " AND personID = " + personID; 
+		string connector = " WHERE "; //WHERE or AND
 		
 		string sessionIDString = "";
 		if(sessionID != -1)
-			sessionIDString = " AND sessionID = " + sessionID; 
+		{
+			sessionIDString = connector + "sessionID = " + sessionID;
+			connector = " AND ";
+		}
+
+		string personIDString = "";
+		if(personID != -1)
+		{
+			personIDString = connector + "personID = " + personID;
+			connector = " AND ";
+		}
+
+		string typeString = "";
+		if(type != "")
+		{
+			typeString = connector + "type = \"" + type + "\"";
+			connector = " AND ";
+		}
 		
 		dbcmd.CommandText = "SELECT " + statistic + "(" + valueToSelect + ")" +
 			" FROM " + table +				
-			" WHERE type = \"" + type + "\" " +
+			sessionIDString +
 			personIDString + 
-			sessionIDString;
+			typeString;
 		
 		LogB.SQL(dbcmd.CommandText.ToString());
 		dbcmd.ExecuteNonQuery();
@@ -786,87 +898,176 @@ class SqliteSession : Sqlite
 		}
 	}
 
-	
-	public static void DeleteAllStuff(string uniqueID)
+	// It's used by export and receives a specific database
+	// we want to delete all stuff of unwanted sessions
+	public static void DeleteAllStuff(string sessionID, SqliteConnection dbcon)
 	{
 		Sqlite.Open();
 
+		deleteAllStuffDo (sessionID, dbcon, true);
+
+		Sqlite.Close();
+	}
+	
+	// This is the usual chronojump's call (default database)
+	public static void DeleteAllStuff(string sessionID)
+	{
+		Sqlite.Open();
+
+		deleteAllStuffDo (sessionID, dbcon, false);
+
+		Sqlite.Close();
+	}
+
+	private static void deleteAllStuffDo (string sessionID, SqliteConnection dbcon, bool export)
+	{
+		LogB.Information("DeleteAllStuffDo 0");
+		dbcmd = dbcon.CreateCommand();
+
 		//delete the session
-		dbcmd.CommandText = "Delete FROM " + Constants.SessionTable + " WHERE uniqueID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.SessionTable + " WHERE uniqueID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete relations (existance) within persons and sessions in this session
-		dbcmd.CommandText = "Delete FROM " + Constants.PersonSessionTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.PersonSessionTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 
-		Sqlite.deleteOrphanedPersons();
+		LogB.Information("DeleteAllStuffDo 1");
+		//TODO: take care on export to do that but passing dbcon
+		if(! export)
+			Sqlite.deleteOrphanedPersons();
+		LogB.Information("DeleteAllStuffDo 2");
 		
 		//delete normal jumps
-		dbcmd.CommandText = "Delete FROM " + Constants.JumpTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.JumpTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete repetitive jumps
-		dbcmd.CommandText = "Delete FROM " + Constants.JumpRjTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.JumpRjTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete normal runs
-		dbcmd.CommandText = "Delete FROM " + Constants.RunTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.RunTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete intervallic runs
-		dbcmd.CommandText = "Delete FROM " + Constants.RunIntervalTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.RunIntervalTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete reaction times
-		dbcmd.CommandText = "Delete FROM " + Constants.ReactionTimeTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.ReactionTimeTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete pulses
-		dbcmd.CommandText = "Delete FROM " + Constants.PulseTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.PulseTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete multiChronopic
-		dbcmd.CommandText = "Delete FROM " + Constants.MultiChronopicTable + " WHERE sessionID == " + uniqueID;
+		dbcmd.CommandText = "Delete FROM " + Constants.MultiChronopicTable + " WHERE sessionID == " + sessionID;
 		dbcmd.ExecuteNonQuery();
 		
 		//delete from encoder start ------>
 
-		//signals
-		ArrayList encoderArray = SqliteEncoder.Select(
-				true, -1, -1, Convert.ToInt32(uniqueID), Constants.EncoderGI.ALL,
-				-1, "signal", EncoderSQL.Eccons.ALL,
-				false, true);
-		
-		foreach(EncoderSQL eSQL in encoderArray) {
-			Util.FileDelete(eSQL.GetFullURL(false));	//signal, don't convertPathToR
-			if(eSQL.videoURL != "")
-				Util.FileDelete(eSQL.videoURL);		//video
-			Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
-		}
-		
-		//curves
-		encoderArray = SqliteEncoder.Select(
-				true, -1, -1, Convert.ToInt32(uniqueID), Constants.EncoderGI.ALL,
-				-1, "curve",  EncoderSQL.Eccons.ALL,
-				false, true);
-		
-		foreach(EncoderSQL eSQL in encoderArray) {
-			Util.FileDelete(eSQL.GetFullURL(false));	//don't convertPathToR
-			/* commented: curve has no video
-			if(eSQL.videoURL != "")
-				Util.FileDelete(eSQL.videoURL);
-			*/
-			Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
-			SqliteEncoder.DeleteSignalCurveWithCurveID(true, Convert.ToInt32(eSQL.uniqueID));
+		/*
+		 * on export we only want to delete SQL stuff, because files of other sessions will not be copied
+		 * but note if we want to call some other SQL method, we need to take care to pass dbcon or dbcmd
+		 */
+		if(export)
+		{
+			// 1 get all the encoder signals of that session
+			dbcmd.CommandText = "SELECT uniqueID FROM " + Constants.EncoderTable +
+				" WHERE signalOrCurve = \"signal\"" +
+				" AND sessionID = " + sessionID;
 
-			//delete related triggers
-			SqliteTrigger.DeleteByModeID(true, Convert.ToInt32(eSQL.uniqueID));
+			SqliteDataReader reader;
+			reader = dbcmd.ExecuteReader();
+			List<string> signal_l = new List<string>();
+
+			// 2 delete all the EncoderSignalCurves (relation with signal and curves) of that signals
+			while(reader.Read())
+				signal_l.Add(reader[0].ToString());
+
+			reader.Close();
+
+			foreach(string signal in signal_l)
+			{
+				dbcmd.CommandText = "Delete FROM " + Constants.EncoderSignalCurveTable +
+					" WHERE signalID = " + signal;
+				dbcmd.ExecuteNonQuery();
+			}
+
+			// 3 delete all encoder table stuff (signals and curves)
+			dbcmd.CommandText = "Delete FROM " + Constants.EncoderTable + " WHERE sessionID = " + sessionID;
+			dbcmd.ExecuteNonQuery();
+		} else
+		{
+			//signals
+			ArrayList encoderArray = SqliteEncoder.Select(
+					true, -1, -1, Convert.ToInt32(sessionID), Constants.EncoderGI.ALL,
+					-1, "signal", EncoderSQL.Eccons.ALL, "",
+					false, true);
+
+			foreach(EncoderSQL eSQL in encoderArray) {
+				Util.FileDelete(eSQL.GetFullURL(false));	//signal, don't convertPathToR
+				if(eSQL.videoURL != "")
+					Util.FileDelete(eSQL.videoURL);		//video
+				Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
+			}
+
+			//curves
+			encoderArray = SqliteEncoder.Select(
+					true, -1, -1, Convert.ToInt32(sessionID), Constants.EncoderGI.ALL,
+					-1, "curve",  EncoderSQL.Eccons.ALL, "",
+					false, true);
+
+			foreach(EncoderSQL eSQL in encoderArray) {
+				Util.FileDelete(eSQL.GetFullURL(false));	//don't convertPathToR
+				/* commented: curve has no video
+				   if(eSQL.videoURL != "")
+				   Util.FileDelete(eSQL.videoURL);
+				   */
+				Sqlite.Delete(true, Constants.EncoderTable, Convert.ToInt32(eSQL.uniqueID));
+				SqliteEncoder.DeleteSignalCurveWithCurveID(true, Convert.ToInt32(eSQL.uniqueID));
+
+				//delete related triggers
+				SqliteTrigger.DeleteByModeID(true, Convert.ToInt32(eSQL.uniqueID));
+			}
 		}
 		
 		//<------- delete from encoder end
-				
-		
-		Sqlite.Close();
+
+		// delete forceSensor
+		dbcmd.CommandText = "Delete FROM " + Constants.ForceSensorTable + " WHERE sessionID = " + sessionID;
+		dbcmd.ExecuteNonQuery();
+
+		System.IO.DirectoryInfo folderSession;
+		//on export we only want to delete SQL stuff, because files of other sessions will not be copied
+		if(! export)
+		{
+			folderSession = new System.IO.DirectoryInfo(
+					Util.GetForceSensorSessionDir(Convert.ToInt32(sessionID)));
+
+			if(folderSession.Exists)
+				foreach (FileInfo file in folderSession.GetFiles())
+					Util.FileDelete(file.Name);
+		}
+
+		// delete runEncoder
+		dbcmd.CommandText = "Delete FROM " + Constants.RunEncoderTable + " WHERE sessionID = " + sessionID;
+		dbcmd.ExecuteNonQuery();
+
+		//on export we only want to delete SQL stuff, because files of other sessions will not be copied
+		if(! export)
+		{
+			folderSession = new System.IO.DirectoryInfo(
+					Util.GetRunEncoderSessionDir(Convert.ToInt32(sessionID)));
+
+			if(folderSession.Exists)
+				foreach (FileInfo file in folderSession.GetFiles())
+					Util.FileDelete(file.Name);
+		}
+
+		//TODO: delete multimedia stuff of persons that have to be deleted, eg. on export: persons that are not in session (just for privacity)
 	}
 
 }
