@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -30,6 +30,8 @@ using System.Globalization; 	//Unicode
 //this class tries to be a space for methods that are used in different classes
 public class Util
 {
+	public static UtilAll.OperatingSystems operatingSystem;
+
 	/*
 	 * sometimes two doubles are similar "human eye" but different when they are compared with equal
 	 * just return true if the difference between them is lower than 0.001
@@ -73,7 +75,14 @@ public class Util
 		else
 			return ConvertToPoint(s);
 	}
-		
+	//this method performs a Math.Round
+	public static string DoubleToCSV(double d, int roundDecimals, string CSVsepString) {
+		string s = Math.Round(d, roundDecimals).ToString();
+		if(CSVsepString == "COMMA")
+			return ConvertToComma(s);
+		else
+			return ConvertToPoint(s);
+	}
 
 
 	//when we do a query to the server, it returns avg as "0,54" because it's latin localized
@@ -393,6 +402,17 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
+	public static string AddBoldMarks(string s)
+	{
+		return "<b>" + s + "</b>";
+	}
+	public static string RemoveBoldMarks(string s)
+	{
+		s = s.Replace("<b>", "");
+	        s = s.Replace("</b>", "");
+		return s;
+	}
+
 	//use this!!!	
 	public static string RemoveChar(string s, char c) 
 	{
@@ -445,13 +465,15 @@ public class Util
 		return myStringBuilder.ToString();
 	}
 
-	
-	public static string GetHeightInCentimeters (string time) {
-		// s = 4.9 * (tv/2)^2
-		double timeAsDouble = Convert.ToDouble(time);
-		double height = 100 * 4.9 * Math.Pow( timeAsDouble / 2.0 , 2 );
 
-		return height.ToString();
+	//old code sends and returns strings
+	public static string GetHeightInCentimeters (string time) {
+		return GetHeightInCentimeters (Convert.ToDouble(time)).ToString();
+	}
+	//new code (2019 ...) sends and returns doubles
+	public static double GetHeightInCentimeters (double tv) {
+		// s = 4.9 * (tv/2)^2
+		return 100 * 4.9 * Math.Pow( tv / 2.0 , 2 );
 	}
 	
 	public static double WeightFromKgToPercent (double jumpKg, double personKg) {
@@ -697,11 +719,16 @@ public class Util
 
 		return stiffness;
 	}
-	
 
-	public static string GetInitialSpeed (string time, bool metersSecondsPreferred) 
+	//old code sends and returns strings
+	public static string GetInitialSpeed (string time, bool metersSecondsPreferred)
 	{
-		double height = Convert.ToDouble( GetHeightInCentimeters(time) );
+		return GetInitialSpeed (Convert.ToDouble(time), metersSecondsPreferred).ToString();
+	}
+	//new code (2019 ...) sends and returns doubles
+	public static double GetInitialSpeed (double time, bool metersSecondsPreferred)
+	{
+		double height = GetHeightInCentimeters(time);
 		height = height / 100; //in meters
 		
 		// Vo = sqrt(2gh)
@@ -710,7 +737,7 @@ public class Util
 		if(! metersSecondsPreferred)
 			initialSpeed *= 3.6;
 
-		return initialSpeed.ToString();
+		return initialSpeed;
 	}
 	
 	public static double GetDjPower (double tc, double tf, double mass, double fallHeight) 
@@ -810,6 +837,11 @@ public class Util
 		LogB.Information("tryParse 'joan' as double: " + Util.IsNumber("joan",true).ToString()); //catalan (True)
 	}
 
+	public static bool IsNumber(char c, bool canBeDecimal)
+	{
+		return IsNumber(c.ToString(), canBeDecimal);
+	}
+
 	//gets a string and returns if all the chars are numbers or the decimal point in current localization
 	public static bool IsNumber(string str, bool canBeDecimal) 
 	{
@@ -858,6 +890,24 @@ public class Util
 		return path;
 	}
 	
+	//url and videoURL stored path is relative to be able to move data between computers
+	//then SELECT: makes it abolute (addURLpath)
+	//INSERT and UPDATE: makes it relative (removeURLpath)
+	public static string MakeURLabsolute(string url) {
+		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
+		if( ! url.StartsWith(parentDir) )
+			url = parentDir + url;
+
+		return url;
+	}
+	public static string MakeURLrelative(string url) {
+		string parentDir = Util.GetParentDir(true); //add final '/' or '\'
+		if( url.StartsWith(parentDir) )
+			url = url.Replace(parentDir, "");
+
+		return url;
+	}
+
 	/********** end of LocalApplicationData path ************/
 	
 	/********** start of database paths ************/
@@ -887,7 +937,11 @@ public class Util
 	public static string GetDatabaseTempDir() {
 		return Path.Combine(Path.GetTempPath(), "Chronojump");
 	}
-	
+
+	public static string GetDatabaseTempImportDir() {
+		return Path.Combine(Path.GetTempPath(), "ChronojumpImportDir");
+	}
+
 	/********** end of database paths ************/
 
 	/*	
@@ -980,15 +1034,15 @@ public class Util
 	 */
 
 	//to store run encoder data and graphs
-	public static string GetRaceAnalyzerDir()
+	public static string GetRunEncoderDir()
 	{
 		return Path.Combine(
 				Environment.GetFolderPath(Environment.SpecialFolder.LocalApplicationData),
 				"Chronojump" + Path.DirectorySeparatorChar + "raceAnalyzer");
 	}
-	public static void CreateRaceAnalyzerDirIfNeeded ()
+	public static void CreateRunEncoderDirIfNeeded ()
 	{
-		string dir = GetRaceAnalyzerDir();
+		string dir = GetRunEncoderDir();
 		if( ! Directory.Exists(dir)) {
 			Directory.CreateDirectory (dir);
 			LogB.Information ("created dir:", dir);
@@ -996,13 +1050,13 @@ public class Util
 	}
 
 	//runEncoder organized by sessions.
-	public static string GetRaceAnalyzerSessionDir (int sessionID)
+	public static string GetRunEncoderSessionDir (int sessionID)
 	{
-		return GetRaceAnalyzerDir() + Path.DirectorySeparatorChar + sessionID.ToString();
+		return GetRunEncoderDir() + Path.DirectorySeparatorChar + sessionID.ToString();
 	}
-	public static void CreateRaceAnalyzerSessionDirIfNeeded (int sessionID)
+	public static void CreateRunEncoderSessionDirIfNeeded (int sessionID)
 	{
-		string dir = GetRaceAnalyzerSessionDir(sessionID);
+		string dir = GetRunEncoderSessionDir(sessionID);
 		if( ! Directory.Exists(dir)) {
 			Directory.CreateDirectory (dir);
 			LogB.Information ("created dir:", dir);
@@ -1081,17 +1135,17 @@ public class Util
 	 */
 
 	//Pre: filename without 0001.png
-	public static string GetWebcamPhotoTempFileNamePre(string videoDevice)
+	public static string GetWebcamPhotoTempFileNamePre()
 	{
 		string fileName = Constants.PhotoTemp;
 
-		return Path.Combine(Path.GetTempPath(), Constants.PhotoTemp + "-" + videoDevice + "-");
+		return Path.Combine(Path.GetTempPath(), Constants.PhotoTemp + "-");
 	}
 
 	//Pre: filename with 0001.png
-	public static string GetWebcamPhotoTempFileNamePost(string videoDevice)
+	public static string GetWebcamPhotoTempFileNamePost()
 	{
-		return GetWebcamPhotoTempFileNamePre(videoDevice) + "0001.png";
+		return GetWebcamPhotoTempFileNamePre() + "0001.png";
 	}
 
 
@@ -1204,7 +1258,14 @@ public class Util
 			"share" + Path.DirectorySeparatorChar + "doc" + Path.DirectorySeparatorChar + "chronojump");
 	}
 
-	public static string GetPrefixDir(){
+	public static string GetPrefixDir()
+	{
+		//on mac with the bundle we use this method to return PrefixDir, as BaseDirectory and GetCurrentDirectory() do not work
+		if(operatingSystem == UtilAll.OperatingSystems.MACOSX)
+			return (System.IO.Path.Combine(
+						Path.GetDirectoryName(Process.GetCurrentProcess().MainModule.FileName),
+						".."));
+
 		string baseDirectory = System.IO.Path.Combine(System.AppDomain.CurrentDomain.BaseDirectory, "..");
 		if (! Directory.Exists(Path.Combine(baseDirectory, "lib" + Path.DirectorySeparatorChar + "chronojump"))) {
 			baseDirectory = System.IO.Path.Combine(baseDirectory, "..");
@@ -1267,14 +1328,23 @@ public class Util
 		return false;
 	}
 	
-	public static bool FileMove(string path, string filenameOrigin, string filenameDestination) {
+	public static bool FileMove(string path, string filenameOrigin, string filenameDestination)
+	{
+		LogB.Information(string.Format("Going to move: {0} to {1}",
+					path + Path.DirectorySeparatorChar + filenameOrigin,
+					path + Path.DirectorySeparatorChar + filenameDestination
+					));
 		try {
 			File.Move(
 					path + Path.DirectorySeparatorChar + filenameOrigin, 
 					path + Path.DirectorySeparatorChar + filenameDestination
 					);
+			LogB.Information("Moved ok");
 			return true;
-		} catch {}
+		} catch {
+			LogB.Information("Catched! cannot move");
+		}
+
 		return false;
 	}
 	
@@ -1382,7 +1452,7 @@ public class Util
  
 		if (UtilAll.IsWindows())
 			rBin=System.IO.Path.Combine(GetPrefixDir(), "bin/R.exe");
-		else if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.MACOSX)
+		else if(operatingSystem == UtilAll.OperatingSystems.MACOSX)
 			rBin = Constants.ROSX;
 
 		pinfo = new ProcessStartInfo();
@@ -1435,14 +1505,13 @@ public class Util
 		 * and some MacOSX users have 300% CPU
 		 */
 
-		if(UtilAll.GetOSEnum() == UtilAll.OperatingSystems.WINDOWS ||
+		if(operatingSystem == UtilAll.OperatingSystems.WINDOWS ||
 				gstreamer == Preferences.GstreamerTypes.SYSTEMSOUNDS)
 			return playSoundWindows(mySound);
 		else
 			return playSoundGstreamer(mySound, gstreamer);
 	}
 	
-//	private enum gstreamerVersions { GST_0_1, GST_1_0, SYSTEMSOUNDS }
 	private static SoundCodes playSoundGstreamer (Constants.SoundTypes mySound, Preferences.GstreamerTypes gstreamer)
 	{
 		string fileName = "";
@@ -1465,10 +1534,25 @@ public class Util
 				pBin="gst-launch-0.10";
 				pinfo.Arguments = "playbin2 " + @"uri=file://" + fileName;
 			}
-			else { //gstreamer == Preferences.GstreamerTypes.GST_1_0
+			else if (gstreamer == Preferences.GstreamerTypes.GST_1_0) {
 				pBin="gst-launch-1.0";
 				pinfo.Arguments = "playbin " + @"uri=file://" + fileName;
 			}
+			else if (gstreamer == Preferences.GstreamerTypes.FFPLAY)
+			{
+				pBin="ffplay";
+				if(operatingSystem == UtilAll.OperatingSystems.WINDOWS)
+				{
+					if(System.Environment.Is64BitProcess)
+						pBin = System.IO.Path.Combine(Util.GetPrefixDir(), "bin/ffplay.exe");
+					else
+						pBin = System.IO.Path.Combine(Util.GetPrefixDir(), "bin/i386/ffplay.exe");
+				}
+				else if(operatingSystem == UtilAll.OperatingSystems.MACOSX)
+					pBin = System.IO.Path.Combine(Util.GetPrefixDir(), "bin/ffplay");
+
+				pinfo.Arguments = fileName + " -nodisp -nostats -hide_banner -autoexit";
+			}
 
 			pinfo.FileName=pBin;
 
@@ -1691,6 +1775,21 @@ public class Util
 		return returnString;
 	}
 
+	public static string ListStringToString (List<string> l)
+	{
+		string str = "";
+		string sep = "";
+		if(l == null)
+			return str;
+
+		foreach (string s in l)
+		{
+			str += sep + s;
+			sep = "\n";
+		}
+
+		return str;
+	}
 	public static string [] ArrayListToString (ArrayList myArrayList) {
 		//if myArrayList is not defined, return with an empty string
 		try { 
@@ -1774,7 +1873,14 @@ public class Util
 		return false;
 	}
 
-	public static bool FoundInListDouble(List<double>l, double d) {
+	public static bool FoundInListInt(List<int> l, int i) {
+		foreach (int i2 in l)
+			if(i2 == i)
+				return true;
+
+		return false;
+	}
+	public static bool FoundInListDouble(List<double> l, double d) {
 		foreach (double d2 in l)
 			if(d2 == d)
 				return true;
@@ -1861,6 +1967,16 @@ public class Util
 		return myFile + extension;
 	}
 
+	//this includes the '.', eg: returns ".csv"
+	public static string GetExtension(string myFile)
+	{
+		int posOfDot = myFile.LastIndexOf('.');
+		if (posOfDot > 0)
+			return myFile.Substring(posOfDot);
+
+		return "";
+	}
+
 	public static string RemoveExtension(string myFile)
 	{
 		int posOfDot = myFile.LastIndexOf('.');
@@ -1886,9 +2002,9 @@ public class Util
 
 	public static string BoolToInOut (bool areWeIn) {
 		if(areWeIn)
-			return Constants.In;
+			return Constants.InStr();
 		else
-			return Constants.Out;
+			return Constants.OutStr();
 	}
 
 	public static int BoolToInt (bool myBool) {
@@ -1918,7 +2034,7 @@ public class Util
 
 	public static string FindLevelName(int levelInt) {
 		string foundLevelName = "";
-		foreach(string level in Constants.Levels)
+		foreach(string level in Constants.LevelsStr())
 			if(FetchID(level) == levelInt)
 				foundLevelName = FetchName(level);
 
@@ -1952,36 +2068,6 @@ public class Util
 	}
 
 
-	//avoids divide by zero
-	//thought for being between 0, 1
-	//ideal for progressBars
-	public static double DivideSafeFraction (double num, double denom)
-	{
-		if(num == 0 || denom == 0)
-			return 0;
-
-		double result = num / denom;
-		
-		if(result > 1)
-			result = 1;
-		else if(result < 0)
-			result = 0;
-
-		return result;
-	}
-	
-	public static double DivideSafeFraction (int val1, int val2) {
-		return DivideSafeFraction(Convert.ToDouble(val1), Convert.ToDouble(val2));
-	}
-
-	//Not restricted to values 0-1
-	public static double DivideSafe (double val1, double val2)
-	{
-		if(val1 == 0 || val2 == 0)
-			return 0;
-
-		return val1 / val2;
-	}
 
 	/*
 	//converts all values to positive
@@ -2007,16 +2093,16 @@ public class Util
 
 	public static string SimulatedTestNoYes(int num) {
 		if(num < 0)
-			return Constants.Yes;
+			return Constants.YesStr();
 		else
-			return Constants.No;
+			return Constants.NoStr();
 	}
 
 	public static string NoYes(bool b) {
 		if(! b)
-			return Constants.No;
+			return Constants.NoStr();
 		else
-			return Constants.Yes;
+			return Constants.YesStr();
 	}
 
 
@@ -2155,10 +2241,20 @@ public class Util
 	public static double ConvertFeetInchesToCm(int feet, double inches) {
 		return feet * 30.48 + inches * 2.54;
 	}
-	
+
+	public static void ConvertCmToFeetInches(double cm, out int feet, out double inches)
+	{
+		double numInches = UtilAll.DivideSafe(cm, 2.54);
+		feet = Convert.ToInt32(Math.Floor(UtilAll.DivideSafe(numInches, 12)));
+		inches = numInches % 12;
+	}
+
 	public static double ConvertPoundsToKg(double pounds) {
 		return pounds * 0.45359237;
 	}
+	public static double ConvertKgToPounds(double kg) {
+		return kg / 0.45359237;
+	}
 
 
 	/* 
@@ -2173,7 +2269,19 @@ public class Util
 			if (' ' <= c && c <= '~')
 				sb.Append(c);
 			else
-				sb.AppendFormat("\\U{0:X4}", (int)c);
+			{
+				//old: C#
+				//sb.AppendFormat("\\U{0:X4}", (int)c);
+				//On R, note:
+				//\Unnnn 1-8 hex digits (so this can have problems when a unicode char is at the side of another char
+				// 	\U00E1 2 : works
+				// 	\U00E12 : does not work, tries to find a unicode char different than the U00E1
+				//\unnnn 1-4 hex digits
+				// 	\u00E1 2 : works
+				// 	\u00E12 : works
+				//https://stat.ethz.ch/R-manual/R-devel/library/base/html/Quotes.html
+				sb.AppendFormat("\\u{0:X4}", (int)c);
+			}
 		}
 		return sb.ToString();
 	}
@@ -2218,17 +2326,25 @@ public class UtilCopy
 	public int BackupSecondDirsLength;
 	public string LastMainDir;
 	public string LastSecondDir;
+	private int sessionID;
+	private bool backup;
 
 	//to go faster on CopyFilesRecursively
 	static string backupDir = Util.GetDatabaseDir() + Path.DirectorySeparatorChar + "backup";
 
-	public UtilCopy()
+	//-1 is the default on a backup, means all sessions (regular backup)
+	//4 will only copy files related to session 4 (for export session)
+	//on export do not copy logs
+	public UtilCopy(int sessionID, bool backup)
 	{
 		BackupMainDirsCount = 0;
 		BackupSecondDirsCount = 0;
 		BackupSecondDirsLength = 0;
 		LastMainDir = "";
 		LastSecondDir = "";
+
+		this.sessionID = sessionID;
+		this.backup = backup;
 	}
 
 	//http://stackoverflow.com/a/58779
@@ -2240,20 +2356,46 @@ public class UtilCopy
 			{
 				if(level == 0)
 				{
+					if(! backup && Util.GetLastPartOfPath(dir.ToString()) == "logs")
+						continue;
+
 					BackupMainDirsCount ++;
 					LastMainDir = Util.GetLastPartOfPath (dir.ToString());
 					BackupSecondDirsCount = 0;
 					//LogB.Information("at level 0: " + dir);
-				} else if(level == 1) {
+				} else if(level == 1)
+				{
+					//on export, discard the unwanted sessions
+					if(sessionID > 0 && Util.IsNumber(Util.GetLastPartOfPath(dir.ToString()), false) &&
+							Convert.ToInt32(Util.GetLastPartOfPath(dir.ToString())) != sessionID)
+					{
+						//LogB.Information("Discarded: " + dir.ToString());
+						continue;
+					}
+
 					BackupSecondDirsLength = diArray.Length;
 					BackupSecondDirsCount ++;
 					LastSecondDir = Util.GetLastPartOfPath (dir.ToString());
 					//LogB.Information("at level 1: " + dir);
+				} else if(level == 2)
+				{
+					//on export, discard the unwanted sessions of multimedia videos
+					if(sessionID > 0 && dir.ToString().Contains("multimedia") && dir.ToString().Contains("videos") &&
+							Util.IsNumber(Util.GetLastPartOfPath(dir.ToString()), false) &&
+							Convert.ToInt32(Util.GetLastPartOfPath(dir.ToString())) != sessionID)
+					{
+						LogB.Information("Discarded video dir: " + dir.ToString());
+						continue;
+					}
 				}
 				CopyFilesRecursively(dir, target.CreateSubdirectory(dir.Name), level +1);
-
 			}
 		foreach (FileInfo file in source.GetFiles())
+		{
+			if(file.Name == "chronojump_running") 	//do not copy chronojump_running file
+				continue;
+
 			file.CopyTo(Path.Combine(target.FullName, file.Name));
+		}
 	}
 }
