@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -38,6 +38,10 @@ public class UtilDate
 	
 	//records date & time, useful to backup database without having strange chars on filename
 	//used also on SQL when time wants to be stored also
+	public static string ToFile ()
+	{
+		return ToFile(DateTime.Now);
+	}
 	public static string ToFile (DateTime dt)
 	{
 		return UtilAll.DigitsCreate(dt.Year,4) + "-" + 
@@ -48,6 +52,23 @@ public class UtilDate
 			UtilAll.DigitsCreate(dt.Second,2);
 	}
 
+	//records date & time, useful to backup database without having strange chars on filename
+	//used also on SQL when time wants to be stored also
+	public static DateTime FromFile (string s)
+	{
+		//TODO: check possible errors
+		string [] allFull = s.Split(new char[] {'_'});
+		string [] dateFull = allFull[0].Split(new char[] {'-'});
+		string [] timeFull = allFull[1].Split(new char[] {'-'});
+		return new DateTime(
+				Convert.ToInt32(dateFull[0]),
+				Convert.ToInt32(dateFull[1]),
+				Convert.ToInt32(dateFull[2]),
+				Convert.ToInt32(timeFull[0]),
+				Convert.ToInt32(timeFull[1]),
+				Convert.ToInt32(timeFull[2])
+				);
+	}
 
 	//comes from sql like YYYY-MM-DD (with always all digits)
 	//return datetime
@@ -105,4 +126,20 @@ public class UtilDate
 		return UtilAll.DigitsCreate(dt.Year,4) + "-" + Catalog.GetString(dt.ToString("MMMM"));
 	}
 
+	public static double DateTimeYearDayAsDouble(DateTime dt)
+	{
+		return dt.Year + UtilAll.DivideSafe(dt.DayOfYear, 360);
+	}
+
+	//month from 0 to 11
+	public static string GetMonthName(int month, bool abbreviate)
+	{
+	        string [] monthNames = { "January", "February", "March", "April", "May", "June", "July", "August", "September", "October", "November", "December" };
+	        string [] monthNamesAbbr = { "Jan", "Feb", "Mar", "Apr", "May", "Jun", "Jul", "Aug", "Sept", "Oct", "Nov", "Dec" };
+
+		if(abbreviate)
+			return monthNamesAbbr[month];
+		else
+			return monthNames[month];
+	}
 }
