@@ -149,8 +149,8 @@ public class UtilEncoder
 							GetEncoderSessionDataSignalDir(sessionID) + 
 							Path.DirectorySeparatorChar + fileName, true);
 				} catch {
-					new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblem);
-					LogB.Error(Constants.FileCopyProblem);
+					new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblemStr());
+					LogB.Error(Constants.FileCopyProblemStr());
 					return "";
 				}
 //			}
@@ -166,15 +166,15 @@ public class UtilEncoder
 			try {
 				File.Copy(origin, dest, true);
 			} catch {
-				new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblem);
-				LogB.Error(Constants.FileCopyProblem);
+				new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileCopyProblemStr());
+				LogB.Error(Constants.FileCopyProblemStr());
 				return false;
 			}
 			return true;
 		}
 
-		new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFound);
-		LogB.Error(Constants.FileNotFound);
+		new DialogMessage(Constants.MessageTypes.WARNING, Constants.FileNotFoundStr());
+		LogB.Error(Constants.FileNotFoundStr());
 		return false;
 	}
 
@@ -254,16 +254,6 @@ public class UtilEncoder
 		return System.IO.Path.Combine(Util.GetDataDir(), "r-scripts");
 	}
 
-	public static string GetRaceAnalyzerScript() {
-		return System.IO.Path.Combine(GetSprintPath(), "sprintEncoder.R");
-	}
-	public static string GetRaceAnalyzerCSVFileName() {
-		return Path.Combine(Path.GetTempPath(), "cj_race_analyzer_data.csv");
-	}
-	public static string GetRaceAnalyzerTempFileName() {
-		return Path.Combine(Path.GetTempPath(), "cj_race_analyzer_graph.png");
-	}
-
 	public static string GetmifScript() {
 		return System.IO.Path.Combine(GetSprintPath(), "maximumIsometricForce.R");
 	}
