@@ -15,7 +15,7 @@
  *  along with this program; if not, write to the Free Software
  *   Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
  *
- *  Copyright (C) 2004-2017   Xavier de Blas <xaviblas@gmail.com> 
+ *  Copyright (C) 2004-2020   Xavier de Blas <xaviblas@gmail.com> 
  */
 
 using System;
@@ -25,6 +25,7 @@ using System.Collections.Generic; //List<T>
 using System.IO;
 using Gtk;
 using Gdk;
+using System.Text.RegularExpressions; //Regex
 
 //this class tries to be a space for methods that are used in different classes
 //only Gtk related methods (not used bu the server) this is the differnece with Util
@@ -128,6 +129,12 @@ public class UtilGtk
 		} while (myCombo.Model.IterNext (ref iter));
 	}
 
+	//used on gui/preferences camera
+	public static void ComboDelAll(ComboBox myCombo)
+	{
+		comboDelAll(myCombo);
+	}
+
 	private static void comboDelAll(ComboBox myCombo) {
 		//myCombo = ComboBox.NewText(); don't work
 		TreeIter myIter;
@@ -456,9 +463,12 @@ public class UtilGtk
 	public static Gdk.Color WHITE = new Gdk.Color(0xff,0xff,0xff);
 	public static Gdk.Color BLACK = new Gdk.Color(0x00,0x00,0x00);
 	public static Gdk.Color GRAY = new Gdk.Color(0x66,0x66,0x66);
+	public static Gdk.Color GRAY_LIGHT = new Gdk.Color(0x99,0x99,0x99);
 	public static Gdk.Color BLUE = new Gdk.Color(0x6c,0x77,0xab);
 	public static Gdk.Color BLUE_CLEAR = new Gdk.Color(0xa0,0xa7,0xca);
+	public static Gdk.Color BLUE_CLEAR2 = new Gdk.Color(0x02,0x4e,0x69); //used on background of start buttons (modes)
 	public static Gdk.Color YELLOW = new Gdk.Color(0xff,0xcc,0x01);
+	public static Gdk.Color YELLOW_LIGHT = new Gdk.Color(0xf3,0xde,0x8c);
 	public static Gdk.Color YELLOW_DARK = new Gdk.Color(0xcd,0xcd,0x00);
 	public static Gdk.Color ORANGE_DARK = new Gdk.Color(0xff,0x7f,0x00);
 	
@@ -466,7 +476,7 @@ public class UtilGtk
 	public static Gdk.Color RED_PLOTS = new Gdk.Color(200,0,0);
 	public static Gdk.Color LIGHT_BLUE_PLOTS = new Gdk.Color(178,223,238);
 	public static Gdk.Color BLUE_PLOTS = new Gdk.Color(0,0,200);
-	public static Gdk.Color BLUE_CHRONOJUMP = new Gdk.Color(14,30,70); //so dark, can be used only for background
+	public static Gdk.Color BLUE_CHRONOJUMP = new Gdk.Color(14,30,70); //so dark, can be used only for background (is the 0e1e46)
 	
 	//used on encoder capture
 	public static Gdk.Color RED_DARK = new Gdk.Color(140,0,0);
@@ -475,14 +485,63 @@ public class UtilGtk
 	public static Gdk.Color GREEN_LIGHT = new Gdk.Color(0,238,0);
 	public static Gdk.Color BLUE_DARK = new Gdk.Color(0,0,140);
 	public static Gdk.Color BLUE_LIGHT = new Gdk.Color(0,75,238);
+	public static Gdk.Color MAGENTA = new Gdk.Color(255,0,255);
 	
 	public static string ColorGood = "ForestGreen";
 	public static string ColorBad = "red";
 	public static string ColorNothing = "";
+	public static string ColorGray = "gray";
+
 
-	
 	public static Gdk.Color SELECTED = GetBackgroundColorSelected();
 
+	public static bool ColorIsDark(Gdk.Color color)
+	{
+		//LogB.Information(string.Format("color red: {0}, green: {1}, blue: {2}", color.Red, color.Green, color.Blue));
+		//3 components come in ushort (0-65535)
+		//return (color.Red + color.Green + color.Blue < 3 * 65535 / 2.0);
+
+		//https://stackoverflow.com/questions/3942878/how-to-decide-font-color-in-white-or-black-depending-on-background-color
+		return (color.Red * 0.299 + color.Green * 0.587 + color.Blue * 0.114 < 186 * 256);
+	}
+	public static bool ColorIsDark(string colorString)
+	{
+		return ColorIsDark(ColorParse(colorString));
+	}
+
+
+	//darker or clearer
+	public static Gdk.Color GetColorShifted (Gdk.Color color, bool darker)
+	{
+		if(darker)
+			return new Gdk.Color(
+					(byte) Convert.ToDouble(.25 * color.Red),
+					(byte) Convert.ToDouble(.25 * color.Green),
+					(byte) Convert.ToDouble(.25 * color.Blue) );
+		else
+			return new Gdk.Color(
+					(byte) Convert.ToDouble(.25 * (65535 - color.Red)),
+					(byte) Convert.ToDouble(.25 * (65535 - color.Green)),
+					(byte) Convert.ToDouble(.25 * (65535 - color.Blue)) );
+	}
+
+	//if color is too white or too yellow, it will not be ok
+	public static bool ColorIsOkWithLogoTransparent (Gdk.Color color)
+	{
+		return ( ! colorIsQuiteClear(color) && ! colorIsYellow(color) );
+	}
+
+	//if is very clear it does not show ok the yellow of Boscosystem letters (also if it is clear blue)
+	private static bool colorIsQuiteClear (Gdk.Color color)
+	{
+		return (color.Red > 150 * 256 && color.Green > 150 * 256  && color.Blue > 150 * 256);
+	}
+
+	//yellow is red + green
+	private static bool colorIsYellow (Gdk.Color color)
+	{
+		return (color.Red > 200 * 256 && color.Green > 200 * 256 && color.Blue < 50 * 256);
+	}
 
 	public static Gdk.Color GetBackgroundColorSelected() {
 		Gtk.Style regularLabel = Gtk.Rc.GetStyle (new Gtk.Label());
@@ -577,7 +636,74 @@ public class UtilGtk
 			l2.ModifyFg(StateType.Normal, WHITE);
 		}
 	}
+
+	//changes of colors without widgets that are in a EventBox
+	public static void EventBoxColorBackgroundActive (Gtk.EventBox e, Gdk.Color colorActive, Gdk.Color colorPrelight)
+	{
+		e.ModifyBg(StateType.Active, colorActive);
+		e.ModifyBg(StateType.Prelight, colorPrelight);
+	}
+
+	public static void ContrastLabelsHBox (bool bgDark, Gtk.HBox hbox)
+	{
+		contrastLabelsContainer (bgDark, (Gtk.Container) hbox);
+	}
+	public static void ContrastLabelsVBox (bool bgDark, Gtk.VBox vbox)
+	{
+		contrastLabelsContainer (bgDark, (Gtk.Container) vbox);
+	}
+	public static void ContrastLabelsTable (bool bgDark, Gtk.Table table)
+	{
+		contrastLabelsContainer (bgDark, (Gtk.Container) table);
+	}
+	public static void ContrastLabelsNotebook (bool bgDark, Gtk.Notebook notebook)
+	{
+		contrastLabelsContainer (bgDark, (Gtk.Container) notebook);
+	}
+
+	private static void contrastLabelsContainer (bool bgDark, Gtk.Container container)
+	{
+		foreach(Gtk.Widget w in container.Children)
+		{
+			if(w.GetType() == typeof(Gtk.Label))
+				ContrastLabelsLabel (bgDark, (Gtk.Label) w);
+
+			else if(w.GetType() == typeof(Gtk.Alignment))
+			{
+				Gtk.Widget child = ((Gtk.Alignment) w).Child;
+				if(isContainer(child))
+					contrastLabelsContainer (bgDark, (Gtk.Container) child);
+			}
+			else if(isContainer(w))
+				contrastLabelsContainer (bgDark, (Gtk.Container) w);
+		}
+	}
+
+	private static bool isContainer(Gtk.Widget w)
+	{
+		return ( w.GetType() == typeof(Gtk.HBox) ||
+				w.GetType() == typeof(Gtk.VBox) ||
+				w.GetType() == typeof(Gtk.Table) ||
+				w.GetType() == typeof(Gtk.Notebook) ||
+				w.GetType() == typeof(Gtk.Frame) ||
+				w.GetType() == typeof(Gtk.CheckButton) ||
+				w.GetType() == typeof(Gtk.RadioButton)
+			);
+	}
+
+	public static void ContrastLabelsLabel (bool bgDark, Gtk.Label l)
+	{
+		if(bgDark)
+		{
+			l.ModifyFg(StateType.Normal, YELLOW_LIGHT);
+			l.ModifyFg(StateType.Active, YELLOW_LIGHT); //needed for CheckButton and RadioButton
+		} else {
+			l.ModifyFg(StateType.Normal, BLACK);
+			//l.ModifyFg(StateType.Active, BLACK);
+		}
+	}
 	
+
 	/*
 	 *
 	 * PRETTY THINGS
@@ -623,6 +749,13 @@ public class UtilGtk
 	}
 
 
+	public static string TextViewGetCommentValidSQL (Gtk.TextView tv)
+	{
+		//string s = Util.MakeValidSQL(textview_force_sensor_capture_comment.Buffer.Text);
+		string s = Util.MakeValidSQL(tv.Buffer.Text);
+		return s;
+	}
+
 	
 	public static TextBuffer TextViewPrint(string message) {
 		TextBuffer tb = new TextBuffer (new TextTagTable());
@@ -661,11 +794,12 @@ public class UtilGtk
 		l.TooltipText = Util.RemoveMarkup(s);
 	}
 
+	public enum ArrowEnum { NONE, FORWARD, BACKWARD, FORWARD_EMPHASIS }
 	public static Button CreateArrowButton(ArrowType arrow_type, ShadowType shadow_type)
 	{
-		return CreateArrowButton(arrow_type, shadow_type, -1, -1);
+		return CreateArrowButton(arrow_type, shadow_type, -1, -1, ArrowEnum.NONE);
 	}
-	public static Button CreateArrowButton(ArrowType arrow_type, ShadowType shadow_type, int width, int height)
+	public static Button CreateArrowButton(ArrowType arrow_type, ShadowType shadow_type, int width, int height, ArrowEnum customArrow)
 	{
 		Button button = new Button ();
 
@@ -674,12 +808,27 @@ public class UtilGtk
 		if(height > 0)
 			button.HeightRequest = height;
 
-		Arrow  arrow = new Arrow (arrow_type, shadow_type);
+		if(customArrow == ArrowEnum.NONE)
+		{
+			Arrow  arrow = new Arrow (arrow_type, shadow_type);
+			button.Add(arrow);
+		} else {
+			Pixbuf pixbuf;
+			if(customArrow == ArrowEnum.FORWARD)
+				pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameArrowForward);
+			else if(customArrow == ArrowEnum.BACKWARD)
+				pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameArrowBackward);
+			else if(customArrow == ArrowEnum.FORWARD_EMPHASIS)
+				pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameArrowForwardEmphasis);
+			else
+				pixbuf = new Pixbuf (null, Util.GetImagePath(false) + Constants.FileNameArrowForward); //default
 
-		button.Add(arrow);
+			Gtk.Image image = new Gtk.Image();
+			image.Pixbuf = pixbuf;
+			button.Add(image);
+		}
 
-		button.Show();
-		arrow.Show();
+		button.ShowAll();
 
 		return button;
 	}
@@ -706,6 +855,47 @@ public class UtilGtk
 		
 		UtilGtk.ErasePaint(da, px);
 	}
+
+	//color string like "#0e1e46" for Chronojump blue
+	public static Gdk.Color ColorParse(string colorString)
+	{
+		Gdk.Color color = new Gdk.Color();
+		Gdk.Color.Parse(colorString, ref color);
+		return color;
+	}
+	//reverse of previous method
+	public static string ColorToColorString (Gdk.Color color)
+	{
+		string str = color.ToString(); //returns this: rgb:8b8b/6969/1414 or this: rgb:ffff/a5a5/0 (if blue is 0)
+		LogB.Information("str at ColorToColorString: " + str);
+		Match match = Regex.Match(str, @"rgb:(\w+)/(\w+)/(\w+)");
+		LogB.Information("ColorToColorString match groups: " + match.Groups.Count.ToString());
+		if(match.Groups.Count == 4)
+		{
+			return string.Format("#{0}{1}{2}", colHexTwoChars(match.Groups[1].Value),
+					colHexTwoChars(match.Groups[2].Value), colHexTwoChars(match.Groups[3].Value));
+		} else
+			return "#0e1e46"; //default if there are problems
+	}
+	private static string colHexTwoChars(string colorString)
+	{
+		if(colorString.Length == 1) //if "0" return "00"
+			return colorString + colorString;
+		if(colorString.Length == 2) //if "ce" return "ce"
+			return colorString;
+		if(colorString.Length == 3) //if "e0e" return "0e" (like the Chronojump blue)
+			return colorString.Substring(1,2);
+		if(colorString.Length == 4) //if "cece" return "ce")
+			return colorString.Substring(0,2);
+
+		return colorString;
+	}
+
+	public static void PaintColorDrawingArea(Gtk.DrawingArea da, Gdk.Color color)
+	{
+		da.ModifyBg(StateType.Normal, color);
+	}
+
 	
 	/*
 	 *
@@ -771,6 +961,62 @@ public class UtilGtk
 		return pixbuf;
 	}
 
+	//spacing allows the line to breath
+	public static void DrawHorizontalLine(Pixmap pixmap, Gdk.GC pen, int xleft, int xright, int y,
+			int spacing, bool arrowleft, bool arrowright, int arrowlength)
+	{
+		pixmap.DrawLine(pen, xleft + spacing, y, xright - spacing, y);
 
+		//empty arrows
+		if(arrowleft)
+		{
+			pixmap.DrawLine(pen,
+					xleft + spacing, y,
+					xleft + spacing + arrowlength, y - arrowlength);
+			pixmap.DrawLine(pen,
+					xleft + spacing, y,
+					xleft + spacing + arrowlength, y + arrowlength);
+		}
+		if(arrowright)
+		{
+			pixmap.DrawLine(pen,
+					xright - spacing, y,
+					xright - spacing - arrowlength, y - arrowlength);
+			pixmap.DrawLine(pen,
+					xright - spacing, y,
+					xright - spacing - arrowlength, y + arrowlength);
+		}
+	}
+
+
+
+	// adapted from: https://stackoverflow.com/a/9295210/12366369
+	// thanks to renosis and Komplot
+	// tip is the point where the arrow will be drawn
+	public static void DrawArrow (Pixmap pixmap, Gdk.GC pen, int tipX, int tailX, int tipY, int tailY, int arrowLength)
+	{
+		int dx = tipX - tailX;
+		int dy = tipY - tailY;
+
+		double theta = Math.Atan2(dy, dx);
+
+		double rad = MathCJ.ToRadians(35); //35 angle, can be adjusted
+		double x = tipX - arrowLength * Math.Cos(theta + rad);
+		double y = tipY - arrowLength * Math.Sin(theta + rad);
+
+		double phi2 = MathCJ.ToRadians(-35);//-35 angle, can be adjusted
+		double x2 = tipX - arrowLength * Math.Cos(theta + phi2);
+		double y2 = tipY - arrowLength * Math.Sin(theta + phi2);
+
+		Point [] points = new Point[3];
+		points[0].X = (int) x;
+		points[0].Y = (int) y;
+		points[1].X = tipX;
+		points[1].Y = tipY;
+		points[2].X = (int) x2;
+		points[2].Y = (int) y2;
+
+		pixmap.DrawPolygon(pen, true, points);
+	}
 
 }
